#!/bin/ksh
#############################################################################
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2006, 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
##
##   Title:	configPort.sh
##   Description: Updates the /etc/services with the port information of
##		  MQ
##		
##
#############################################################################

# determine where script was called from
script_location=`dirname $0 2>/dev/null`
if [ -z "$script_location" ];then
	script_location="."
fi

version=v1.1

# determine TS_HOME and source the tsEnv.sh here 
if  [ -f $script_location"/../etc/RFIDICServer.xml" ]; then
	TS_HOME="`( cd \"${script_location}"/.."\" && pwd )`"
	echo "TS_HOME=$TS_HOME"
elif [ -n "$TS_HOME" ]; then
	echo "TS_HOME=$TS_HOME"
else
	TS_HOME=/opt/ibm/InfoSphere/TraceabilityServer
fi

if [ -d $TS_HOME ] 
then
	. $TS_HOME/bin/tsEnv.sh> /dev/null
else
	# Use the 'file' command to return the 'cannot open directory' message in the 
	# current locale.  RFIDIC messages are available only after setting the environment.
 	file $TS_HOME
 	exit -1
fi

mqport=$MQ_LSR_PORT


# The code below will search for the port in /etc/services and if it present and is not commented, then it will
# search for another port. However if it is present and is not commented and is already used for MQ, then it will continue to use it.
setMQPort()
{
	while `grep -w $mqport/tcp /etc/services | grep -v '^#' | grep -v 'MQ' >/dev/null`
	do
		getMessage  RFID05021I  "$mqport"
        echo $msg
		let mqport=mqport+1
		getMessage  RFID05022I "$mqport"
        echo $msg
	done
	getMessage  RFID05023I "$mqport"
    echo $msg
	echo  "mqm		$mqport/tcp			# MQ Series Port" >> /etc/services
}

temp_services=/tmp/rfidic-configPort-svcs.tmp
case "$1" in
	mq)
		mqport=$2
		setMQPort
		MQ_LSR_PORT=$mqport
		export MQ_LSR_PORT
		;;
	clean)
		sed '/mqm/d' /etc/services >| ${temp_services}
		mv -f ${temp_services} /etc/services
		chmod 644 /etc/services
		;;
	cleanmq)
		sed '/mqm/d' /etc/services >| ${temp_services}
		mv -f ${temp_services} /etc/services
		chmod 644 /etc/services
		;;         
	*)
		# Usage
		. $TS_HOME/bin/tsEnv.sh > /dev/null
		getMessage RFID05081I "$0"
esac
