#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
##
##   Title: configureWAS.sh
##   Description: Configures WAS. Creates DataSource, scheduler and
##   		  installs an enterprise application
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
. $SCRIPT_DIR/utils.sh
. $SCRIPT_DIR/tsEnv.sh 
returnCode=$?
if [ "$returnCode" != "0" ];then
    exit $returnCode
fi

ID=`id`
CURRENT_USER=`expr "$ID" : ".*uid=[0-9]*(\([^)]*\)*"`

umask 022
PLATFORM=`/bin/uname`

if [ "$PLATFORM" = "SunOS" ];then
	AWK="awk -F."
	AWK_COLON="awk -F:"
else
	AWK="awk -F ".""
	AWK_COLON="awk -F ":""

fi

if [ ! -e "${TS_HOME}/logs/WAS" ];then
	run_command ln -s "${WAS_PROFILE_HOME}/logs" "${TS_HOME}/logs/WAS"
fi

connectDB()
{
	# Check Database status
	java -classpath $CLASSPATH -DRFIDIC_HOME=$TS_HOME -DTS_HOME=$TS_HOME com.ibm.rfidic.utils.install.DBConnect connect
	db_status=$?
	if [ "$db_status" -ne 0 ];then
		#echo "Ensure that the database is running and then try again."
		getMessage RFID05231E
        $ECHO $msg
		return 1;
	fi
}

usage()
{
	. $TS_HOME/bin/tsEnv.sh > /dev/null
	 getMessage RFID05086I "$0"
     $ECHO $msg
}

#XXX -bundle messages
#Make sure the stand-alone server or the dmgr is running
startWAS()
{
    if [ ! -z "$was_admin_user" ];then
		creds="-username $was_admin_user -password $was_admin_password"
    fi
    if [ -z "$CLUSTERNAME" ];then
		start_server=$SERVERNAME
    else
		start_server=dmgr
    fi
    server_status=`${WAS_PROFILE_HOME}/bin/serverStatus.sh $start_server $creds`
    status=$?

    if [ "$status" -ne 0 ];then
    	getMessage TSIN02249E $start_server $status
    	$ECHO $msg
		#echo "Could not get status for $start_server status=$status"
		return 1
    fi

    present=`echo $server_status |grep "ADMU0508I"`
    status=$?

    if [ $status -ne 0 ];then
		if [ -z "$CLUSTERNAME" ];then
            if [ -n "$was_runas_user" ];then
                runCommandAsUser $was_runas_user:$TS_ADMIN_PASSWORD ${WAS_PROFILE_HOME}/bin/startServer.sh $SERVERNAME
            else
                ${WAS_PROFILE_HOME}/bin/startServer.sh $SERVERNAME
            fi
			status=$?
		else
            if [ -n "$was_runas_user" ];then
                runCommandAsUser $was_runas_user:$TS_ADMIN_PASSWORD ${WAS_PROFILE_HOME}/bin/startManager.sh
            else
                ${WAS_PROFILE_HOME}/bin/startManager.sh
            fi
			status=$?
		fi
	
		if [ "$status" -ne 0 ];then
			getMessage TSIN02250E $start_server $status
			$ECHO $msg
			#echo "Could not start $start_server status=$status"
			return 1
		fi
    else
    	getMessage TSIN02251I $start_server
    	$ECHO $msg
		#echo "$start_server already running"
    fi
}

#Stop a stand-alone application server
#Don't stop the dmgr, in the ND case configDriver will restart cluster members
stopWAS()
{
    if [ -z "$CLUSTERNAME" ];then
		if [ -n "$was_admin_user"  ];then
			${WAS_PROFILE_HOME}/bin/stopServer.sh ${SERVERNAME} -username $was_admin_user -password $was_admin_password
			status=$?
		else
			${WAS_PROFILE_HOME}/bin/stopServer.sh ${SERVERNAME}
			status=$?
		fi
    fi

    if [ "$status" -ne 0 ];then
    	getMessage TSIN02252I $SERVERNAME $status
    	$ECHO $msg
		#echo "Could not stop $SERVERNAME status=$status"
		return 1
    fi
}

if [ $# -gt 7 ];then
	usage
	exit 1
else
	for item in $*
	do
		if [ `echo $item | wc -c` = 2 ];then
			usage
			exit 1
		elif [ `expr match "$item" '-clean'` != 0 ];then
			CONFIG_OPTION=unconfigure
		elif [ `expr match "$item" '-was_admin_user'` != 0 ];then
			was_admin_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
			was_admin_password=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-was_admin_group'` != 0 ];then
			was_admin_group=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-was_runas_user'` != 0 ];then
			was_runas_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-was_runas_password'` != 0 ];then
		was_runas_password=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-was_runas_group'` != 0 ];then
			was_runas_group=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-MQ_USER_PASSWORD'` != 0 ];then
			MQ_USER_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-MQ_USER_NAME'` != 0 ];then
			MQ_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_ADMIN_USER'` != 0 ];then
			DBMS_ADMIN_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_ADMIN_PASSWORD'` != 0 ];then
			DBMS_ADMIN_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-new_member_name'` != 0 ];then
			new_member_name=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-new_member_node'` != 0 ];then
			new_member_node=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-RESULT='` != 0 ];then
			RESULT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		else
			usage
			exit 1
		fi
	done
fi

#XXX bundle

if [ -z "$CONFIG_OPTION" ]; then
	CONFIG_OPTION=configure
    getMessage RFID05028I
    $ECHO $msg
	#XXX uncomment later
	#    connectDB
else
	getMessage RFID05069I
    $ECHO $msg
fi

MEMBERONLY='false'
if [ ! -z "$new_member_name" ];then
    if [ -z "$new_member_node" ];then
    	getMessage TSIN02253E
    	$ECHO $msg
		#echo "The name for the new cluster member is missing"
		exit 1
    fi
	
    if [ -z "$CLUSTERNAME" ];then
    	getMessage TSIN02254E
    	$ECHO $msg
		#echo "The cluster name for new cluster member is missing"
		exit 1
    fi
	
    if [ $CONFIG_OPTION = "unconfigure" ]; then
    	getMessage TSIN02255E
    	$ECHO $msg
		#echo "The name for the new cluster member is invalid for unconfigure"
		exit 1
    fi
    SERVERNAME=$new_member_name
    NODENAME=$new_member_node
    MEMBERONLY='true'
fi

#this is run in tsEnv.sh when we source it
#getActualWASConfig

if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
    getMessage RFID05030I "$was_admin_user"
    $ECHO $msg
    stty -echo
	read was_admin_password
	stty echo
	echo
fi

if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
    credentials="-user $was_admin_user -password $was_admin_password"
fi

# If the runas user isn't set and the admin user is, then the admin user will be the runas user.
if [ -z "$was_runas_user" ];then
    if [ -n "$TS_ADMIN_USER" ];then
        was_runas_user=$TS_ADMIN_USER
    fi
    
    if [ -n "$TS_ADMIN_GROUP" ];then
        was_runas_group=$TS_ADMIN_GROUP
    fi
    
    if [ -n "$TS_ADMIN_PASSWORD" ];then
        was_runas_password=$TS_ADMIN_PASSWORD
    fi
fi

if [ "$CURRENT_USER" = "root" -a "$CONFIG_OPTION" = "configure" -a -n "$was_runas_user" ];then

	###if was_runas_user does not exist, create the user and group
	getMessage TSIN02256I
	$ECHO $msg
	#echo "Setting up the WebSphere Application Server run as user"

	OS=`/bin/uname`
	CREATEGROUP="groupadd"
	was_runas_user_home=/home/${was_runas_user}
	case $PLATFORM in
		SunOS)
			was_runas_user_home=/export/home/${was_runas_user}
			;;
		AIX)
			CREATEGROUP="mkgroup"
			;;
	esac

	WAS_RUNAS_USER_EXIST=`cat /etc/passwd | grep ^$was_runas_user | ${AWK_COLON} '{print($1)}'` 
	if [ -z "$WAS_RUNAS_USER_EXIST" -o "$WAS_RUNAS_USER_EXIST" != "$was_runas_user" ];then
		getMessage TSIN02257I
		$ECHO $msg
		#echo "Creating the WebSphere Application Server run as user and group"
		$CREATEGROUP $was_runas_group
		if [ "$PLATFORM" = "Linux" ];then
			useradd -d $was_runas_user_home -m -p `openssl passwd $was_runas_password` -g $was_runas_group $was_runas_user
		elif [ "$PLATFORM" = "AIX" ];then
			useradd -d $was_runas_user_home -m -g $was_runas_group $was_runas_user
			`echo "$was_runas_user:$was_runas_password" | /bin/chpasswd -c`
		elif [ "$PLATFORM" = "SunOS" ];then
			useradd -d $was_runas_user_home -m -g $was_runas_group $was_runas_user
			#update password command here if available
		fi
		run_command mkdir -p ${was_runas_user_home}
	fi
	
	run_command chown -hR ${TS_ADMIN_USER}:${TS_ADMIN_GROUP} ${WAS_PROFILE_HOME}
	addGroupToUser $TS_ADMIN_GROUP $was_runas_user
	
	#now change group permissions and ownership
	
	run_command chgrp ${was_runas_group} ${WAS_HOME}/..
	run_command chgrp ${was_runas_group} ${WAS_HOME}
	run_command chgrp -R ${was_runas_group} ${WAS_HOME}/profiles
	run_command chgrp -R ${was_runas_group} ${WAS_PROFILE_HOME}
	run_command chgrp -R ${was_runas_group} ${WAS_HOME}/logs
	run_command chgrp -R ${was_runas_group} ${WAS_HOME}/properties
	run_command chgrp -R ${was_runas_group} ${WAS_HOME}/temp
	# Varies on the WAS version and edition
	if [ -d "${WAS_HOME}/cloudscape" ];then
		chgrp -R ${was_runas_group} ${WAS_HOME}/cloudscape
		chmod -R g+wr ${WAS_HOME}/cloudscape
	fi
	if [ -d "${WAS_HOME}/derby" ];then
		chgrp -R ${was_runas_group} ${WAS_HOME}/derby
		chmod -R g+wr ${WAS_HOME}/derby
	fi
	run_command chgrp -R ${was_runas_group} ${WAS_HOME}/bin
	run_command chgrp -R ${was_runas_group} ${WAS_HOME}/java
	run_command chgrp -R ${was_runas_group} ${WAS_HOME}/lib
	# Varies on the WAS version and edition
	if [ -d "${WAS_HOME}/installedChannels" ];then
		chgrp -R ${was_runas_group} ${WAS_HOME}/installedChannels
		chmod -R g+rw ${WAS_HOME}/installedChannels
	fi
	if [ -d "${WAS_HOME}/installedConnectors" ];then
		chgrp -R ${was_runas_group} ${WAS_HOME}/installedConnectors
		chmod -R g+rw ${WAS_HOME}/installedConnectors
	fi
	run_command chgrp -R ${was_runas_group} ${WAS_PROFILE_HOME}/installedFilters
	run_command chgrp -R ${was_runas_group} ${WAS_HOME}/etc/
	# Varies on the WAS version and edition
	if [ -d ${WAS_HOME}/classes ];then
		chgrp -R ${was_runas_group} ${WAS_HOME}/classes
		chmod -R g+rw ${WAS_HOME}/classes
	fi
	run_command chgrp -R ${was_runas_group} ${WAS_HOME}/systemApps
	
	run_command chmod g+wr ${WAS_HOME}/..
	run_command chmod g+wr ${WAS_HOME}
	run_command chmod -R g+wr ${WAS_HOME}/profiles
	run_command chmod -R g+rw ${WAS_PROFILE_HOME}
    run_command find ${WAS_PROFILE_HOME} -type d | sed 's/./\\&/g' | xargs chmod ug+x
	run_command chmod -R g+wr ${WAS_HOME}/logs
	run_command chmod -R g+wr ${WAS_HOME}/properties
	run_command chmod -R g+wr ${WAS_HOME}/temp
	run_command chmod -R g+r ${WAS_HOME}/bin
	run_command chmod -R g+r ${WAS_HOME}/java
    run_command find ${WAS_HOME}/java -type f | sed 's/./\\&/g' | xargs chmod g+x
	run_command chmod -R g+r ${WAS_HOME}/lib
	run_command chmod -R g+rw ${WAS_PROFILE_HOME}/installedFilters
	run_command chmod -R g+rw ${WAS_HOME}/etc/
	run_command chmod -R g+rw ${WAS_HOME}/systemApps
	
	getMessage TSIN02258I
	$ECHO $msg
	#echo "Updated WebSphere Application Server run as user profile"
	###end creating profile
fi

if [ "$DB_TYPE" = "ORACLE" ];then
	# Determine the Oracle Version
    getDBVersion
    if [ `echo $returnString | ${AWK} '{print($1)}'` = "11" ];then
		oraVersion="11g"
    else
		oraVersion="10g"
    fi
fi

startWAS

RFIDIC_FILE_STORE=${TS_HOME}/MEDATA
if [ ! -d "${RFIDIC_FILE_STORE}" ]; then
    mkdir ${RFIDIC_FILE_STORE}
fi
run_command chown -hR ${TS_ADMIN_USER}:${TS_ADMIN_GROUP} ${RFIDIC_FILE_STORE}

# Clear the OSGI cache
cd $WAS_HOME/deploytool/scripts/install
./ejbdeploy-clear-cache.sh
cd -

RFIDIC_PROPS_FILE=/tmp/cfgProps.$$
writeProperties

if [ -f ${TS_HOME}/MQScripts/cluster.properties ];then
	run_command ${WAS_PROFILE_HOME}/bin/wsadmin.sh $credentials -lang jython -wsadmin_classpath ${WSADMIN_JARS_PATH} -f ${RFIDIC_INSTALL_HOME}/bin/jython/configDriverPhase1.py ${RFIDIC_PROPS_FILE} ${TS_HOME}/bin/jython ${TS_HOME}/MQScripts/cluster.properties
else
	run_command ${WAS_PROFILE_HOME}/bin/wsadmin.sh $credentials -lang jython -wsadmin_classpath ${WSADMIN_JARS_PATH} -f ${RFIDIC_INSTALL_HOME}/bin/jython/configDriverPhase1.py ${RFIDIC_PROPS_FILE} ${TS_HOME}/bin/jython
fi
retCode=$?

if [ "$retCode" != "0" ];then
	exit $retCode
fi

#In the stand alone case, restart the app server
#In the ND case, configDriver takes care of restarting the members
#No need to restart during an unconfigure
if [ -z "$CLUSTERNAME" ];then
    if [ "$CONFIG_OPTION" == "configure" ];then
		stopWAS
		startWAS
    fi
fi

#/bin/rm -rf ${RFIDIC_FILE_STORE}/*

if [ "$MEMBERONLY" = "false" ];then
    run_command ${WAS_PROFILE_HOME}/bin/wsadmin.sh $credentials -lang jython -wsadmin_classpath ${WSADMIN_JARS_PATH} -f ${RFIDIC_INSTALL_HOME}/bin/jython/configDriverPhase2.py ${RFIDIC_PROPS_FILE} ${TS_HOME}/bin/jython
	retCode=$?
	
	if [ "$retCode" != "0" ];then
		exit $retCode
	fi
fi

#In the stand alone case, restart the app server
#In the ND case, configDriver takes care of restarting the members
if [ -z "$CLUSTERNAME" ];then
    stopWAS
    startWAS
fi

# Change permissmions on the profile again due to the bus being created by the root user. 
if [ "$CURRENT_USER" = "root" -a "$CONFIG_OPTION" = "configure" ];then
    run_command chown -hR ${TS_ADMIN_USER}:${TS_ADMIN_GROUP} ${WAS_PROFILE_HOME}
fi

/bin/rm -f ${RFIDIC_PROPS_FILE}

. $SCRIPT_DIR/updateEnv.sh -CONFIG_TYPE=WAS -WAS_HOME=$WAS_HOME -WAS_PROFILE=$WAS_PROFILE -WAS_PORT_NO=$WAS_PORT_NO -SERVERNAME=$SERVERNAME -NODENAME=$NODENAME -CELLNAME=$CELLNAME -CLUSTERNAME=$CLUSTERNAME -was_admin_user=$was_admin_user -was_admin_group=$was_admin_group -was_runas_user=$was_runas_user -was_runas_group=$was_runas_group -RESULT=$RESULT -RFIDIC_FILE_STORE=$RFIDIC_FILE_STORE
retCode=$?

if [ $retCode -eq 0 ];then
	echo "SUCCESS"
	if [ ! -z "$RESULT" ];then
		$ECHO "SUCCESS" >> $RESULT
	fi
fi

exit $retCode
