#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
#
# 
# createUserProfile.sh - creates user profile for IBM InfoSphere Traceability Server 3.0.0.0
###############################################################################################################

sDir=`dirname ${0}`
scriptDir=`cd $sDir && pwd`
. $scriptDir/utils.sh
TS_HOME=$sDir/..
if [ -f $scriptDir/tsEnv.sh ];then
	TS_HOME=$scriptDir/..
fi

ECHO="echo"
AWK_COLON="awk -F ":""

ID=`id`
CURRENT_USER=`expr "$ID" : ".*uid=[0-9]*(\([^)]*\)*"`
CURRENT_GROUP=`expr "$ID" : ".*gid=[0-9]*(\([^)]*\)*"`
set_perm_only=$FALSE

case $PLATFORM in
	Linux)
		ECHO="echo -e"
		CREATEGROUP="groupadd"
		TS_HOME=`echo "$TS_HOME" | awk '{print substr($TS_HOME, 1, length($TS_HOME)-7)}'`			
		;;
	AIX)
		CREATEGROUP="mkgroup"
		TS_HOME=`echo ${TS_HOME} | awk -v Flag=$TS_HOME '{print substr(Flag, 1, length(Flag)-7)}'`
		;;
	SunOS)
		CREATEGROUP="groupadd"
		AWK_COLON="awk -F:"
		TS_HOME=`echo "$TS_HOME" | awk '{print substr($TS_HOME, 1, length($TS_HOME)-7)}'`
		;;
esac

usage(){
	echo "	USAGE: ./createUserProfile.sh"
	echo "                          [-TS_ADMIN_USER=<TS user>]"
	echo "                          [-TS_ADMIN_PASSWORD=<TS password>]"
	echo "                          [-TS_ADMIN_GROUP=<TS group>]"
	echo "                          [-SET_PERMISSIONS_ONLY] only set permissions, do not create profile"
	echo "                          [-RESULT=<Result of the script>]"
	return 1
}

changeOwnership(){
	
	# Change ownership of files
	getMessage TSIN01108I
	echo $msg
	#echo "Setting file permissions"
	
	run_command mkdir -p ${TS_HOME}/logs
    
	run_command touch ${TS_HOME}/logs/default.log
	run_command touch ${TS_HOME}/logs/TSLog.0

	run_command chown ${TS_ADMIN_USER}:${TS_ADMIN_GROUP} ${TS_HOME}
	
	run_command chown -hR ${TS_ADMIN_USER}:${TS_ADMIN_GROUP} ${TS_HOME}
	run_command chown -hR ${TS_ADMIN_USER}:${TS_ADMIN_GROUP} ${TS_HOME}/../installableApps/com.ibm.ts.web.ear
	run_command chown -hR ${TS_ADMIN_USER}:${TS_ADMIN_GROUP} ${TS_HOME}/../installableApps/com.ibm.ts.web.ui.ear
	run_command chown -hR ${TS_ADMIN_USER}:${TS_ADMIN_GROUP} ${TS_HOME}/../installableApps/com.ibm.rfidic.web.enterprise.serialid.ear
	run_command chown -hR ${TS_ADMIN_USER}:${TS_ADMIN_GROUP} ${TS_HOME}/../installableApps/ibm-application-ext-pme.xmi
	run_command chown -hR ${TS_ADMIN_USER}:${TS_ADMIN_GROUP} ${TS_HOME}/../configuration/org.eclipse.osgi	

	# Set permissions
	run_command chmod -R 755 ${TS_HOME}

	run_command find ${TS_HOME} -type f | sed 's/./\\&/g' | xargs chmod 444

	run_command chmod 750 ${TS_HOME}/bin/tsEnv.sh
	run_command chmod 644 ${TS_HOME}/bin/configureTS.properties

	run_command chmod 644 ${TS_HOME}/etc/*.xml
	run_command chmod 640 ${TS_HOME}/etc/RFIDICServer.xml

	run_command find ${TS_HOME}/logs -type f | sed 's/./\\&/g' | xargs chmod 644
	run_command find ${TS_HOME}/MEDATA -type f | sed 's/./\\&/g' | xargs chmod 644
	run_command find ${TS_HOME}/tsar -type f | sed 's/./\\&/g' | xargs chmod 644

	run_command find ${TS_HOME} -name "*.sh" | sed 's/./\\&/g' | xargs chmod 755

	run_command chmod 755 ${TS_HOME}/../installableApps/com.ibm.ts.web.ear
	run_command chmod 755 ${TS_HOME}/../installableApps/com.ibm.ts.web.ui.ear
	run_command chmod 755 ${TS_HOME}/../installableApps/com.ibm.rfidic.web.enterprise.serialid.ear
	run_command chmod 755 ${TS_HOME}/../installableApps/ibm-application-ext-pme.xmi
	
	getMessage TSIN02261I
	echo $msg
	#echo $file permissions set
}

asciiUpdate()
{
    # Takes an array of search and replace strings for a file, constructs the sed script and performs the update on the file
    index=0
    searchStr=$2
    replaceStr=$3
    count=${#searchStr[*]}
    command="{\n"
    while [ "$index" -lt "$count" ]
    do
        command=$command"s%"${searchStr[$index]}"%"${replaceStr[$index]}"%g\n"
        index=`expr $index + 1`
    done
    command=$command"}"
    $ECHO $command > $1.sed
    run_command sed -f $1.sed $1 > $1.tmp
    sedReturnCode=$?

    if [ $? -eq 0 ];then
        run_command mv -f $1.tmp $1
    else
        rm -f $1.tmp
    fi

    run_command rm -f $1.sed
    unset searchStr
    unset replaceStr

    return $sedReturnCode
}

if [ "$CURRENT_USER" = "root" ];then
	for item in $@
	do
		if [ `expr match "$item" '-TS_ADMIN_USER='` != 0 ];then
	             	TS_ADMIN_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-TS_ADMIN_PASSWORD='` != 0 ];then
                     TS_ADMIN_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-TS_ADMIN_GROUP='` != 0 ];then
                     TS_ADMIN_GROUP=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
       		elif [ `expr match "$item" '-SET_PERMISSIONS_ONLY'` != 0 ];then
                     set_perm_only=$TRUE
		elif [ `expr match "$item" '-RESULT='` != 0 ];then
	       	         RESULT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		else
			usage
			exit 1
		fi
	done

	if [ "$set_perm_only" = "$TRUE" ];then
		. $sDir/tsEnv.sh
	fi

    TS_ADMIN_USER_EXIST=`cat /etc/passwd | grep ^$TS_ADMIN_USER | ${AWK_COLON} '{print($1)}'` 
    if [ -n "$TS_ADMIN_USER_EXIST" ];then
        TS_ADMIN_USER_HOME=`cat /etc/passwd | grep ^$TS_ADMIN_USER | ${AWK_COLON} '{print $6}'`
    else
        TS_ADMIN_USER_HOME=/home/${TS_ADMIN_USER}
        case $PLATFORM in
            SunOS)
                TS_ADMIN_USER_HOME=/export/home/${TS_ADMIN_USER}
            ;;
        esac
    fi

	echo "TS_ADMIN_USER: $TS_ADMIN_USER"
	echo "TS_ADMIN_GROUP: $TS_ADMIN_GROUP"
	echo "TS_HOME: $TS_HOME"
	echo "TS_ADMIN_USER_HOME: $TS_ADMIN_USER_HOME"

	if [ "$set_perm_only" = "$FALSE" ];then
        #Create the group if it doesn't exist
        grep $TS_ADMIN_GROUP: /etc/group > /dev/null 2>&1
        if [ $? -ne 0 ];then
            $CREATEGROUP $TS_ADMIN_GROUP
        fi

	    if [ -z "$TS_ADMIN_USER_EXIST" -o "$TS_ADMIN_USER_EXIST" != "$TS_ADMIN_USER" ];then
		    getMessage TSIN02262I
		    echo $msg
		    #echo "The system is creating the InfoSphere Traceability Server administrative user ID and group"
		
		    if [ "$PLATFORM" = "Linux" ];then
 			    useradd -d $TS_ADMIN_USER_HOME -m -p `openssl passwd $TS_ADMIN_PASSWORD` -g $TS_ADMIN_GROUP $TS_ADMIN_USER
		    elif [ "$PLATFORM" = "AIX" ];then
			    useradd -d $TS_ADMIN_USER_HOME -m -g $TS_ADMIN_GROUP $TS_ADMIN_USER
			    `echo "$TS_ADMIN_USER:$TS_ADMIN_PASSWORD" | /bin/chpasswd -c`
		    elif [ "$PLATFORM" = "SunOS" ];then
			    useradd -d $TS_ADMIN_USER_HOME -m -g $TS_ADMIN_GROUP $TS_ADMIN_USER
			    #update password command here if available
		    fi
		    run_command mkdir -p ${TS_ADMIN_USER_HOME}
	    fi
    
	    # Create a .profile for the TS user and udpate it
	
        TS_PROFILE=".profile"
	    TS_SHELL=`cat /etc/passwd | grep ^$TS_ADMIN_USER | ${AWK_COLON} '{print($7)}'`
        if [ "$TS_SHELL" = "/bin/bash" ];then
            if [ -e "$TS_ADMIN_USER_HOME/.bash_profile" ];then
                TS_PROFILE=".bash_profile"
            fi
        fi

	    run_command touch ${TS_ADMIN_USER_HOME}/${TS_PROFILE}
	    run_command chown -hR ${TS_ADMIN_USER}:${TS_ADMIN_GROUP} ${TS_ADMIN_USER_HOME}

	    TS_HOME_ISSET=`cat ${TS_ADMIN_USER_HOME}/${TS_PROFILE} | grep "TS_HOME"`
	    if [ -z "$TS_HOME_ISSET" ];then
		    echo ". ${TS_HOME}/bin/tsEnv.sh" >> ${TS_ADMIN_USER_HOME}/${TS_PROFILE}
		    echo "export TS_HOME" >> ${TS_ADMIN_USER_HOME}/${TS_PROFILE}
	    fi

	    getMessage TSIN02263I
	    echo $msg
	    #echo "updating tsEnv.sh file"
	
	    searchStr[0]='TS_ADMIN_USER=.*'
	    searchStr[1]='TS_ADMIN_GROUP=.*'
	    searchStr[2]='TS_HOME=.*'

	    replaceStr[0]="TS_ADMIN_USER=$TS_ADMIN_USER"
	    replaceStr[1]="TS_ADMIN_GROUP=$TS_ADMIN_GROUP"
	    replaceStr[2]="TS_HOME=$TS_HOME"

	    asciiUpdate "${TS_HOME}/bin/tsEnv.sh" $searchStr $replaceStr
	
	fi

    grep '^'$TS_ADMIN_GROUP':' /etc/group > /dev/null 2>&1
    if [ $? -ne 0 ];then
        getMessage TSIN02276E $TS_ADMIN_GROUP
        echo $msg
        exit 1
    fi
	
	#change ownership of directories
	run_command chown ${TS_ADMIN_USER}:${TS_ADMIN_GROUP} ${TS_HOME}/bin/tsEnv.sh
	run_command chmod 750 ${TS_HOME}/bin/tsEnv.sh
	changeOwnership


else  # run from IM as non root......called with no arguments so use current user credentials and create profile for current user

	for item in $@
       do
        if [ `expr match "$item" '-SET_PERMISSIONS_ONLY'` != 0 ];then
                    set_perm_only=$TRUE
		elif [ `expr match "$item" '-RESULT='` != 0 ];then
	             	RESULT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		else
			usage
			exit 1
		fi
	done

	TS_ADMIN_USER=$CURRENT_USER
	TS_ADMIN_GROUP=$CURRENT_GROUP

    TS_ADMIN_USER_HOME=`cat /etc/passwd | grep ^$TS_ADMIN_USER | ${AWK_COLON} '{print $6}'`
	TS_PROFILE=".profile"
	TS_SHELL=`cat /etc/passwd | grep ^$TS_ADMIN_USER | ${AWK_COLON} '{print($7)}'`
    if [ "$TS_SHELL" = "/bin/bash" ];then
        TS_PROFILE=".bash_profile"
    fi

	echo "TS_ADMIN_USER: $TS_ADMIN_USER"
	echo "TS_ADMIN_GROUP: $TS_ADMIN_GROUP"
	echo "TS_HOME: $TS_HOME"
	echo "TS_ADMIN_USER_HOME: $TS_ADMIN_USER_HOME"
	echo "SET_PERMISSIONS_TRUE: $set_perm_only"

	if [ "$set_perm_only" = "$FALSE" ];then
	    TS_HOME_ISSET=`cat ${TS_ADMIN_USER_HOME}/${TS_PROFILE} | grep "TS_HOME"`
	    if [ -z "$TS_HOME_ISSET" ];then
		    echo ". ${TS_HOME}/bin/tsEnv.sh" >> ${TS_ADMIN_USER_HOME}/${TS_PROFILE}
		    echo "export TS_HOME" >> ${TS_ADMIN_USER_HOME}/${TS_PROFILE}
	    fi

	    getMessage TSIN02263I
	    echo $msg
	    #echo "updating tsEnv.sh file"
	
	    searchStr[0]='TS_ADMIN_USER=.*'
	    searchStr[1]='TS_ADMIN_GROUP=.*'
	    searchStr[2]='TS_HOME=.*'

	    replaceStr[0]="TS_ADMIN_USER=$TS_ADMIN_USER"
	    replaceStr[1]="TS_ADMIN_GROUP=$TS_ADMIN_GROUP"
	    replaceStr[2]="TS_HOME=$TS_HOME"

	    asciiUpdate "${TS_HOME}/bin/tsEnv.sh" $searchStr $replaceStr
	fi
	
	#change ownership of directories
	run_command chown ${TS_ADMIN_USER}:${TS_ADMIN_GROUP} ${TS_HOME}/bin/tsEnv.sh
	run_command chmod 750 ${TS_HOME}/bin/tsEnv.sh
	changeOwnership

fi

retCode=$?
if [ $retCode -eq 0 ];then	
	echo "SUCCESS"
	if [ ! -z "$RESULT" ];then
		$ECHO "SUCCESS" >> $RESULT
	fi
fi
exit 0
