#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
import sys
from com.ibm.rfidic.messages.tools import RFIDICGetMessage

#Add TS jython scripts to jython's import path
def updatePath(p):
    sys.path.append(p)

updatePath(sys.argv[1])

#Now that the rfidic jython directory is on the path, import our modules
import rfidicCfgUtils
import createSchedTables
import resetVariables
import recreateDatasource
import recreateMQQCF
import recreateMQQ
import createTopicConfig
import recreateListener
import recreateWMQAS
import recreateObjectCache
import setLibrary
import reinstallApplication
import recreateAuditConfig
import recreateScheduler
import updateWSClientBindings
import addUsrOrGrpToSecurityRole
import setWebServicesBindings

properties=rfidicCfgUtils.getProperties(sys.argv[0])
servers=rfidicCfgUtils.findServers(properties)

#In the single server case the shell script already started the app server
if( properties.get("ISCLUSTER")=='true' ):
    rfidicCfgUtils.startServers(servers)

if( properties.get("MEMBERONLY")=='false' ):
    # If we're cleaning the configuration, the updateBindings need to be 
    # run before the applications are removed.
    if( properties.get("CONFIG_OPTION")!='configure' ):
        setWebServicesBindings.updateBindings( properties )
    
    reinstallApplication.run( properties, 'CPAPP_LOCATION', 'CPAPP_NAME' )
    reinstallApplication.run( properties, 'UIAPP_LOCATION', 'UIAPP_NAME' )
    reinstallApplication.run( properties, 'SIDAPP_LOCATION', 'SIDAPP_NAME' )

    #XXX fix jdbc jndi names
    dsJndi='jdbc/ts/schedulerDS'
    recreateScheduler.run( properties, 'RFIDICStandingQueryScheduler',
                           dsJndi, '10', 'RFIDIC_',
                           'RFIDICWorkManager', 'wm/rfidic/standing' )
    recreateScheduler.run( properties, 'MDMCacheRefreshScheduler',
                           dsJndi, '10', 'MDMRFIDIC_',
                           'MDMCacheRefreshWM', 'wm/MDMCacheRefresh' )
    recreateScheduler.run( properties, 'SerialIdScheduler',
                           dsJndi, '10', 'SERIALID_',
                           'SerialIdWorkManager', 'wm/Serialid' )

    # If we're configuring, the updateBindings need to be 
    # run after the applications are installed.
    if( properties.get("CONFIG_OPTION")=='configure' ):
        setWebServicesBindings.updateBindings( properties )
    
print "Saving..."
AdminConfig.save()

if( properties.get("ISCLUSTER")=='true' ):
    rfidicCfgUtils.syncNodes(servers)
    
if( properties.get("MEMBERONLY")=='false' ):
    if( properties.get("CONFIG_OPTION")=='configure'):
        createSchedTables.run(properties, servers, 'RFIDICStandingQueryScheduler')
        createSchedTables.run(properties, servers, 'MDMCacheRefreshScheduler')
        createSchedTables.run(properties, servers, 'SerialIdScheduler')

#In the single server case, the shell script recycles the server
#No need to restart here for an unconfigure
if( properties.get("CONFIG_OPTION")!='unconfigure'):
    if( properties.get("ISCLUSTER")=='true' ):
        rfidicCfgUtils.syncNodes(servers)
        rfidicCfgUtils.stopServers(servers)
        rfidicCfgUtils.startServers(servers)
