#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
from com.ibm.rfidic.messages.tools import RFIDICGetMessage
import AdminUtilities

def getServerId( p, server ):
    sid=AdminConfig.getid('/Cell:'+p.get("CELLNAME")+'/Node:'+server[0]+'/Server:'+server[1])
    return sid

#get the scope
def getScope(p):
    cell=p.get("CELLNAME")
    if(p.get("ISCLUSTER")=="true"):
        ret='/Cell:'+cell+'/ServerCluster:'+p.get("CLUSTERNAME")+'/'
    else:
        ret='/Cell:'+cell+'/Node:'+p.get("NODENAME")+'/Server:'+p.get("SERVERNAME")+'/'

    return ret

def createMQTopic( p, topicName, topicJndi ):
    scope=getScope(p)
    scopeObj=AdminConfig.getid(scope)
    args=['-name '+topicName+' -jndiName '+topicJndi+' -topicName '+topicJndi]
    AdminTask.createWMQTopic( scopeObj, args )
    #XXX bundle
    print 'Create MQ Topic with JNDI: '+topicJndi

def getArgs( p, server, tcfJndi, tcfName, tcfDesc ):
    args=[]
    args=args+['-name', tcfName]
    args=args+['-jndiName', tcfJndi]
    args=args+['-type', 'TCF']
    args=args+['-description', tcfDesc]
    args=args+['-qmgrName', server[2][1]]
    args=args+['-qmgrHostname', server[2][0]]
    args=args+['-qmgrPortNumber', server[2][2]]
    args=args+['-wmqTransportType', 'CLIENT']
    args=args+['-brokerCtrlQueue', 'SYSTEM.BROKER.CONTROL.QUEUE']
    args=args+['-brokerQmgr', server[2][1]]
    args=args+['-brokerPubQueue', 'SYSTEM.BROKER.DEFAULT.STREAM']
    args=args+['-brokerVersion', 'MA0C']
    args=args+['-subStore', 'MIGRATE']
    args=args+['-msgSelection',  'CLIENT']
    args=args+['-support2PCProtocol', 'true']
    
    return args

def createMQTopicCFOnServer( p, server, tcfJndi, tcfName, tcfDesc ):
    #XXX - bundle
    print "Creating new MQ Topic Connection Factory with JNDI: "+tcfJndi
    
    sid=getServerId(p, server)
    args=getArgs(p, server, tcfJndi, tcfName, tcfDesc)
    AdminTask.createWMQConnectionFactory( sid, args )

    #XXX - bundle
    print "Created MQ Topic Connection Factory with JNDI: "+tcfJndi

def createMQTopicCF( p, servers, tcfJndi, tcfName, tcfDesc ):
    for server in servers:
        createMQTopicCFOnServer( p, server, tcfJndi, tcfName, tcfDesc )

def removeMQTCFOnServer( p, server, tcfJndi ):
    #XXX - bundle
    print "Attempting to remove MQ Topic Connection factory with JNDI: "+tcfJndi
    sid=getServerId(p, server)
    tcfObjs=AdminConfig.list('MQTopicConnectionFactory', sid)
    tcfList=AdminUtilities.convertToList(tcfObjs)
    for tcf in tcfList:
        jndi=AdminConfig.showAttribute( tcf, "jndiName" )
        if( jndi==tcfJndi ):
            AdminTask.deleteWMQConnectionFactory(tcf)
            #XXX - bundle
            print 'Removed MQ Topic Connection Factory with JNDI: '+tcfJndi
            return

def removeMQTCF( p, servers, tcfJndi ):
    for server in servers:
        removeMQTCFOnServer( p, server, tcfJndi )

def removeTopic( p, topicJndi ):
    #XXX - bundle 
    print "Attempting to remove Topic with JNDI: "+topicJndi
    scope=getScope(p)
    scopeObj=AdminConfig.getid(scope)
    tObjs=AdminConfig.list('MQTopic', scopeObj)
    tList=AdminUtilities.convertToList(tObjs)
    for t in tList:
        jndi=AdminConfig.showAttribute( t, "jndiName" )
        if( jndi==topicJndi ):
            AdminTask.deleteWMQTopic(t)
            #XXX - bundle
            print "Removed MQ Topic with JNDI: "+topicJndi
            return

def run( p, servers, tcfJndi, tcfName, tcfDesc, topicName, topicJndi ):
    removeTopic( p, topicJndi )
    removeMQTCF( p, servers, tcfJndi )

    if( p.get("CONFIG_OPTION")=="configure" ):
        createMQTopicCF( p, servers, tcfJndi, tcfName, tcfDesc )
        createMQTopic( p, topicName, topicJndi )
