#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
from com.ibm.rfidic.messages.tools import RFIDICGetMessage
import AdminUtilities
import os

#get the scope
def getScope(p):
    cell=p.get("CELLNAME")
    if(p.get("ISCLUSTER")=="true"):
        ret='/Cell:'+cell+'/ServerCluster:'+p.get("CLUSTERNAME")+'/'
    else:
        ret='/Cell:'+cell+'/Node:'+p.get("NODENAME")+'/Server:'+p.get("SERVERNAME")+'/'

    return ret

def removeSIBus(p, bName):
    msg=RFIDICGetMessage.getMessage('RFID07124I', bName)
    print msg.getMessage()

    bus=AdminConfig.getid('/SIBus:'+bName)
    if( bus != '' ):
        stopMes(p, bName)
        AdminTask.deleteSIBus('[-bus '+bName+']')
        
        msg=RFIDICGetMessage.getMessage('RFID07125I', bName)
        print msg.getMessage()

    storeDir=p.get("RFIDIC_FILE_STORE")
    if( storeDir != None and storeDir != '' ):
        os.system('/bin/rm -rf '+storeDir+'/*')

def createBus(p, bName):
    desc=RFIDICGetMessage.getMessage('RFID07154I')
    args=['-bus', bName, '-description', desc.getMessage(), '-secure', 'false']
    
    msg=RFIDICGetMessage.getMessage('RFID07132I', bName)
    print msg.getMessage()

    AdminTask.createSIBus(args)

    msg=RFIDICGetMessage.getMessage('RFID07133I', bName)
    print msg.getMessage()

def getGenericArgs(p, bName):
    args=['-bus', bName]
    if( p.get("ISCLUSTER")=='true' ):
        args=args+[ '-cluster', p.get("CLUSTERNAME") ]
    else:
        args=args+[ '-node', p.get("NODENAME") ]
        args=args+[ '-server', p.get("SERVERNAME") ]

    return args

def getMemberArgs(p, bName):
    args=getGenericArgs(p, bName)
    args=args+[ '-fileStore' ]
    args=args+[ '-logDirectory', '${RFIDIC_FILE_STORE}' ]
    args=args+[ '-permanentStoreDirectory', '${RFIDIC_FILE_STORE}' ]
    args=args+[ '-temporaryStoreDirectory', '${RFIDIC_FILE_STORE}' ]

    return args

def addMember(p, bName):
    msg=RFIDICGetMessage.getMessage('RFID07134I', bName, p.get('RFIDIC_FILE_STORE'))
    print msg.getMessage()

    args=getMemberArgs(p, bName)
    AdminTask.addSIBusMember(args)

    msg=RFIDICGetMessage.getMessage('RFID07135I', bName)
    print msg.getMessage()

def getTopicSpaceArgs(p, bName, tsName):
    args=getGenericArgs(p, bName)
    args=args+['-type', 'TopicSpace']
    args=args+['-name', tsName]
    args=args+['-maintainStrictMessageOrder', 'true']

    return args

def createTopicSpace(p, bName, tsName):
    msg=RFIDICGetMessage.getMessage('RFID07136I', tsName, bName)
    print msg.getMessage()

    args=getTopicSpaceArgs(p, bName, tsName)
    AdminTask.createSIBDestination(args)

    msg=RFIDICGetMessage.getMessage('RFID07137I', tsName)
    print msg.getMessage()

def removeJMSConnFactory(p, cfName):
    msg=RFIDICGetMessage.getMessage('RFID07130I', cfName)
    print msg.getMessage()

    scope=getScope(p)
    scopeObj=AdminConfig.getid(scope)

    cfs=AdminConfig.list( 'J2CConnectionFactory', scopeObj )
#    cfs=AdminTask.listSIBJMSConnectionFactories(scopeObj)
    cfList=AdminUtilities.convertToList( cfs )

    for cf in cfList:
        name=AdminConfig.showAttribute(cf, 'name')
        if( name==cfName ):
            AdminConfig.remove(cf)

            msg=RFIDICGetMessage.getMessage('RFID07131I', name)
            print msg.getMessage()

            
def getJMSCFArgs(p, bName, cfName, cfJndi):
    args=['-type', 'topic']
    args=args+['-busName', bName]
    args=args+['-name', cfName]
    args=args+['-jndiName', cfJndi]

    return args

def createJMSConnFactory(p, bName, cfName, cfJndi):
    msg=RFIDICGetMessage.getMessage('RFID07138I', cfName, cfJndi, bName)
    print msg.getMessage()

    scope=getScope(p)
    scopeObj=AdminConfig.getid(scope)
    args=getJMSCFArgs(p, bName, cfName, cfJndi)
    AdminTask.createSIBJMSConnectionFactory(scopeObj, args)

    msg=RFIDICGetMessage.getMessage('RFID07139I', cfName)
    print msg.getMessage()

def removeJMSQ(p, qName):
    msg=RFIDICGetMessage.getMessage('RFID07140I', qName)
    print msg.getMessage()

    scope=getScope(p)
    scopeObj=AdminConfig.getid(scope)

    qs=AdminTask.listSIBJMSQueues(scopeObj)
    qList=AdminUtilities.convertToList( qs )

    for q in qList:
        name=AdminConfig.showAttribute(q, 'name')
        if( name==qName ):
            AdminConfig.remove(q)

            msg=RFIDICGetMessage.getMessage('RFID07141I', name)
            print msg.getMessage()
    
def removeJMSTopic(p, topicName):
    msg=RFIDICGetMessage.getMessage('RFID07178I', topicName)
    print msg.getMessage()

    scope=getScope(p)
    scopeObj=AdminConfig.getid(scope)

    topicString=AdminTask.listSIBJMSTopics(scopeObj)
    topicList=AdminUtilities.convertToList( topicString )

    for topic in topicList:
        name=AdminConfig.showAttribute(topic, 'name')
        if( name==topicName ):
            AdminConfig.remove(topic)

            msg=RFIDICGetMessage.getMessage('RFID07179I', name)
            print msg.getMessage()
    
def getJMSTopicArgs(p, bName, topicName, topicJndi, topicSpaceName):
    args=['-name', topicName]
    args=args+['-topicSpace', topicSpaceName]
    args=args+['-topicName', topicName]
    args=args+['-jndiName', topicJndi]
    args=args+['-deliveryMode', 'Persistent']
    args=args+['-busName', bName]

    return args

def createJMSTopic(p, bName, topicName, topicJndi, topicSpaceName):
    msg=RFIDICGetMessage.getMessage('RFID07176I', topicName, topicJndi)
    print msg.getMessage()

    scope=getScope(p)
    scopeObj=AdminConfig.getid(scope)
    args=getJMSTopicArgs(p, bName, topicName, topicJndi, topicSpaceName)
    AdminTask.createSIBJMSTopic( scopeObj, args )
    
    msg=RFIDICGetMessage.getMessage('RFID07177I', topicName)
    print msg.getMessage()

def removeActSpec(p, asName):
    msg=RFIDICGetMessage.getMessage('RFID07142I', asName)
    print msg.getMessage()

    scope=getScope(p)
    scopeObj=AdminConfig.getid(scope)

    as=AdminConfig.list( 'J2CActivationSpec', scopeObj )
    asList=AdminUtilities.convertToList( as )

    for a in asList:
        name=AdminConfig.showAttribute(a, 'name')
        if( name==asName ):
            AdminConfig.remove(a)

            msg=RFIDICGetMessage.getMessage('RFID07155I', name)
            print msg.getMessage()

def getASArgs(p, bName, asName, asJndi, topicJndi):
    args=['-name', asName]
    args=args+['-jndiName', asJndi]
    args=args+['-destinationJndiName', topicJndi]
    args=args+['-destinationType', 'Topic']
    args=args+['-busName', bName]

    return args

def createActSpec(p, bName, asName, asJndi, topicJndi):
    msg=RFIDICGetMessage.getMessage('RFID07145I', asName, asJndi, topicJndi)
    print msg.getMessage()

    scope=getScope(p)
    scopeObj=AdminConfig.getid(scope)
    args=getASArgs(p, bName, asName, asJndi, topicJndi)
    AdminTask.createSIBJMSActivationSpec(scopeObj, args)
    
    msg=RFIDICGetMessage.getMessage('RFID07146I', asName)
    print msg.getMessage()

def stopMes(p, bName):
    mes=AdminTask.listSIBEngines( ['-bus', bName] )
    meList=AdminUtilities.convertToList(mes)
    for me in meList:
        meName=AdminConfig.showAttribute(me, 'name')
        mbeanStr='WebSphere:*,type=SIBMessagingEngine,name='+meName
        beans=AdminControl.queryNames(mbeanStr)
        if( beans != '' ):
            beanList=AdminUtilities.convertToList(beans)
            for bean in beanList:
                state=AdminControl.invoke(bean, 'state')
                if( state=='Started' or state=='Starting' ):
                    msg=RFIDICGetMessage.getMessage('RFID07143I',bName,bean)
                    print msg.getMessage()
                    AdminControl.invoke(bean, 'stop', 'FORCE')

def run(p):
    bName=p.get("RFIDIC_BUS_NAME")
    cfName='TSAuditTopicCF'
    cfJndi='jms/ibm/ts/audit/topicCF'
    alertASName='TSAlertActivationSpec'
    alertASJndi='jms/ibm/ts/alert/audit/activation'
    auditSampleASName='TSAuditSampleActivation'
    auditSampleASJndi='jms/ibm/ts/audit/sample/activation'
    topicSpaceName='TSAuditTopicSpace'
    topicName='TSAuditTopic'
    topicJndi='jms/ibm/ts/audit/topic'
    oldQName='RFIDICAuditQueue'
    oldCFName='RFIDICAuditQueueCF'
    oldASName='RFIDICAuditActivationSpec'

    removeSIBus(p, bName)
    removeJMSConnFactory(p, oldCFName)
    removeJMSConnFactory(p, cfName)
    removeJMSQ(p, oldQName)
    removeJMSTopic(p, topicName)
    removeActSpec(p, oldASName)
    removeActSpec(p, alertASName)
    removeActSpec(p, auditSampleASName)
    
    if( p.get("CONFIG_OPTION")=="configure" ):
        createBus(p, bName)
        addMember(p, bName)
        createTopicSpace(p, bName, topicSpaceName)
        createJMSConnFactory(p, bName, cfName, cfJndi)
        createJMSTopic(p, bName, topicName, topicJndi, topicSpaceName)
        createActSpec(p, bName, alertASName, alertASJndi, topicJndi)
        createActSpec(p, bName, auditSampleASName, auditSampleASJndi, topicJndi)
                      
