#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
from com.ibm.rfidic.messages.tools import RFIDICGetMessage
import AdminUtilities

def getServerId( p, server ):
    sid=AdminConfig.getid('/Cell:'+p.get("CELLNAME")+'/Node:'+server[0]+'/Server:'+server[1])
    return sid

def removeAliasForServer(server, MQAlias):
    msg=RFIDICGetMessage.getMessage('RFID07114I', MQAlias)
    print msg.getMessage()
    
    authEntries=AdminConfig.list('JAASAuthData')
    authEntryList=AdminUtilities.convertToList(authEntries)
    for authEntry in authEntryList:
        thisName=AdminConfig.showAttribute(authEntry, "alias")
        if( thisName.startswith(MQAlias) ):
            msg=RFIDICGetMessage.getMessage('RFID07115I', thisName)
            print msg.getMessage()
            AdminConfig.remove(authEntry)
            return
        
    msg=RFIDICGetMessage.getMessage('RFID07116I', MQAlias)
    print msg.getMessage()

#remove the auth alias
def removeAlias(servers, MQAlias):
    for server in servers:
        removeAliasForServer( server, MQAlias )

def createAliasForServer(p, server, MQAlias):
    uName=server[2][4]
    uPass=server[2][5]
    msg=RFIDICGetMessage.getMessage('RFID07067I', MQAlias)
    print msg.getMessage()
    cell = AdminConfig.list("Cell")
    cellName = AdminConfig.showAttribute(cell, "name")
    sec = AdminConfig.getid("/Cell:"+cellName+"/Security:/")
    attrs = [["alias", MQAlias], ["userId", uName], ["password", uPass],
             ["description", "MQ connection factory alias"]]
    AdminConfig.create( "JAASAuthData", sec, attrs )
    msg=RFIDICGetMessage.getMessage('RFID07068I', MQAlias)
    print msg.getMessage()

#create the auth alias
def createAlias(p, servers, MQAlias):
    mqCluster=p.get("MQ_CLUSTER")
    if ( mqCluster==None or mqCluster=="" ):
        createAliasForServer( p, servers[0], MQAlias )
    else:
        for server in servers:
            serverMQAlias=MQAlias+'_'+server[2][0]
            createAliasForServer( p, server, serverMQAlias )

#build the arguments
def getArgs(p, server, QCFname, QCFdesc, QCFjndi, MQAlias, xa):
    args=[]
    args=args+['-name', QCFname]
    args=args+['-jndiName', QCFjndi]
    args=args+['-type', 'QCF']
    args=args+['-description', QCFdesc]
    if( p.get("USE_MQ_CCDT")=='true' ):
        args=args+['-ccdtUrl', p.get('MQ_CCDT_URL')]
        args=args+['-ccdtQmgrName', p.get('MQ_CCDT_QM')]
    else:
        args=args+['-qmgrName', server[2][1]]
        args=args+['-qmgrHostname', server[2][0]]
        args=args+['-qmgrPortNumber', server[2][2]]
        args=args+['-wmqTransportType', 'CLIENT']
    args=args+['-containerAuthAlias', MQAlias]
    args=args+['-support2PCProtocol', xa]

    return args

#get the scope
def getScope(p):
    cell=p.get("CELLNAME")
    if(p.get("ISCLUSTER")=="true"):
        ret='/Cell:'+cell+'/ServerCluster:'+p.get("CLUSTERNAME")+'/'
    else:
        ret='/Cell:'+cell+'/Node:'+p.get("NODENAME")+'/Server:'+p.get("SERVERNAME")+'/'

    return ret

#create the qcf
def createMQQCFOnServer( p, server, QCFname, QCFdesc, QCFjndi, MQAlias, xa ):
    msg=RFIDICGetMessage.getMessage('RFID07121I', QCFjndi)
    print msg.getMessage()
    
    sid=getServerId(p, server)
    args=getArgs( p, server, QCFname, QCFdesc, QCFjndi, MQAlias, xa )
    AdminTask.createWMQConnectionFactory( sid, args )

    msg=RFIDICGetMessage.getMessage('RFID07123I', QCFjndi)
    print msg.getMessage()
    
def createMQQCF( p, servers, QCFname, QCFdesc, QCFjndi, MQAlias, xa ):
    mqCluster=p.get("MQ_CLUSTER")
    for server in servers:
        if ( mqCluster==None or mqCluster=="" ):
            serverMQAlias=MQAlias
        else:
            serverMQAlias=MQAlias+'_'+server[2][0]
        createMQQCFOnServer( p, server, QCFname, QCFdesc, QCFjndi, serverMQAlias, xa )
    
#remove the qcf
def removeMQQCFOnServer( p, server, QCFjndi ):
    msg=RFIDICGetMessage.getMessage('RFID07119I', QCFjndi)
    print msg.getMessage()

    sid=getServerId(p, server)
    qcfObjs=AdminConfig.list('MQQueueConnectionFactory', sid)
    qcfList=AdminUtilities.convertToList(qcfObjs)
    for qcf in qcfList:
        jndi=AdminConfig.showAttribute(qcf, "jndiName")
        if( QCFjndi==jndi ):
            AdminTask.deleteWMQConnectionFactory(qcf)
            msg=RFIDICGetMessage.getMessage('RFID07120I', QCFjndi)
            print msg.getMessage()
            return

def removeMQQCF( p, servers, QCFjndi ):
    for server in servers:
        removeMQQCFOnServer( p, server, QCFjndi )
            
def run(p, servers, doAlias, MQAlias, QCFname, QCFdesc, QCFjndi, xa):
    removeMQQCF( p, servers, QCFjndi )
    if( doAlias == 'true' ):
        removeAlias(servers, MQAlias)

    if( p.get("CONFIG_OPTION")=="configure" ):
        if( doAlias == 'true' ):
            createAlias(p, servers, MQAlias)
        createMQQCF( p, servers, QCFname, QCFdesc, QCFjndi, MQAlias, xa )
