#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
from com.ibm.rfidic.messages.tools import RFIDICGetMessage
import AdminUtilities

def getServerId( p, server ):
    sid=AdminConfig.getid('/Cell:'+p.get("CELLNAME")+'/Node:'+server[0]+'/Server:'+server[1])
    return sid

def removeAliasForServer(server, MQAlias):
    msg=RFIDICGetMessage.getMessage('RFID07114I', MQAlias)
    print msg.getMessage()
    
    authEntries=AdminConfig.list('JAASAuthData')
    authEntryList=AdminUtilities.convertToList(authEntries)
    for authEntry in authEntryList:
        thisName=AdminConfig.showAttribute(authEntry, "alias")
        if( thisName.startswith(MQAlias) ):
            msg=RFIDICGetMessage.getMessage('RFID07115I', thisName)
            print msg.getMessage()
            AdminConfig.remove(authEntry)
            return
        
    msg=RFIDICGetMessage.getMessage('RFID07116I', MQAlias)
    print msg.getMessage()

#remove the auth alias
def removeAlias(servers, MQAlias):
    for server in servers:
        removeAliasForServer( server, MQAlias )

def createAliasForServer(p, server, MQAlias):
    uName=server[2][4]
    uPass=server[2][5]
    msg=RFIDICGetMessage.getMessage('RFID07067I', MQAlias)
    print msg.getMessage()
    cell = AdminConfig.list("Cell")
    cellName = AdminConfig.showAttribute(cell, "name")
    sec = AdminConfig.getid("/Cell:"+cellName+"/Security:/")
    attrs = [["alias", MQAlias], ["userId", uName], ["password", uPass],
             ["description", "MQ activation spec alias"]]
    AdminConfig.create( "JAASAuthData", sec, attrs )
    msg=RFIDICGetMessage.getMessage('RFID07068I', MQAlias)
    print msg.getMessage()

#create the auth alias
def createAlias(p, servers, MQAlias):
    mqCluster=p.get("MQ_CLUSTER")
    if ( mqCluster==None or mqCluster=="" ):
        createAliasForServer( p, servers[0], MQAlias )
    else:
        for server in servers:
            serverMQAlias=MQAlias+'_'+server[2][0]
            createAliasForServer( p, server, serverMQAlias )

#get the scope
def getScope(p, server):
    cell=p.get("CELLNAME")
    if(p.get("ISCLUSTER")=="true"):
        ret='/Cell:'+cell+'/ServerCluster:'+p.get("CLUSTERNAME")+'/'
    else:
        ret='/Cell:'+cell+'/Node:'+p.get("NODENAME")+'/Server:'+p.get("SERVERNAME")+'/'

    return ret

def removeWMQASOnServer( p, server, specName ):
    msg=RFIDICGetMessage.getMessage('RFID07142I', specName)
    print msg.getMessage()
    
    sid=getServerId(p, server)
    actSpecs=AdminConfig.list('J2CActivationSpec', sid)
    specList=AdminUtilities.convertToList(actSpecs)
    for spec in specList:
        name=AdminConfig.showAttribute( spec, 'name' )
        if( name==specName ):
            AdminTask.deleteWMQActivationSpec( spec )

            msg=RFIDICGetMessage.getMessage('RFID07155I', name)
            print msg.getMessage()

#remove the activation spec
def removeWMQAS( p, servers, specName ):
    for server in servers:
        removeWMQASOnServer( p, server, specName )

#get the arguments for spec creation
def getArgs( p, server, specName, specDesc, specJndi, destJndi, authAlias ):
    args=[]
    args=args+['-name', specName]
    args=args+['-jndiName', specJndi]
    args=args+['-destinationJndiName', destJndi]
    args=args+['-destinationType', 'javax.jms.Queue']
    if( p.get('USE_MQ_CCDT')=='true' ):
        args=args+['-ccdtUrl', p.get('MQ_CCDT_URL')]
        args=args+['-ccdtQmgrName', p.get('MQ_CCDT_QM')]
    else:
        args=args+['-qmgrName', server[2][1]]
        args=args+['-qmgrHostname', server[2][0]]
        args=args+['-qmgrPortNumber', server[2][2]]
        args=args+['-wmqTransportType', 'CLIENT']
    args=args+['-authAlias', authAlias]
    args=args+['-failureDeliveryCount', 10]
    args=args+['-customProperties', '[[WAS_EndpointInitialState INACTIVE]]']
    return args

def createWMQASOnServer( p, server, specName, specDesc, specJndi, destJndi, authAlias ):
    msg=RFIDICGetMessage.getMessage('RFID07145I', specName, specJndi, destJndi)
    print msg.getMessage()
    
    sid=getServerId(p, server)
    args=getArgs( p, server, specName, specDesc, specJndi, destJndi, authAlias )
    AdminTask.createWMQActivationSpec( sid, args )

    msg=RFIDICGetMessage.getMessage('RFID07146I', specName)
    print msg.getMessage()
    

#create the activation spec
def createWMQAS( p, servers, specName, specDesc, specJndi, destJndi, authAlias ):
    mqCluster=p.get("MQ_CLUSTER")
    for server in servers:
        if ( mqCluster==None or mqCluster=="" ):
            serverAuthAlias=authAlias
        else:
            serverAuthAlias=authAlias+'_'+server[2][0]
        createWMQASOnServer( p, server, specName, specDesc, specJndi, destJndi, serverAuthAlias )

def run( p, servers, doAlias, authAlias, specName, specDesc, specJndi, destJndi ):
    if( doAlias=='true' ):
        removeAlias(servers, authAlias)
    removeWMQAS( p, servers, specName )
    
    if( p.get("CONFIG_OPTION")=="configure" ):
        if( doAlias=='true' ):
            createAlias(p, servers, authAlias)
        createWMQAS( p, servers, specName, specDesc, specJndi, destJndi, authAlias )    
