#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
## Removes and then creates the work manager required for automatic capture retry.
## This work manager is not associated with any scheduler, therefore it's not created in recreateScheduler.py.
##############################################################################################################
from com.ibm.rfidic.messages.tools import RFIDICGetMessage
import AdminUtilities

def getScope(p):
    cell=p.get("CELLNAME")
    if(p.get("ISCLUSTER")=="true"):
        ret='/Cell:'+cell+'/ServerCluster:'+p.get("CLUSTERNAME")+'/'
    else:
        ret='/Cell:'+cell+'/Node:'+p.get("NODENAME")+'/Server:'+p.get("SERVERNAME")+'/'

    return ret

def getWmAttrs( wmName, wmJndi ):
    attrs=[]
    attrs=attrs+[ ['isGrowable', 'true'] ]
    attrs=attrs+[ ['jndiName', wmJndi] ]
    attrs=attrs+[ ['maxThreads', '10'] ]
    attrs=attrs+[ ['minThreads', '0'] ]
    attrs=attrs+[ ['name', wmName] ]
    attrs=attrs+[ ['numAlarmThreads', 10] ]
    attrs=attrs+[ ['serviceNames', 'security'] ]
    attrs=attrs+[ ['threadPriority', '5'] ]

    return attrs

def removeWorkManager(p, wmName):

    scope=getScope(p)
    wmScope=scope+'WorkManagerProvider:WorkManagerProvider/WorkManagerInfo:'+wmName+'/'

    wrkMgr=AdminConfig.getid(wmScope)

    if( wrkMgr!='' ):
        AdminConfig.remove(wrkMgr)
        msg=RFIDICGetMessage.getMessage('RFID07089I', wmName)
        print msg.getMessage()
    else:
        msg=RFIDICGetMessage.getMessage('RFID07088I', wmName)
        print msg.getMessage()
        
def createWorkManager(p, workManagerName, workManagerJndi):

    scope=getScope(p)
    wmScope=scope+'WorkManagerProvider:WorkManagerProvider/'

    wmProv=AdminConfig.getid(wmScope)

    if( wmProv=='' ):
        msg=RFIDICGetMessage.getMessage('RFID07044I', wmScope)
        print msg.getMessage()

    msg=RFIDICGetMessage.getMessage('RFID07091I')
    print msg.getMessage()

    wmAttrs=getWmAttrs(workManagerName, workManagerJndi)

    msg=RFIDICGetMessage.getMessage('RFID07092I')
    print msg.getMessage()

    wmInfo=AdminConfig.create('WorkManagerInfo', wmProv, wmAttrs)

    msg=RFIDICGetMessage.getMessage('RFID07093I')
    print msg.getMessage()


def run(p, wmName, wmJndi):
    
    removeWorkManager(p, wmName)

    if( p.get("CONFIG_OPTION")=="configure" ):
        createWorkManager(p, wmName, wmJndi)
    
