#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
import sys
import AdminUtilities
from java.io import FileInputStream
from java.util import Properties
from com.ibm.rfidic.messages.tools import RFIDICGetMessage

#Sync the nodes
def syncNodes(servers):
    for server in servers:
        #XXX - bundle
        print "Syncing node: "+server[0]
        nodeStr='type=NodeSync,node='+server[0]+',*'
        syncBean=AdminControl.completeObjectName(nodeStr)
        AdminControl.invoke(syncBean, 'sync')

#Stop the servers
def stopServers(servers):
    for server in servers:
        serverStr="WebSphere:name="+server[1]+",type=Server,node="+server[0]+",processType=ManagedProcess,*"
        runningServer = AdminControl.queryNames(serverStr)
        if( runningServer == '' ):
            print 'Server '+server[1]+' on node '+server[0]+' already stopped.'
        else:
            print 'Stopping '+server[1]+' on node '+server[0]
            AdminControl.stopServer( server[1], server[0] )

def startServers(servers):
    for server in servers:
        nodeagent = AdminControl.queryNames("type=NodeAgent,node="+server[0]+",*")
        if( nodeagent == '' ):
            print "Cannot find node agent on node "+server[0]
        else:
            runningServer = AdminControl.queryNames("type=Server,node="+server[0]+",name="+server[1]+",*")
            if( runningServer == '' ):
                print 'Starting '+server[1]+' on node '+server[0]
                AdminControl.startServer( server[1], server [0] )
            else:
                print 'Server '+server[1]+' on node '+server[0]+' already started.'



#Load the properties file that was passed as the first arg
def getProperties(f):
    fis=FileInputStream(f)
    p=Properties()
    p.load(fis)
    
    cname=p.get("CLUSTERNAME")
    if(cname==None or cname==""):
        p.put("ISCLUSTER", "false")
    else:
        p.put("ISCLUSTER", "true")

    if(AdminTask.isGlobalSecurityEnabled()=="true"):
        appSec=AdminTask.isAppSecurityEnabled()
        p.put("SECURITY_ON", appSec)
    else:
        p.put("SECURITY_ON", 'false')
        
    ccdt=p.get('MQ_CCDT_URL')
    if(ccdt==None or ccdt==""):
        p.put("USE_MQ_CCDT", 'false')
    else:
        p.put("USE_MQ_CCDT", 'true')
    return p

#Return a list of [nodeName, serverName] pairs
#In the single server case, the list has one member
#If we're just initializing a new cluster member, only return it
def findServers(p):
    if(p.get("ISCLUSTER")=="false" or p.get("MEMBERONLY")=='true'):
        ret=[ [p.get("NODENAME"), p.get("SERVERNAME")] ]
        servid=AdminConfig.getid('/Cell:'+p.get("CELLNAME")+'/Node:'+ret[0][0]+'/Server:'+ret[0][1]+'/')
        if( servid=='' ):
            msg=RFIDICGetMessage.getMessage('RFID07075I', cJndi)
            print msg.getMessage()
            exit(1)
        return ret
    else:
        ret=[]
        cluster=AdminConfig.getid("/ServerCluster:"+p.get("CLUSTERNAME"))
        if( cluster=='' ):
            #XXX - bundle
            print 'Cluster id null - returning'
            exit(1)
        mems=AdminConfig.showAttribute(cluster, "members")
        mList=AdminUtilities.convertToList(mems)
        for mem in mList:
            s=AdminConfig.showAttribute(mem, "memberName")
            n=AdminConfig.showAttribute(mem, "nodeName")
            ret.append([n,s])
        return ret

def getQueueManagersFromProperties(p):
    ret=[]
    c=1
    while (1):
        mqHost=p.get("MQ_HOST_"+str(c))
        if ( mqHost==None or mqHost=="" ):
            break
        mqQMgr=p.get("QUEUE_MANAGER_"+str(c))
        mqPort=p.get("MQ_LSR_PORT_"+str(c))
        mqHome=p.get("MQ_HOME_"+str(c))
        mqUser=p.get("MQ_USER_"+str(c))
        mqPass=p.get("MQ_USER_PASSWORD_"+str(c))
        ret.append([mqHost,mqQMgr,mqPort,mqHome,mqUser,mqPass])
        c+=1
    
    return ret

