#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
if( __name__=='__main__'):
    sys.path.append(sys.argv[1])
    import rfidicCfgUtils
    properties=rfidicCfgUtils.getProperties(sys.argv[0])

import sys
import os
import string
import AdminUtilities
import addUsrOrGrpToSecurityRole
import updateWSClientBindings
import java.lang
from java.io import FileInputStream
from java.util import Properties
from jarray import array
from com.ibm.rfidic.utils.install import ReadMappedUserGroups

def addUserToSecurityRole( properties, appName, user, role ):
    muStr=AdminApp.view( appName, ['-MapRolesToUsers'] )
    muFileName='/tmp/WebEARMappedUsers'
    muFile=open(muFileName, 'w')
    muFile.write(muStr)
    muFile.close()
    
    jyArr=[muFileName, role, user ]
    javaArr=array(jyArr, java.lang.String)
    ReadMappedUserGroups.main(javaArr)
    muFile=open(muFileName, 'r')
    newMuStr=muFile.read()
    muFile.close()
    os.remove(muFileName)
    
    addUsrOrGrpToSecurityRole.run( properties, newMuStr, appName, role, 'user' )

def deleteServerBinding( bindingName ):
    print "Looking for binding "+bindingName
    types=["application", "client"]

    for type in types:
        bindings=AdminTask.getBinding('[-bindingLocation ]')
        pos=string.find(bindings, bindingName)
        if pos > -1:
            print "Found "+bindingName+" binding. Removing binding."
            AdminTask.setBinding('[-bindingLocation -attachmentType '+type+' -remove true -bindingName '+bindingName+']')

def deleteApplicationBinding( bindingName, appName ):
    print "Looking for binding "+bindingName
    bindings=AdminTask.getBinding('-bindingLocation [[application '+appName+'] [attachmentId *]]')
    pos=string.find(bindings, bindingName)
    if pos > -1:
        print "Found "+bindingName+" binding. Removing binding." 
        AdminTask.setBinding('[-bindingLocation [[application '+appName+'] [attachmentId *]] -remove true -bindingName '+bindingName+']')


def deletePolicySet( policyName ):
    policies=AdminTask.listPolicySets()
    policyList=AdminUtilities.convertToList(policies)
    print "Looking for policy "+policyName
    for policy in policyList:
        if ( policy == policyName ):
            print "Found "+policyName+" policy set. Removing policy set."
            AdminTask.deleteAttachmentsForPolicySet('[-policySet '+policyName+']')
            AdminTask.deletePolicySet('[-policySet '+policyName+']')

def createProviderPolicySet( policyName, policyDescription ):
    print "Creating policy set "+policyName
    AdminTask.createPolicySet('[-policySet '+policyName+' -description ['+policyDescription+']]')
    AdminTask.addPolicyType('[-policySet '+policyName+' -policyType SSLTransport]')
    AdminTask.addPolicyType('[-policySet '+policyName+' -policyType HTTPTransport]')
    AdminTask.addPolicyType('[-policySet '+policyName+' -policyType WSSecurity]')

    ltpaTokenName="TS-Token-LTPA"
    userNameTokenName="TS-Token-UserName"
    AdminTask.setPolicyType('[-policySet '+policyName+' -policyType WSSecurity -attributes [ [enabled true] [type WSSecurity] [Wss11.RequireSignatureConfirmation false] [SupportingTokens.request:'+ltpaTokenName+'.LTPAToken.IncludeToken http://docs.oasis-open.org/ws-sx/ws-securitypolicy/200512/IncludeToken/Always] [SupportingTokens.request:'+userNameTokenName+'.UsernameToken.IncludeToken http://docs.oasis-open.org/ws-sx/ws-securitypolicy/200512/IncludeToken/Always] [description [Policies for sending security tokens and providing message confidentiality and integrity, based on the OASIS Web Service Security and Token Profiles specifications.]] [SupportingTokens.request:'+userNameTokenName+'.UsernameToken.WssUsernameToken10 true] ] -replace true]')


def createProviderBinding( bindingName, appName, attachmentID, wsCSsl ):
    bindings=AdminTask.getBinding('-bindingLocation [[application '+appName+'] [attachmentId *]]')
    pos=string.find(bindings, bindingName)
    #If the binding doesn't exist, then create it. Creating it will also assign the binding. Otherwise, just assign the one that already exists.
    if pos < 0:
        AdminTask.setBinding('[-policyType SSLTransport -attachmentType application -attributes [ [outAsyncResponsewithSSL:configAlias '+wsCSsl+'] ] -bindingName '+bindingName+' -bindingLocation [ [application '+appName+'] [attachmentId '+attachmentID+'] ]]')

        tokenName="TS-Token-UserName"
        print "Setting token "+tokenName
        AdminTask.setBinding('[-policyType WSSecurity -attachmentType application -attributes [ [application.securityinboundbindingconfig.tokenconsumer_999.valuetype.localname http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-username-token-profile-1.0#UsernameToken] [application.securityinboundbindingconfig.tokenconsumer_999.jaasconfig.configname system.wss.consume.unt] [application.securityinboundbindingconfig.tokenconsumer_999.name request:'+tokenName+'] [application.securityinboundbindingconfig.tokenconsumer_999.classname com.ibm.ws.wssecurity.wssapi.token.impl.CommonTokenConsumer] [application.securityinboundbindingconfig.tokenconsumer_999.enforcetokenversion false] [application.securityinboundbindingconfig.tokenconsumer_999.securitytokenreference.reference request:'+tokenName+'] [application.securityinboundbindingconfig.tokenconsumer_999.callbackhandler.classname com.ibm.websphere.wssecurity.callbackhandler.UNTConsumeCallbackHandler] ] -bindingName '+bindingName+' -bindingLocation [ [application '+appName+'] [attachmentId '+attachmentID+']]')

        tokenName="TS-Token-LTPA"
        print "Setting token "+tokenName
        AdminTask.setBinding('[-policyType WSSecurity -attachmentType application -attributes [ [application.securityinboundbindingconfig.tokenconsumer_999.valuetype.uri http://www.ibm.com/websphere/appserver/tokentype] [application.securityinboundbindingconfig.tokenconsumer_999.valuetype.localname LTPAv2] [application.securityinboundbindingconfig.tokenconsumer_999.jaasconfig.configname system.wss.consume.ltpa] [application.securityinboundbindingconfig.tokenconsumer_999.name request:'+tokenName+'] [application.securityinboundbindingconfig.tokenconsumer_999.classname com.ibm.ws.wssecurity.wssapi.token.impl.CommonTokenConsumer] [application.securityinboundbindingconfig.tokenconsumer_999.securitytokenreference.reference request:'+tokenName+'] [application.securityinboundbindingconfig.tokenconsumer_999.callbackhandler.classname com.ibm.websphere.wssecurity.callbackhandler.LTPAConsumeCallbackHandler] ] -bindingName '+bindingName+' -bindingLocation [ [application '+appName+'] [attachmentId '+attachmentID+'] ]]')
 
        print "Checking for existing callers"
        #If callers exist, use them.
        callers=AdminTask.getBinding('[-policyType WSSecurity -bindingLocation [ [application '+appName+'] [attachmentId '+attachmentID+'] ] -bindingName TS-Provider-Binding -attachmentType application -attributes [application.securityinboundbindingconfig.caller ]]')
        print "Creating callers"
        callerName="TS-Caller-LTPA"
        pos=string.find(callers, callerName)
        if pos < 0:
            print "Creating caller "+callerName
            AdminTask.setBinding('[-policyType WSSecurity -attachmentType application -attributes [ [application.securityinboundbindingconfig.caller_999.calleridentity.uri http://www.ibm.com/websphere/appserver/tokentype] [application.securityinboundbindingconfig.caller_999.name '+callerName+'] [application.name application] [application.securityinboundbindingconfig.caller_999.order 1] [application.securityinboundbindingconfig.caller_999.calleridentity.localname LTPAv2] [application.securityinboundbindingconfig.caller_999.jaasconfig.configname system.wss.caller] ] -bindingName '+bindingName+' -bindingLocation [ [application '+appName+'] [attachmentId '+attachmentID+'] ]]')

        callerName="TS-Caller-UserName"
        pos=string.find(callers, callerName)
        if pos < 0:
            print "Creating caller "+callerName
            AdminTask.setBinding('[-policyType WSSecurity -attachmentType application -attributes [ [application.securityinboundbindingconfig.caller_999.name '+callerName+'] [application.name application] [application.securityinboundbindingconfig.caller_999.order 2] [application.securityinboundbindingconfig.caller_999.calleridentity.localname http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-username-token-profile-1.0#UsernameToken] [application.securityinboundbindingconfig.caller_999.jaasconfig.configname system.wss.caller] ] -bindingName '+bindingName+' -bindingLocation [ [application '+appName+'] [attachmentId '+attachmentID+'] ]]')

    else:
        AdminTask.setBinding('[-bindingName '+bindingName+' -attachmentType application -bindingLocation [ [application '+appName+'] [attachmentId '+attachmentID+'] ]]')


def createProviderPolicySetAttachment( webService, appName, policyName, bindingName, wsCSsl ):
    print "Creating provider policy set attachment for "+webService 
    attachmentID=AdminTask.createPolicySetAttachment('[-applicationName '+appName+' -attachmentType application -policySet '+policyName+' -resources [WebService:/'+webService+' ]]')
    createProviderBinding(bindingName, appName, attachmentID, wsCSsl)


def createClientPolicySet( policyName, policyDescription ):
    print "Creating policy set "+policyName
    AdminTask.createPolicySet('[-policySet '+policyName+' -description ['+policyDescription+']]')
    AdminTask.addPolicyType('[-policySet '+policyName+' -policyType SSLTransport]')
    AdminTask.addPolicyType('[-policySet '+policyName+' -policyType HTTPTransport]')
    AdminTask.addPolicyType('[-policySet '+policyName+' -policyType WSSecurity]')

    ltpaTokenName="TS-Token-LTPA"
    AdminTask.setPolicyType('[-policySet '+policyName+' -policyType WSSecurity -attributes [ [enabled true] [type WSSecurity] [SupportingTokens.request:'+ltpaTokenName+'.LTPAToken.IncludeToken http://docs.oasis-open.org/ws-sx/ws-securitypolicy/200512/IncludeToken/Always] [description [Policies for sending security tokens and providing message confidentiality and integrity, based on the OASIS Web Service Security and Token Profiles specifications.]] [Wss11.RequireSignatureConfirmation false] ] -replace true]')


def createClientPolicySetAttachment( webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl ):
    if (wsCUser=='' or wsCPwd==''):
        print "Unable to configure client binding without the web services user ID and password."
        return
        
    print "Creating client policy set attachment for "+webService 
    attachmentID=AdminTask.createPolicySetAttachment('[-applicationName '+appName+' -attachmentType client -policySet '+policyName+' -resources [WebService:/'+webService+' ]]')

    AdminTask.setBinding('[-policyType HTTPTransport -attachmentType client -attributes [ [outRequestBasicAuth:userid '+wsCUser+'] [outRequestBasicAuth:password '+wsCPwd+'] ] -bindingName '+bindingName+'  -bindingLocation [ [application '+appName+'] [attachmentId '+attachmentID+'] ]]')

    AdminTask.setBinding('[-policyType SSLTransport -attachmentType client -attributes [ [inResponsewithSSL:configAlias '+wsCSsl+'] [outRequestwithSSL:configAlias '+wsCSsl+'] ] -bindingName '+bindingName+' -bindingLocation [ [application '+appName+'] [attachmentId '+attachmentID+'] ]]')

    tokenName="TS-Token-LTPA"
    AdminTask.setBinding('[-policyType WSSecurity -attachmentType client -attributes [ [application.securityoutboundbindingconfig.tokengenerator_999.securitytokenreference.reference request:'+tokenName+'] [application.securityoutboundbindingconfig.tokengenerator_999.name request:'+tokenName+'] [application.securityoutboundbindingconfig.tokengenerator_999.valuetype.uri http://www.ibm.com/websphere/appserver/tokentype] [application.securityoutboundbindingconfig.tokengenerator_999.classname com.ibm.ws.wssecurity.wssapi.token.impl.CommonTokenGenerator] [application.securityoutboundbindingconfig.tokengenerator_999.callbackhandler.classname com.ibm.websphere.wssecurity.callbackhandler.LTPAGenerateCallbackHandler] [application.securityoutboundbindingconfig.tokengenerator_999.jaasconfig.configname system.wss.generate.ltpa] [application.securityoutboundbindingconfig.tokengenerator_999.valuetype.localname LTPAv2] ] -bindingName '+bindingName+' -bindingLocation [ [application '+appName+'] [attachmentId '+attachmentID+'] ]]')



def updateBindings( properties ):
    wsEpUrlPref='://'+properties.get("WS_EP_IP")+':'+properties.get("WS_EP_PORT")
    epOnly='false'
    if( properties.get("CONFIG_OPTION")=='configure' ):
        if( properties.get("SECURITY_ON")=='true' ):
            addUserToSecurityRole( properties, properties.get("CPAPP_NAME"), properties.get("WS_UI_USER"), 'EPCISQuery' )
            addUserToSecurityRole( properties, properties.get("CPAPP_NAME"), properties.get("WS_UI_USER"), 'NamedAnswerQuery' )
            addUserToSecurityRole( properties, properties.get("CPAPP_NAME"), properties.get("WS_UI_USER"), 'AlertsRegistry' )
            addUserToSecurityRole( properties, properties.get("CPAPP_NAME"), properties.get("WS_UI_USER"), 'HttpCapture' )
            addUserToSecurityRole( properties, properties.get("CPAPP_NAME"), properties.get("WS_UI_USER"), 'SecurityRegistry' )
            addUserToSecurityRole( properties, properties.get("CPAPP_NAME"), properties.get("WS_UI_USER"), 'FailedEventManager' )
            addUserToSecurityRole( properties, properties.get("CPAPP_NAME"), properties.get("WS_UI_USER"), 'ContainmentService' )
            addUserToSecurityRole( properties, properties.get("CPAPP_NAME"), properties.get("WS_UI_USER"), 'TrackAndTraceService' )
            addUserToSecurityRole( properties, properties.get("CPAPP_NAME"), properties.get("WS_UI_USER"), 'MasterDataServices' )
            addUserToSecurityRole( properties, properties.get("UIAPP_NAME"), properties.get("WS_UI_USER"), 'Administrator' )
            addUserToSecurityRole( properties, properties.get("SIDAPP_NAME"), properties.get("WS_UI_USER"), 'Serial ID Admin' )
            addUserToSecurityRole( properties, properties.get("SIDAPP_NAME"), properties.get("WS_UI_USER"), 'Serial ID Requester' )
            wsEpUrlPref='https'+wsEpUrlPref
        else:
            wsEpUrlPref='http'+wsEpUrlPref
            epOnly='true'

        wsCUser=properties.get("WS_UI_USER") or ''
        wsCSsl=properties.get("WS_UI_SSL") or ''
        wsCPwd=properties.get("WS_UI_PWD") or ''

    #Remove old policy set from 3.0.0.0
    deletePolicySet("TS-WSHTTPS")
  
    #Configure provider policies and bindings
    appName=properties.get("CPAPP_NAME")

    #Create policies and bindings 
    policyName="TS-Provider-Policy-Set"
    policyDescription="Traceability Server provider policy set."
    bindingName="TS-Provider-Binding"
    bindingDescription="Traceability Server provider bindings."
    deletePolicySet(policyName)
    deleteApplicationBinding(bindingName, appName) 
    deletePolicySet("TS-Policy-Provider")
    deleteApplicationBinding("TS-Binding-Provider", appName) 

    if( properties.get("CONFIG_OPTION")=='configure' ):
        if( properties.get("SECURITY_ON")=='true' ):
            createProviderPolicySet(policyName, policyDescription)

        if( properties.get("SECURITY_ON")=='true' ):
            #Web service client ports for engine.war
            appModule='com.ibm.ts.engine.web.war'
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/xmlns/prod/ts/alerts_management/alertsregistry/}AlertsRegistryService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/xmlns/prod/ts/tnt/query/containment/}ContainmentService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/xmlns/prod/ts/alerts_management/deliverymethodsregistry/}DeliveryMethodsRegistryService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{urn:epcglobal:epcis:wsdl:1}EPCglobalEPCISService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/xmlns/prod/ts/fem}FailedEventManagerService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/xmlns/prod/ts/mdm/}MasterDataManagerService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/xmlns/prod/ts/alerts_management/notificationconfigurationsregistry/}NotificationConfigurationsRegistryService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/xmlns/prod/ts/alerts_management/subscriptionsregistry/}SubscriptionsRegistryService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/xmlns/prod/ts/tsqm}TSQueryManagerService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/xmlns/prod/ts/tnt/query/tnt/}TrackAndTraceService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/xmlns/prod/ts/tiqm/}TrackedItemQueryManagerService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/xmlns/prod/ts/sqm/}SubscriptionQueryManagerService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/xmlns/prod/ts/aqm/}AnswerQueryManagerService', appName, policyName, bindingName, wsCSsl)
            #Web service client ports for snm.war
            appName=properties.get("SIDAPP_NAME")
            appModule='com.ibm.ts.snm.web.war'
        
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/epcis/serialid/ResourceManager}ResourceManagerService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/epcis/serialid/RuleManager}RuleManagerService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/epcis/serialid/PolicyManager}PolicyManagerService', appName, policyName, bindingName, wsCSsl)
            createProviderPolicySetAttachment(appModule+':{http://www.ibm.com/epcis/serialid/TagManager}TagManagerService', appName, policyName, bindingName, wsCSsl)


    #Configure client policies and bindings
    appName=properties.get("UIAPP_NAME")

    #Create policies and bindings 
    policyName="TS-Client-Policy-Set"
    policyDescription="Traceability Server client policy set."
    bindingName="TS-Client-Binding"
    bindingDescription="Traceability Server client bindings."
    deletePolicySet(policyName)
    deleteApplicationBinding(bindingName, appName) 
    deletePolicySet("TS-Policy-Client")
    deleteApplicationBinding("TS-Binding-Client", appName) 
                
    if( properties.get("CONFIG_OPTION")=='configure' ):
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySet(policyName, policyDescription)

        #Web service client ports and bindings for alerts.war
        appModule='com.ibm.ts.web.ui.alerts.war'
    
        appService='service/AlertsRegistryService'
        appPort='{http://www.ibm.com/xmlns/prod/ts/alerts_management/alertsregistry/}AlertsRegistryPort'
        appEpu=wsEpUrlPref+'/ts/engine/services/AlertsRegistryService'
        webService=appModule+':{http://www.ibm.com/xmlns/prod/ts/alerts_management/alertsregistry/}AlertsRegistryService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu, epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)
    
    
        appService='service/DeliveryMethodsRegistryService'
        appPort='{http://www.ibm.com/xmlns/prod/ts/alerts_management/deliverymethodsregistry/}DeliveryMethodsRegistryPort'
        appEpu=wsEpUrlPref+'/ts/engine/services/DeliveryMethodsRegistryService'
        webService=appModule+':{http://www.ibm.com/xmlns/prod/ts/alerts_management/deliverymethodsregistry/}DeliveryMethodsRegistryService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu, epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)


        appService='service/SubscriptionsRegistryService'
        appPort='{http://www.ibm.com/xmlns/prod/ts/alerts_management/subscriptionsregistry/}SubscriptionsRegistryPort'
        appEpu=wsEpUrlPref+'/ts/engine/services/SubscriptionsRegistryService'
        webService=appModule+':{http://www.ibm.com/xmlns/prod/ts/alerts_management/subscriptionsregistry/}SubscriptionsRegistryService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu, epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)


        appService='service/NotificationConfigurationsRegistryService'
        appPort='{http://www.ibm.com/xmlns/prod/ts/alerts_management/notificationconfigurationsregistry/}NotificationConfigurationsRegistryPort'
        appEpu=wsEpUrlPref+'/ts/engine/services/NotificationConfigurationsRegistryService'
        webService=appModule+':{http://www.ibm.com/xmlns/prod/ts/alerts_management/notificationconfigurationsregistry/}NotificationConfigurationsRegistryService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu, epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)


        #Web service client ports and bindings for snm.war
        appModule='com.ibm.ts.web.ui.snm.war'
        
        appService='service/ResourceManagerService'
        appPort='{http://www.ibm.com/epcis/serialid/ResourceManager}ResourceManagerPort'
        appEpu=wsEpUrlPref+'/ts/engine/snm/services/ResourceManagerService'
        webService=appModule+':{http://www.ibm.com/epcis/serialid/ResourceManager}ResourceManagerService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu, epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)
    
    
        appService='service/RuleManagerService'
        appPort='{http://www.ibm.com/epcis/serialid/RuleManager}RuleManagerPort'
        appEpu=wsEpUrlPref+'/ts/engine/snm/services/RuleManagerService'
        webService=appModule+':{http://www.ibm.com/epcis/serialid/RuleManager}RuleManagerService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu, epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)
    
    
        appService='service/PolicyManagerService'
        appPort='{http://www.ibm.com/epcis/serialid/PolicyManager}PolicyManagerPort'
        appEpu=wsEpUrlPref+'/ts/engine/snm/services/PolicyManagerService'
        webService=appModule+':{http://www.ibm.com/epcis/serialid/PolicyManager}PolicyManagerService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu, epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)
    
        appService='service/TagManagerService'
        appPort='{http://www.ibm.com/epcis/serialid/TagManager}TagManagerPort'
        appEpu=wsEpUrlPref+'/ts/engine/snm/services/TagManagerService'
        webService=appModule+':{http://www.ibm.com/epcis/serialid/TagManager}TagManagerService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu, epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)


        #Web service client ports and bindings for evb.war
        appModule='com.ibm.ts.web.ui.evb.war'
        
        appService='service/EPCglobalEPCISService'
        appPort='{urn:epcglobal:epcis:wsdl:1}EPCglobalEPCISPort'
        appEpu=wsEpUrlPref+'/ts/engine/services/EPCglobalEPCISService'
        webService=appModule+':{urn:epcglobal:epcis:wsdl:1}EPCglobalEPCISService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu, epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)
        

        appService='service/TSQueryManagerService'
        appPort='{http://www.ibm.com/xmlns/prod/ts/tsqm}TSQueryManagerPort'
        appEpu=wsEpUrlPref+'/ts/engine/services/TSQueryManagerService'
        webService=appModule+':{http://www.ibm.com/xmlns/prod/ts/tsqm}TSQueryManagerService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu, epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)

        #Web service client ports and bindings for feb.war
        appModule='com.ibm.ts.web.ui.feb.war'

        appService='service/FailedEventManagerService'
        appPort='{http://www.ibm.com/xmlns/prod/ts/fem}FailedEventManagerPort'
        appEpu=wsEpUrlPref+'/ts/engine/services/FailedEventManagerService'
        webService=appModule+':{http://www.ibm.com/xmlns/prod/ts/fem}FailedEventManagerService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu,  epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)

        #Web service client ports and bindings for mde.war
        appModule='com.ibm.ts.web.ui.mde.war'

        appService='service/MasterDataManagerService'
        appPort='{http://www.ibm.com/xmlns/prod/ts/mdm/}MasterDataManagerPort'
        appEpu=wsEpUrlPref+'/ts/engine/services/MasterDataManagerService'
        webService=appModule+':{http://www.ibm.com/xmlns/prod/ts/mdm/}MasterDataManagerService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu,  epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)

        #Web service client ports and bindings for sqe.war
        appModule='com.ibm.ts.web.ui.sqe.war'

        appService='service/SubscriptionQueryManagerService'
        appPort='{http://www.ibm.com/xmlns/prod/ts/sqm/}SubscriptionQueryManagerPort'
        appEpu=wsEpUrlPref+'/ts/engine/services/SubscriptionQueryManagerService'
        webService=appModule+':{http://www.ibm.com/xmlns/prod/ts/sqm/}SubscriptionQueryManagerService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu,  epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)

        #Web service client ports and bindings for tib.war
        appModule='com.ibm.ts.web.ui.tib.war'

        appService='service/TrackAndTraceService'
        appPort='{http://www.ibm.com/xmlns/prod/ts/tnt/query/tnt/}TrackAndTracePort'
        appEpu=wsEpUrlPref+'/ts/engine/services/TrackAndTraceService'
        webService=appModule+':{http://www.ibm.com/xmlns/prod/ts/tnt/query/tnt/}TrackAndTraceService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu,  epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)
    
        appService='service/TrackedItemQueryManagerService'
        appPort='{http://www.ibm.com/xmlns/prod/ts/tiqm/}TrackedItemQueryManagerPort'
        appEpu=wsEpUrlPref+'/ts/engine/services/TrackedItemQueryManagerService'
        webService=appModule+':{http://www.ibm.com/xmlns/prod/ts/tiqm/}TrackedItemQueryManagerService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu,  epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)
    

        appService='service/AnswerQueryManagerService'
        appPort='{http://www.ibm.com/xmlns/prod/ts/aqm/}AnswerQueryManagerPort'
        appEpu=wsEpUrlPref+'/ts/engine/services/AnswerQueryManagerService'
        webService=appModule+':{http://www.ibm.com/xmlns/prod/ts/aqm/}AnswerQueryManagerService'
        updateWSClientBindings.run( properties, appName, appModule, 'none',
                                    appService, appPort, appEpu,  epOnly, 'none' )
        if( properties.get("SECURITY_ON")=='true' ):
            createClientPolicySetAttachment(webService, appName, policyName, bindingName, wsCUser, wsCPwd, wsCSsl)

    
if( __name__=='__main__'):
    updateBindings( properties )
    AdminConfig.save()
