#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
import sys
import os.path

from java.io import FileInputStream
from java.util import Properties
from jarray import array
from com.ibm.rfidic.messages.tools import RFIDICGetMessage

#Add TS jython scripts to jython's import path
def updatePath(p):
    sys.path.append(p)

updatePath(sys.argv[1])

#Now that the rfidic jython directory is on the path, import our modules
import rfidicCfgUtils
import setLibrary
import reinstallApplication
import updateApplication
import recreateAuditConfig
import recreateDatasource
import recreateScheduler
import setWebServicesBindings

def getScope(p):
    cell=p.get("CELLNAME")
    if(p.get("ISCLUSTER")=="true"):
        ret='/Cell:'+cell+'/ServerCluster:'+p.get("CLUSTERNAME")+'/'
    else:
        ret='/Cell:'+cell+'/Node:'+p.get("NODENAME")+'/Server:'+p.get("SERVERNAME")+'/'
    
    return ret

def getServerId( p, server ):
    sid=AdminConfig.getid('/Cell:'+p.get("CELLNAME")+'/Node:'+server[0]+'/Server:'+server[1])
    return sid

def getTSVersionString(p):
    versionInfoFileName=p.get("TS_HOME")+'/VersionInfo/versionInfo.properties'
    versionInfoFile=open(versionInfoFileName, 'r')
    versionInfoString=versionInfoFile.read()
    versionInfoFile.close()
    return versionInfoString

def modifyWMQASOnServer(p, server, specNameList):
    sid=getServerId(p, server)
    actSpecs=AdminConfig.list('J2CActivationSpec', sid)
    specList=AdminUtilities.convertToList(actSpecs)
    args=[]
    args=args+['-failureDeliveryCount', 10]
    
    #If we rollback to GA or FP1, then we need to revert the endpoints back to an active state upon EAR start.
    tsVersion=getTSVersionString(p)
    if (tsVersion.find("3.0.0.0")!=-1 or tsVersion.find("3.0.0-FP001")!=-1):
        args=args+['-customProperties', '[[WAS_EndpointInitialState ACTIVE]]']
    else:
        args=args+['-customProperties', '[[WAS_EndpointInitialState INACTIVE]]']
    
    for specName in specNameList:
        for spec in specList:
            name=AdminConfig.showAttribute( spec, 'name' )
            if( name==specName ):
                AdminTask.modifyWMQActivationSpec(spec, args)
                break

#main
properties=rfidicCfgUtils.getProperties(sys.argv[0])
servers=rfidicCfgUtils.findServers(properties)

mdmAppLocation=properties.get("MDMAPP_LOCATION")
mdmAppName=properties.get("MDMAPP_NAME")
true=1
false=0

## Need to update Audit Config before the applications get updated
recreateAuditConfig.run(properties)

## Update the activation specifications to be a little more tolerant of failures. 
specNameList=['rfidicAlertsMQActivation', 'rfidicCaptureNotificationActivation', 'rfidicMQActivation', 'tsAS2MQActivation', 'tsCaptureActivation', 'tsCapturePRT']
for server in servers:
    modifyWMQASOnServer( properties, server, specNameList )

## If the MDM ear is in installableApps
##   We are rolling back to GA level code and the application needs to be installed
## If the MDM ear is not in installableApps 
##   we need to uninstall it in case it was installed previously
if( os.path.exists(mdmAppLocation)==true ):
    gaExists=true
else:
    gaExists=false

if( gaExists==true ):
    reinstallApplication.createServer(properties, mdmAppLocation, mdmAppName)
    recreateDatasource.run(properties, 'false',
                           'TS Scheduler JDBC Provider',
                           'Provider for Scheduler  data', "false",
                           "Scheduler Data Source",
                           "Scheduler database settings",
                           "jdbc/ts/schedulerDS" )
else:
    reinstallApplication.uninstallApp(mdmAppName)
    recreateDatasource.run(properties, 'false',
                            'TS Scheduler JDBC Provider',
                            'Provider for Scheduler  data', "true",
                            "Scheduler Data Source",
                            "Scheduler database settings",
                            "jdbc/ts/schedulerDS" )

## Recreate datasource during upgrade to fix the driver version for Oracle
dbType=properties.get("DB_TYPE")
if(dbType=="ORACLE"):
    scope=getScope(properties)
    dsScope=scope+'JDBCProvider:Traceability Server Oracle JDBC Provider/DataSource:traceabiltyDS/'
    dsObj=AdminConfig.getid(dsScope)
    AdminConfig.modify(dsObj, '[[datasourceHelperClassname "com.ibm.websphere.rsadapter.Oracle11gDataStoreHelper"]]')

updateApplication.run( properties, 'CPAPP_LOCATION', 'CPAPP_NAME' )
updateApplication.run( properties, 'UIAPP_LOCATION', 'UIAPP_NAME' )
updateApplication.run( properties, 'SIDAPP_LOCATION', 'SIDAPP_NAME' )

dsJndi='jdbc/ts/schedulerDS'
recreateScheduler.run( properties, 'RFIDICStandingQueryScheduler',
                        dsJndi, '10', 'RFIDIC_',
                        'RFIDICWorkManager', 'wm/rfidic/standing' )
recreateScheduler.run( properties, 'MDMCacheRefreshScheduler',
                        dsJndi, '10', 'MDMRFIDIC_',
                        'MDMCacheRefreshWM', 'wm/MDMCacheRefresh' )
recreateScheduler.run( properties, 'SerialIdScheduler',
                        dsJndi, '10', 'SERIALID_',
                        'SerialIdWorkManager', 'wm/Serialid' )

#Map shared libraries for apps
if( gaExists==true ):
    setLibrary.run(properties, servers, 'IBM_TS_LIB', 'Shared libraries for IBM TS applications.')
    AdminApp.edit(properties.get("MDMAPP_NAME"), '[ -MapSharedLibForMod [[ '+properties.get("MDMAPP_NAME")+' META-INF/application.xml IBM_TS_LIB ][ com.ibm.ts.mdm.web com.ibm.ts.mdm.web.war,WEB-INF/web.xml IBM_TS_LIB ]]]' )
    AdminApp.edit(properties.get("SIDAPP_NAME"), '[ -MapSharedLibForMod [[ '+properties.get("SIDAPP_NAME")+' META-INF/application.xml IBM_TS_LIB ][ com.ibm.rfidic.web.enterprise.serialid com.ibm.rfidic.web.enterprise.serialid.war,WEB-INF/web.xml IBM_TS_LIB ][ com.ibm.rfidic.web.snm com.ibm.rfidic.web.snm.war,WEB-INF/web.xml IBM_TS_LIB ]]]' )

print "Saving..."
AdminConfig.save()


if( properties.get("ISCLUSTER")=='true' ):
    rfidicCfgUtils.stopServers(servers)
    rfidicCfgUtils.startServers(servers)
              
print "Saving..." 
AdminConfig.save()

