#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
#
#
# prereqChecks.sh - contains the methods needed to check the versions of the components
###################################################################################

sDir=`dirname ${0}`
. $sDir/utils.sh

usage()
{
	$ECHO "USAGE: ./prereqChecks.sh -components=<WAS, DB, MQ> 
	$ECHO -DB_TYPE=<DB2|ORACLE> 
	$ECHO -TS_HOME=<location of InfoSphere Traceability Server> 
	$ECHO -WAS_HOME=<locat of WebSphere Application Server 7.0>
	$ECHO -DBMS_ADMIN_USER=<dba_user> 
	$ECHO -DBMS_ADMIN_PASSWORD=<dba_password>
	$ECHO -DBMS_PORT_NUMBER=<DB port number>
	$ECHO -DBMS_DB_NAME=<DB name>
	$ECHO -DBMS_JDBC_LIB_PATH=<path to JDBC drivers>
	$ECHO -DBMS_HOST=<hostname of DB server>
	$ECHO -MQ_HOME=<location of MQ>
	$ECHO -SERVERNAME=<WAS server name>
	$ECHO -was_admin_user=<WAS admin userid>
	$ECHO -was_admin_password=<WAS admin userid password>
	$ECHO -RESULT=<result file path>"
	return 1
}

isOSValid()
{
	futureRelease=$FALSE
	invalidRelease=$FALSE
	unknownOS=$FALSE
	valid=$TRUE
	
	getMessage TSIN01020I
	log $msg
	#log "\nVerifying the operating system level..."

    if [ "$PLATFORM" = "Linux" ];then
        if [ -f "/etc/redhat-release" ];then
            release=`cat /etc/redhat-release | awk '{print($7)}' | ${AWK_PERIOD} '{print($1)}'`
            
            if [ "$release" = "5" ];then
                update=`cat /etc/redhat-release | awk '{print($7)}' | ${AWK_PERIOD} '{print($2)}'`
                if [ "$update" -lt 5 ];then
			invalidRelease=$TRUE
                elif [ "$update" -gt 5 ];then
			futureRelease=$TRUE
		fi
            elif [ "$release" -lt 5 ];then
		invalidRelease=$TRUE
            elif [ "$release" -gt 5 ];then
		futureRelease=$TRUE
            fi
        elif [ -f "/etc/SuSE-release" ];then
            release=`cat /etc/SuSE-release | grep "VERSION" | awk '{print($3)}'`
            if [ "$release" -lt 10 ];then
		invalidRelease=$TRUE
            elif [ "$release" -gt 11 ];then
		futureRelease=$TRUE
            fi
        else
		unknownOS=$TRUE
        fi
    elif [ "$PLATFORM" = "AIX" ];then
        release=`uname -a | awk '{print($4)}'`
        update=`uname -a | awk '{print($3)}'`

        if [  "$release" -lt 6  ];then
		invalidRelease=$TRUE
        elif [  "$release" = "6"  ];then
            if [ "$update" -lt 1 ];then
		invalidRelease=$TRUE
            elif [ "$update" -gt 1 ];then
		futureRelease=$TRUE
            fi
        else
		futureRelease=$TRUE
        fi
    elif [ "$PLATFORM" = "SunOS" ];then
        osLevel=`uname -r`
	release=`echo $osLevel | ${AWK_PERIOD} '{print($1)}'`
	version=`echo $osLevel | ${AWK_PERIOD} '{print($2)}'`

        if [ "$release" -eq "5" ];then
        	if [ "$version" -lt "10" ];then
			invalidRelease=$TRUE
        	elif [ "$version" -gt "10" ];then
			futureRelease=$TRUE
        	fi
        elif [ "$release" -gt "5" ];then
			futureRelease=$TRUE
	fi
    else
		unknownOS=$TRUE
    fi
    
    if [ "$futureRelease" = "$TRUE" ];then
		#TODO: Add a message and a command that lets the user override OS compatibility during silent install
		getMessage TSIN01021W
		log $msg
		$ECHO $msg
		#echo_msg "Support for your operating system might have been added after the release of the product."
		getMessage TSIN01022W
		log $msg
		$ECHO $msg
		#echo_msg "You can continue with the installation, but the installation might not succeed."
		getMessage TSIN01023E
		log $msg
		$ECHO $msg
		#echo_msg "See the web page on the hardware and software prerequisites for more details."
		valid=$TRUE
    fi
	
    if [ "$unknownOS" = "$TRUE" -o "$invalidRelease" = "$TRUE" ];then
		getMessage TSIN01033E
		log $msg
        	#echo_msg "Install >> Platform Verification >> Error"
        	log "--------------------------------------------------"
        	$ECHO "--------------------------------------------------"
        	getMessage TSIN01026E
			log $msg
			$ECHO $msg
        	#echo_msg "\nIBM InfoSphere Traceability Server is not supported for this operating system."
        	getMessage TSIN01025E
			log $msg
			$ECHO $msg
        	#echo_msg "Install a supported operating system and then try installing."
        	getMessage TSIN01023E
			log $msg
			$ECHO $msg
        	#echo_msg "See the web page on the hardware and software prerequisites for more details."
			valid=$FALSE
    fi
	
    return $valid
}

isDiskSpaceValid()
{
	getMessage TSIN01032I
	log $msg
	#log "Verify free disk space"
	
	valid=$TRUE
	
	#Check to ensure 1 GB free space is available
	getDiskSpace $WAS_HOME
	if [ "$returnString" -lt 1048576 ];then
		getMessage TSIN01033E
		log $msg
		#echo_msg "Install >> Platform Verification >> Error"
		log "--------------------------------------------------"
		getMessage TSIN01034E
		log $msg
		#echo_msg "\nIBM InfoSphere Traceability Server requires 1 GB for installation"
		valid=$FALSE
	fi
	
	#Check to ensure 500 MB free space is available in /tmp for installation
	getDiskSpace /tmp
	if [ "$returnString" -lt 512000 ];then
		getMessage TSIN01033E
		log $msg
		#echo_msg "Install >> Platform Verification >> Error"
		log "--------------------------------------------------"
		getMessage TSIN01035E
		log $msg
		#echo_msg "\nIBM InfoSphere Traceability Server requires 500 MB in /tmp for installation"
		valid=$FALSE
	fi
	
	return $valid
}

isUserPermissionValid()
{
	#Do we need this check?
	something="something"
}

isWASValid()
{
    getMessage TSIN01080I
    log $msg
    #log "Verify WAS is valid"

    wasIsValid=$TRUE
    versionIsValid=$FALSE

    getActualWASConfig

    if  [ ! -f "$WAS_HOME/bin/versionInfo.sh" ];then
        wasIsValid=$FALSE
        getMessage TSIN02009E $WAS_HOME
        log $missing_info"\n$msg"
        #missing_info=$missing_info"\nThe value for 'WAS_HOME' - $WAS_HOME does not seem to be valid"
    else
        getWASVersion
        if [ `echo $returnString | ${AWK_PERIOD} '{print($1)}'` -eq 7 ];then
            if [ `echo $returnString | ${AWK_PERIOD} '{print($2)}'` -eq 0 ];then
                if [ `echo $returnString | ${AWK_PERIOD} '{print($3)}'` -eq 0 ];then
                    if [ `echo $returnString | ${AWK_PERIOD} '{print($4)}'` -ge 21 ];then
                        versionIsValid=$TRUE
                    fi
                else
                    versionIsValid=$TRUE
                fi
            fi
        fi

        if [ "$versionIsValid" = "$FALSE" ];then
            wasIsValid=$FALSE
            getMessage TSIN01081E
            log $msg
            #echo_msg "Install >> Pre-requisite Check >> Failure"
            log "----------------------------------------------"
            getMessage TSIN01084E
            log $msg
            #echo_msg "A supported version of WebSphere Application Server was not found at the location mentioned by you."
            getMessage TSIN01023E
            log $msg
            #echo_msg "See the web page on the hardware and software prerequisites for more details."
            getMessage TSIN01085E
            log $msg
            #echo_msg "Install a supported version of WebSphere Application Server and then restart the installation."
        fi

        isLocalOSSecurityEnabled
        if [ $? -eq $TRUE ];then
            if [ "$was_runas_user" != "root" ];then
                wasIsValid=$FALSE
                getMessage TSIN01081E
                log $msg
                #echo_msg "Install >> Pre-requisite Check >> Failure"
                log "----------------------------------------------"
                getMessage TSIN02275E
                log $msg
                #echo_msg "Local OS security is enabled in WebSphere Application Server, but the WAS runas user is not root."
            fi
        fi
    fi

    return $wasIsValid
}

isMQValid()
{
	getMessage TSIN01087I
	log $msg
	#log "Verify MQ is valid"

    valid=$FALSE
	
	mq_home=$1
    
    if [ -z "$mq_home" ];then
        mq_home=$MQ_HOME
    fi
	if [ ! -d $mq_home ]; then
		getMessage TSIN01081E
		log $msg
		#echo_msg "Install >> Pre-requisite Check >> Failure"
		log "----------------------------------------------"
		getMessage TSIN01088E $mq_home
		log $msg
		#echo_msg "WebSphere MQ installation is not found in the location $mq_home."
		getMessage TSIN01089E
		log $msg
		#echo_msg "Verify the WebSphere MQ installation location and then restart the installation."
	else
		getMQVersion
		if [ `echo $returnString | ${AWK_PERIOD} '{print($1)}'` = "7" ];then
			if [ `echo $returnString | ${AWK_PERIOD} '{print($2)}'` = "0" ];then
				if [ `echo $returnString | ${AWK_PERIOD} '{print($3)}'` = "1" ];then
					if [ `echo $returnString | ${AWK_PERIOD} '{print($4)}'` -ge 8 ];then
						valid=$TRUE
					fi
				fi
			fi
		fi
    
		if [ "$valid" = "$FALSE" ];then
			getMessage TSIN01081E
			log $msg
			#echo_msg "Install >> Pre-requisite Check >> Failure"
			log "----------------------------------------------"
			getMessage TSIN01090E
			log $msg
			#echo_msg "A supported version of WebSphere MQ was not found at the location mentioned by you."
			getMessage TSIN01023E
			log $msg
			#echo_msg "See the web page on the hardware and software prerequisites for more details. "
			getMessage TSIN01091E
			log $msg
			#echo_msg "Install a supported version of WebSphere MQ and then restart the installation."
		fi
	fi
    return $valid
}

isDBValid()
{
	getMessage TSIN01095I
	log $msg
	#log "Verify DB is valid"
	
    valid=$FALSE
    
	isHostnameRemote $DBMS_HOST
	isDBRemote=$?

	getDBVersion
    if [ "$?" != "0" ];then
        getMessage TSIN02209E $DBMS_HOST $utilsLogFile
        missing_info=$missing_info"\n$msg"
        return $FALSE
    fi
	dbVersion=$returnString
	
    case "$DB_TYPE" in
        "ORACLE")
            if [ `echo $dbVersion | ${AWK_PERIOD} '{print($1)}'` = "11" ];then
                if [ `echo $dbVersion | ${AWK_PERIOD} '{print($2)}'` = "2" ];then
                    valid=$TRUE
                fi
            fi 
            
            if [ "$valid" = "$FALSE" ];then
				getMessage TSIN01081E
				log $msg
				#echo_msg "Install >> Pre-requisite Check >> Failure"
				log "----------------------------------------------"
				getMessage TSIN01097E
				log $msg
				#echo_msg "\nA supported version of Oracle Server was not found at the location mentioned by you."
				getMessage TSIN01023E
				log $msg
				#echo_msg "See the web page on the hardware and software prerequisites for more details."
				getMessage TSIN01098E
				log $msg
				#echo_msg "Install a supported version of database and then restart the installation."
				
				if [ ! -z "$RESULT" ];then
					getMessage TSIN01097E
					$ECHO $msg >> $RESULT
					#$ECHO "A supported version of Oracle Server was not found at the specified location." >> $RESULT
					return $FALSE
				fi
            fi
            ;;
        "DB2")
            if [ `echo $dbVersion | ${AWK_PERIOD} '{print($1)}'` = "v9" ];then
                if [ `echo $dbVersion | ${AWK_PERIOD} '{print($2)}'` = "7" ];then
                    valid=$TRUE
                fi
            fi              
                    
            if [ "$valid" = "$FALSE" ];then
				getMessage TSIN01081E
				log $msg
				#echo_msg "Install >> Pre-requisite Check >> Failure"
				log "----------------------------------------------"
				getMessage TSIN01099E
				log $msg
				#echo_msg "A supported version of DB2 Server was not found at the location mentioned by you."
				getMessage TSIN01023E
				log $msg
				#echo_msg "See the web page on the hardware and software prerequisites for more details."
				getMessage TSIN01098E
				log $msg
				#echo_msg "Install a supported version of database and then restart the installation."

				if [ ! -z "$RESULT" ];then
					getMessage TSIN01099E
					$ECHO $msg >> $RESULT
					#$ECHO "A supported DB2 Server version was not found at the specified location." >> $RESULT
				return $FALSE
				fi
            fi
            ;;
        *)
			getMessage TSIN01081E
			log $msg
			#echo_msg "Install >> Pre-requisite Check >> Failure"
			log "----------------------------------------------"
			getMessage TSIN01100E $DB_TYPE
			log $msg
			#echo_msg "\nInvalid database type specified."
			getMessage TSIN01098E
			log $msg
			#echo_msg "Install a supported version of database and then restart the installation."
           ;;
    esac
    
    return $valid
}

# Checks to see if hostname resolves to localhost. Returns 0 if it's NOT localhost, and 1 if it is. 
isHostnameValid()
{
	getMessage TSIN01028I
	log $msg
	#log "Verify hostname is correct"
	
	valid=$TRUE
	
    if [ "$HOSTNAME" = "localhost" -o "$HOSTNAME" = "localhost.localdomain" ];then
		getMessage TSIN01033E
		log $msg
        #echo_msg "Install >> Platform Verification >> Error"
        log "--------------------------------------------------"
        getMessage TSIN01029E $HOSTNAME
		log $msg
        #echo_msg "\n$HOSTNAME is not a valid hostname."
        getMessage TSIN01030E
		log $msg
        #echo_msg "Reset the hostname and then try installing."
        valid=$FALSE
    fi
	
	return $valid
}

isTSARValid()
{
    valid=$TRUE

    if [ ! -f "$TSAR" ];then
        getMessage TSIN02274E $TSAR
        missing_info=$missing_info"\n$msg"
        #missing_info="Could not locate file $TSAR"
        valid=$FALSE
    fi

    return $valid
}

# Returns 0 if installed, 1 if not installed
isMQInstalled()
{
	getMessage TSIN02201I
	log $msg
	#log "Verify MQ is installed"
	
    installed=$TRUE
    
    if [ "$PLATFORM" = "Linux" ];then 
        MQ_RPMS="MQSeriesTXClient MQSeriesJava MQSeriesServer MQSeriesRuntime"
            
        for rpmname in ${MQ_RPMS[@]}
        do      
            rpmval=`(rpm -qa | grep ${rpmname})`
            if [ "${rpmval}" = "" ];then
                installed=$FALSE
                break
            fi
        done
    elif [ "$PLATFORM" = "AIX" ];then 
        MQ_PKGS="mqm.base.runtime mqm.client.rte mqm.server.rte mqm.java.rte"
        pkg_all=`lslpp -L all | grep mqm`
            
        for pkg in ${MQ_PKGS[@]}
        do      
            pkgval=`echo ${pkg_all} | grep ${pkg}`
            if [ "${pkgval}" = "" ];then
                installed=$FALSE
                break
            fi
        done
    elif [ "$PLATFORM" = "SunOS" ];then
        pkgInfo=`pkginfo | grep mqm`
        if [ "$pkgInfo" = "" ];then
            installed=$FALSE
        fi
    fi
	
	if [ "installed" = "$FALSE" ];then
		getMessage TSIN01059E
		log $msg
	fi
	
    return $installed
}

# Returns 0 if WAS is running, 1 if it's not. Will take the was user name and password as parameters. If no parameters are passed, it'll look
# at the $was_admin_user and the $was_admin_password variables. If those aren't set, assume that WAS security isn't turned on.
isWASRunning()
{
	getMessage TSIN02202I
	log $msg
	#log "Verify WAS is running"
	
    user=$1
    password=$2
    
    if [ -z "$SERVERNAME" ];then
        SERVERNAME=server1
    fi

    getActualWASConfig
	
    if [ -z "$user" ];then
        user=$was_admin_user
    fi
    
    if [ -z "$password" ];then
        password=$was_admin_password
    fi

    if [ -z "$user" -o -z "$password" ];then
        isWASSecurityEnabled
        if [ $? -eq $TRUE ];then
            if [ -z "$was_admin_user" ];then
                getMessage RFID05095I
                $ECHO $msg
                read was_admin_user
            fi

            if [ -z "$was_admin_password" ];then
                getMessage TSIN01153I $was_admin_user
                $ECHO $msg
                stty -echo
                read was_admin_password
                stty echo
            fi
        fi
    fi

    # It has been determined that these strings are not translated in the WAS message that comes back.
    if [ -n "$CLUSTERNAME" ];then
        serverType="Deployment Manager"
    else
        serverType="Application Server"
    fi

    unset credentials
    if [ -n "$user" -a -n "$password" ];then
        credentials="-username $user -password $password"
    fi
      
    # The ADMU0508I message is used for more than just application servers, it's also used for web servers. So we need to look for the server type
    # as well. Otherwise, if the application server is down and the web server is up...it'll return true when it shouldn't.
    serverStatus=`${WAS_PROFILE_HOME}/bin/serverStatus.sh -all $credentials 2> /dev/null | grep "ADMU0508I" | grep "$serverType"`
    
    status=$?

    if [ $status -eq 0 ];then
        return $TRUE
    else
        return $FALSE
    fi
}

isMQRunning()
{
    if [ -f $WAS_HOME/installedConnectors/wmq.jmsra.rar/com.ibm.mq.jar -a -f $WAS_HOME/installedConnectors/wmq.jmsra.rar/com.ibm.mq.pcf.jar -a -f $WAS_HOME/installedConnectors/wmq.jmsra.rar/com.ibm.mq.jmqi.jar ];then
        cp=$CLASSPATH:$WAS_HOME/installedConnectors/wmq.jmsra.rar/com.ibm.mq.jar:$WAS_HOME/installedConnectors/wmq.jmsra.rar/com.ibm.mq.pcf.jar:$WAS_HOME/installedConnectors/wmq.jmsra.rar/com.ibm.mq.jmqi.jar
    elif [ -d $MQ_HOME -a -f $MQ_HOME/java/lib/com.ibm.mq.jar -a -f $MQ_HOME/java/lib/com.ibm.mq.pcf.jar -a -f $MQ_HOME/java/lib/com.ibm.mq.jmqi.jar ];then
        cp=$CLASSPATH:$MQ_HOME/java/lib/com.ibm.mq.jar:$MQ_HOME/java/lib/com.ibm.mq.pcf.jar:$MQ_HOME/java/lib/com.ibm.mq.jmqi.jar
    fi

    if [ -n "$cp" ];then
        MQ_TS_CHANNEL=SYSTEM.DEF.SVRCONN
        if [ -n R_QUEUE_MANAGER -a ! $MQ_HOST = $R_MQ_HOST ];then
            if [ -n R_QUEUE_MANAGER -a ! $MQ_HOST = $R_MQ_HOST ];then
                ${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.utils.mq.CheckMQStatus $R_MQ_HOST $R_MQ_LSR_PORT $MQ_TS_CHANNEL $R_QUEUE_MANAGER > /dev/null 2>&1
                if [ $? -ne 0 ];then
                    return $FALSE
                else
                    return $TRUE
                fi
            fi
        else
            ${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.utils.mq.CheckMQStatus $MQ_HOST $MQ_LSR_PORT $MQ_TS_CHANNEL $QUEUE_MANAGER > /dev/null 2>&1
            if [ $? -ne 0 ];then
                return $FALSE
            else
                return $TRUE
            fi
        fi
    else
        getMessage TSIN01322E
        echo $msg
        #echo "Error occured while querying MQ instance due to missing MQ connector files"
        return $FALSE
    fi
}

isDBRunning()
{
	getMessage TSIN02203I
	log $msg
	#log "Verify DB is running"

    if [ -z "$DBMS_ADMIN_USER" ];then
        getMessage TSIN02271I
        $ECHO $msg
        read DBMS_ADMIN_USER
    fi

    if [ -z "$DBMS_ADMIN_PASSWORD" ];then
        getMessage TSIN02272I
        $ECHO $msg
        stty -echo
        read DBMS_ADMIN_PASSWORD
        stty echo
    fi


    cp=$TS_HOME/lib/com.ibm.rfidic.utils.jar:$TS_HOME/lib/commons-dbutils-1.0.jar
    case "$DB_TYPE" in
        DB2)
            cp=$cp:$DBMS_JDBC_LIB_PATH/db2jcc.jar:$DBMS_JDBC_LIB_PATH/db2jcc4.jar:$DBMS_JDBC_LIB_PATH/db2jcc_license_cu.jar
            JDBC="jdbc:db2://${DBMS_HOST}:${DBMS_PORT_NUMBER}/${DBMS_DB_NAME}"
            ;;

        ORACLE)
            cp=$cp:$DBMS_JDBC_LIB_PATH/ojdbc5.jar
            JDBC="jdbc:oracle:thin:@${DBMS_HOST}:${DBMS_PORT_NUMBER}:${DBMS_DB_NAME}"
            ;;
        *)
            getMessage TSIN01100E $DB_TYPE
            log $msg
            #log "Invalid RDBMS type: $DB_TYPE"
            return $FALSE
            ;;
    esac

    ${WAS_HOME}/java/bin/java -classpath $cp com.ibm.rfidic.utils.install.HealthCheck_DB ${DB_TYPE} ${JDBC} ${DBMS_ADMIN_USER} ${DBMS_ADMIN_PASSWORD} >> $utilsLogFile 2>&1
    
    dbstatus=$?

    if [ "${dbstatus}" = "0" ];then
        return $TRUE
    else
        if [ -n "$RESULT" ];then
            getMessage TSIN01078E
            $ECHO $msg >> $RESULT
            #$ECHO "Database is not running." >> $RESULT
        fi
        return $FALSE
    fi
}

getWASVersion()
{
	unset returnString
	
	getMessage TSIN01080I
	log $msg
    #log "\nVerifying WebSphere Application Server installation location and version..."
    if [ -d $WAS_HOME ]; then
        returnString=`${WAS_HOME}/bin/versionInfo.sh | awk '/IBM WebSphere Application Server/ { getline; print }' | grep Version | awk '{print($2)}'`
    fi
}

getMQVersion()
{
	unset returnString
	
	getMessage TSIN01087I
	log $msg
    #log "\nVerifying WebSphere MQ installation location and version..."
    if [ -d $MQ_HOME ]; then
        returnString=`${MQ_HOME}/bin/dspmqver | grep "Version" | awk '{print($2)}'`
    fi
}

getDBVersion()
{
	unset returnString
	
	getMessage TSIN02204I
	log $msg
	#log "Query DB version"
    cp=$TS_HOME/lib/commons-lang-2.4.jar:$TS_HOME/lib/icu4j-4_4_1.jar:$TS_HOME/lib/icu4j-charsets-4_4_1.jar:$TS_HOME/lib/icu4j-localespi-4_4_1.jar:$TS_HOME/lib/com.ibm.imc.algorithms.jar:$TS_HOME/lib/com.ibm.rfidic.messages.jar:$TS_HOME/lib/com.ibm.rfidic.utils.messages.jar:$TS_HOME/lib/com.ibm.rfidic.utils.jar:$TS_HOME/lib/commons-dbutils-1.1.jar:$WAS_HOME/lib/j2ee.jar:$WAS_HOME/optionalLibraries/Apache/Struts/1.1/commons-logging.1.1.1.jar:$TS_HOME/lib/commons-codec-1.3.jar:$TS_HOME/lib/commons-httpclient-3.1.jar
	
	if [ -z "$DBMS_ADMIN_USER" ];then
		getMessage TSIN02271I
        $ECHO $msg
		read DBMS_ADMIN_USER
	fi
	if [ -z "$DBMS_ADMIN_PASSWORD" ];then
		getMessage TSIN02272I
        $ECHO $msg
        stty -echo
		read DBMS_ADMIN_PASSWORD
        stty echo
	fi
	
    if [ "$DB_TYPE" = "ORACLE" ];then
		if [ -z "$DBMS_PORT_NUMBER" ];then
            DBMS_PORT_NUMBER=1521
		fi
	
		cp=$cp:$DBMS_JDBC_LIB_PATH/ojdbc5.jar
		
		if [ -n "$ORACLE_JDBC_URL" ];then
			JDBC=$ORACLE_JDBC_URL
		else
			JDBC="jdbc:oracle:thin:@${DBMS_HOST}:${DBMS_PORT_NUMBER}:${DBMS_DB_NAME}"
		fi
		
        JDBCDriver=oracle.jdbc.OracleDriver
        $WAS_HOME/java/bin/java -classpath $cp com.ibm.rfidic.utils.install.SQLFileExecutor ${JDBC} ${JDBCDriver} ${DBMS_ADMIN_USER} ${DBMS_ADMIN_PASSWORD} $TS_HOME/bin/Oracle/VersionCheck.sql 1> /tmp/VersionOutput.txt 2>> $utilsLogFile
        if [ "$?" = "1" ];then
        	getMessage TSIN02209E ${DBMS_HOST} $utilsLogFile
            $ECHO $msg
			log $msg
            #log "\n Database version cannot be retrieved on host - ${DBMS_HOST} , Check if the DB is running and try again ."
            return $FALSE
        fi

        returnString=`cat /tmp/VersionOutput.txt | grep "Release" | awk '{print($7)}'`
    elif [ "$DB_TYPE" = "DB2" ];then
		if [ -z "$DBMS_PORT_NUMBER" ];then
            DBMS_PORT_NUMBER=50000
		fi
        
		cp=$cp:$DBMS_JDBC_LIB_PATH/db2jcc.jar:$DBMS_JDBC_LIB_PATH/db2jcc_javax.jar:$DBMS_JDBC_LIB_PATH/db2jcc_license_cu.jar:$DBMS_JDBC_LIB_PATH/db2jcc_license_cisuz.jar
        
        JDBC="jdbc:db2://${DBMS_HOST}:${DBMS_PORT_NUMBER}/${DBMS_DB_NAME}"
        JDBCDriver=com.ibm.db2.jcc.DB2Driver
        $WAS_HOME/java/bin/java -classpath $cp com.ibm.rfidic.utils.install.SQLFileExecutor ${JDBC} ${JDBCDriver} ${DBMS_ADMIN_USER} ${DBMS_ADMIN_PASSWORD} $TS_HOME/bin/DB2/VersionCheck.sql 1> /tmp/VersionOutput.txt 2>> $utilsLogFile
        if [ "$?" = "1" ];then
        	getMessage TSIN02209E ${DBMS_HOST} $utilsLogFile
            $ECHO $msg
			log $msg 
            #log "\n Database version cannot be retrieved on host - ${DBMS_HOST} , Check if the DB is running and try again ."
            return $FALSE
        fi

        returnString=`cat /tmp/VersionOutput.txt | grep "DB2" | awk '{print($2)}'`
    fi
	
	rm -f /tmp/VersionOutput.txt
}

getWASHome()
{
    ##GETTING THE IM INSTALLATION LOCATION
    if [ "$CURRENT_USER" = "root" ];then
        if [ -f /etc/.ibm/registry/InstallationManager.dat ];then
            IM_LOCATION=`cat /etc/.ibm/registry/InstallationManager.dat | grep "location=" | ${AWK_EQUAL} '{print($2)}'`
        fi
    else
        if [ -f ~/etc/.ibm/registry/InstallationManager.dat ];then
            IM_LOCATION=`cat ~/etc/.ibm/registry/InstallationManager.dat | grep "location=" | ${AWK_EQUAL} '{print($2)}'`
        fi
    fi

    ##GETTING THE APP_DATA_LOCATION
    if [ -d "$IM_LOCATION" ];then
        if [ -f $IM_LOCATION/eclipse/configuration/config.ini ];then
            APP_DATA_LOCATION=`cat $IM_LOCATION/eclipse/configuration/config.ini | grep "cic.appDataLocation" | ${AWK_EQUAL} '{print($2)}'`
        fi
    else
        if [ "$CURRENT_USER" = "root" ];then
            APP_DATA_LOCATION="/var/ibm/InstallationManager"
        else
            APP_DATA_LOCATION=`echo ~/var/ibm/InstallationManager`
        fi
    fi

    ##GETTING WAS LOCATION
    if [ -f $APP_DATA_LOCATION/installRegistry.xml ];then
        WAS_LOCATION=`cat $APP_DATA_LOCATION/installRegistry.xml | sed -n "/<profile id='IBM WebSphere Application Server - /,/<offering id='com.ibm.im.ts'>/p" | grep installLocation | ${TAIL}1 | ${AWK_QUOTE} '{print($4)}'`
    fi


    returnString=$WAS_LOCATION
}

# get CELLNAME and NODENAME from WAS installation. This might override defaults.
getActualWASConfig() 
{
	if [ -z "$WAS_HOME" ];then
		getMessage TSIN02205E "WAS_HOME"
		log $msg
		#log "WAS_HOME environment variable is not set"
		return 1
	fi
   
    if [ -z "$WAS_PROFILE" ];then
        if [ -n "$1" ];then
            WAS_PROFILE=$1
        else
        	getMessage TSIN02205E "WAS_PROFILE"
			log $msg
			#log "WAS_PROFILE environment variable is not set"
            return 1
        fi
    fi
	
	WAS_PROFILE_HOME=`${WAS_HOME}/bin/manageprofiles.sh -getPath -profileName ${WAS_PROFILE} 2> /dev/null`

	WAS_CFG=${WAS_PROFILE_HOME}/config/cells
	
	log "WAS_PROFILE = $WAS_PROFILE"
	log "CELLNAME = $CELLNAME"
	log "NODENAME = $NODENAME"
	log "SERVERNAME = $SERVERNAME"
	log "WAS_PORT_NO = $WAS_PORT_NO"
	
	if [ ! -d "$WAS_CFG"  ];then
		if [ `ls ${WAS_HOME}/profiles | wc -w` = "1" ]; then
			WAS_PROFILE=`ls ${WAS_HOME}/profiles`
			WAS_CFG=${WAS_HOME}/profiles/${WAS_PROFILE}/config/cells
			log "WAS_PROFILE = $WAS_PROFILE"
		else
			getMessage RFID05035E "$WAS_PROFILE"
			return 1
		fi
	fi
	
	if [ ! -d $WAS_CFG/$CELLNAME ]; then
		if [ `ls ${WAS_CFG}| wc -w` = "1" ]; then
			CELLNAME=`ls ${WAS_CFG}`
			log "CELLNAME = $CELLNAME"
		else
			getMessage RFID05029E
			return 1
		fi
	fi
	
	if [ -z "$CLUSTERNAME" ]; then
		if [ ! -d $WAS_CFG/$CELLNAME/nodes/$NODENAME ];then
			if [ `ls ${WAS_CFG}/${CELLNAME}/nodes | wc -w` = "1" ]; then
				NODENAME=`ls ${WAS_CFG}/${CELLNAME}/nodes`
				getMessage RFID05031I "$NODENAME"
			else
				getMessage RFID05032E
				return 1
			fi
		fi
	
		if [ ! -d $WAS_CFG/$CELLNAME/nodes/$NODENAME/servers/$SERVERNAME ]; then
			if [ `ls ${WAS_CFG}/${CELLNAME}/nodes/${NODENAME}/servers | wc -w` = "1" ]; then
				SERVERNAME=`ls ${WAS_CFG}/${CELLNAME}/nodes/${NODENAME}/servers`
				getMessage RFID05033I "$SERVERNAME"
			else
				getMessage RFID05034E
				return 1
			fi
		fi
	else
		if [ ! -d ${WAS_CFG}/$CELLNAME/clusters/${CLUSTERNAME} ]; then
			getMessage RFID05034E
			return 1
		fi
	fi
}

isPortValid()
{
	while [ "$*" != "" ]
	do
		echo "port to be validated $1"
		mqport=$1
		while `grep -w $mqport/tcp /etc/services | grep -v '^#' | grep -v 'MQ' >/dev/null`
		do
			let mqport=mqport+1
			if [ -n $assignedport -a $mqport = $assignedport ];then
				let mqport=mqport+1
			fi
		done
		if [ "$1" != "$mqport" ];then
			if [ ! -z "$RESULT" ];then
				getMessage TSIN02230E $1 $mqport
				echo $msg >> $RESULT 
				#echo "Port no:$1 is already being used by other program, Use port no:$mqport instead" >> $RESULT			
				assignedport=$mqport
			fi
		fi
		shift
	done
	return 1
}


# Called from Launchpad or as a script, take variables for DB,MQ,WAS and perform respective functions for each of them
if [ "$1" = "-runAsScript" ];then
	shift

	for item in $*
	do
		if [ `expr match "$item" '-components='` != 0 ];then
			components=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
			components=`echo "$components" | tr "," "\n" | tr "[a-z]" "[A-Z]" | sort`
		elif [ `expr match "$item" '-DB_TYPE='` != 0 ];then
	             	DB_TYPE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-TS_HOME='` != 0 ];then
                     TS_HOME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-WAS_HOME='` != 0 ];then
                     WAS_HOME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_ADMIN_USER='` != 0 ];then
    	             	DBMS_ADMIN_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_ADMIN_PASSWORD='` != 0 ];then
              	DBMS_ADMIN_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_PORT_NUMBER='` != 0 ];then
                     DBMS_PORT_NUMBER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_DB_NAME='` != 0 ];then
              	DBMS_DB_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_JDBC_LIB_PATH='` != 0 ];then
                     DBMS_JDBC_LIB_PATH=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-DBMS_HOST='` != 0 ];then
              	DBMS_HOST=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-MQ_HOME='` != 0 ];then
              	MQ_HOME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-MQ_PORTS='` != 0 ];then
			MQ_PORTS=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
			MQ_PORTS=`echo "$MQ_PORTS" | tr "," "\n" | tr "[a-z]" "[A-Z]" | sort`
		elif [ `expr match "$item" '-SERVERNAME='` != 0 ];then
              	SERVERNAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-was_admin_user='` != 0 ];then
              	was_admin_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-was_admin_password='` != 0 ];then
              	was_admin_password=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-RESULT'` != 0 ]; then
			RESULT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		else
			usage
		fi
	done

	# Got all variables, now perform checks based on value in components

	assignLogFile $TS_HOME/logs/TSConfigLog

	getMessage TSIN02193I
	echo $msg
	#echo "validating softwares"
	
	isOSValid
	if [ "$?" -eq "$FALSE" ];then
		getMessage TSIN02210E
		$ECHO $msg >> $RESULT
		#$ECHO "Operating System is not supported." >> $RESULT
	fi
	
	isHostnameValid
	if [ "$?" -eq "$FALSE" ];then
		getMessage TSIN02211E
		$ECHO $msg >> $RESULT
		#$ECHO "Hostname is not valid." >> $RESULT
	fi
		
	isUserPermissionValid
	if [ "$?" -eq "$FALSE" ];then
		getMessage TSIN02212E
		$ECHO $msg >> $RESULT
		#$ECHO "User does not have required permissions." >> $RESULT
	fi
	getMessage TSIN02194I
	echo $msg
	#echo "softwares validated"

	for item in $components
	do
		case "$item" in
			DB)
				getMessage TSIN02195I
				echo $msg
				#echo "validating db"
				isDBValid
				isDBRunning
				
				getMessage TSIN02196I
				echo $msg
				#echo "DB validation completed"
				;;
			MQ)
				getMessage TSIN02197I
				echo $msg
				#echo "Validating WebSphere MQ"
				isMQValid $MQ_HOME
				if [ "$?" -eq "$FALSE" ];then
					getMessage TSIN01090E
					$ECHO $msg >> $RESULT
					exit 1
				fi

				isMQInstalled()
				if [ "$?" -eq "$FALSE" ];then
					getMessage TSIN01059E
					$ECHO msg >> $RESULT
					exit 1
				fi

				isPortValid $MQ_PORTS
				
				getMessage TSIN02198I
				echo $msg
				#echo "MQ validated"
				;;
			WAS)
				getMessage TSIN02199I
				echo $msg
				#echo "Validating WebSphere Application Server"
								
				isWASValid
				if [ "$?" -eq "$FALSE" ];then
					getMessage TSIN01084E
					$ECHO $msg >> $RESULT
					exit 1
				fi

				if [ -z "$was_admin_user" -a -z "$was_admin_password" ];then
					isWASRunning
				else
					isWASRunning $was_admin_user $was_admin_password
				fi 
				if [ "$?" -eq "$FALSE" ];then
					getMessage TSIN01076E
					$ECHO $msg >> $RESULT
					#$ECHO "WAS is not running." >> $RESULT
					exit 1
				fi
				getMessage TSIN02200I
				echo $msg
				#echo "WAS validated"
				;;
		esac
	done
	exit 0
fi
