#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2007, 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
##
##   Title: rfidic-was-cfg.sh	
##   Description: Configures WAS. Creates DataSource, scheduler and
##   		  installs an enterprise application
##		
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
        . $RFIDIC_HOME/bin/tsEnv.sh
        . $RFIDIC_HOME/bin/utils.sh
else
        . $SCRIPT_DIR/tsEnv.sh
        . $SCRIPT_DIR/utils.sh
fi

usage(){
        # echo $"Usage: $0 [-clean] [-was_admin_user=<User name used for WAS administration>] [-was_admin_password=<Password of the user>] [-MQ_USER_PASSWORD=<Password for MQ user>]"
        tsGetMessage.sh -noid RFID05260E "$0"
}

getActualWASConfig

CONFIG_OPTION=configure
if [ $# -gt 4 ]
then
        usage
        exit -1
else
        for item in $*
        do
                if [ `expr match "$item" '-clean'` != 0 ];then
                        CONFIG_OPTION=unconfigure
                elif [ `expr match "$item" '-was_admin_user'` != 0 ];then
                        was_admin_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
                elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
		        was_admin_password=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
                elif [ `expr match "$item" '-MQ_USER_PASSWORD'` != 0 ];then
		        MQ_USER_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		else
                        usage
                        exit -1
                fi
        done
fi

QCFName="AS2 Queue Connection Factory"
QCFDesc="AS2 Queue Connection Factory for RFIDIC" 
QCFjndi="jms/ibm/rfidic/AS2/QCF"
MQHost=$MQ_HOST
MQPort=$MQ_LSR_PORT
MQManagerName=$QUEUE_MANAGER
MQAlias=RFIDICAS2MQAlias

cd $RFIDIC_HOME/bin
run_command $WAS_HOME/bin/wsadmin.sh -wsadmin_classpath $CLASSPATH -username $was_admin_user -password $was_admin_password -f ./jacl/recreateMQQCF.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME "$QCFName" "$QCFDesc" $QCFjndi $MQHost $MQPort $MQManagerName $MQAlias "true" $MQ_USER $MQ_USER_PASSWORD

QName="AS2Delivery queue"
QDesc="AS2 Queue for delivery of subscription results"
Qjndi=jms/ibm/rfidic/AS2/delivery


run_command $WAS_HOME/bin/wsadmin.sh -wsadmin_classpath $CLASSPATH -username $was_admin_user -password $was_admin_password -f ./jacl/recreateMQQ.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME "$QName" "$QDesc" $Qjndi $AS2DELIVERY_QUEUE_NAME $MQManagerName

########## AS2 Generic Requests ########################

QName="AS2 Request queue"
QDesc="AS2 Queue for generic EPCIS requests"
Qjndi=jms/ibm/rfidic/AS2/request/queue

run_command $WAS_HOME/bin/wsadmin.sh -wsadmin_classpath $CLASSPATH -username $was_admin_user -password $was_admin_password -f ./jacl/recreateMQQ.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME "$QName" "$QDesc" $Qjndi $AS2REQUEST_QUEUE_NAME $MQManagerName

QName="AS2 Response queue"
QDesc="AS2 Queue for generic EPCIS responses"
Qjndi=jms/ibm/rfidic/AS2/response/queue

run_command $WAS_HOME/bin/wsadmin.sh -wsadmin_classpath $CLASSPATH -username $was_admin_user -password $was_admin_password -f ./jacl/recreateMQQ.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME "$QName" "$QDesc" $Qjndi $AS2RESPONSE_QUEUE_NAME $MQManagerName

LPjndi="jms/ibm/rfidic/AS2/request/queue"
LPName="rfidicAS2MQListener"
QCF="jms/ibm/rfidic/AS2/QCF"
State="START"

run_command wsadmin.sh -wsadmin_classpath $CLASSPATH -username $was_admin_user -password $was_admin_password -f $RFIDIC_INSTALL_HOME/bin/jacl/recreateListener.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $LPjndi $LPName $QCF $State

