#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
##
##   Title: startTS.sh
##   Description: Script to start all the prerequisite software of Traceability
##   Server, namely, MQ, CAPTURE and WAS.
##
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
	. $RFIDIC_HOME/bin/tsEnv.sh
	. $RFIDIC_HOME/bin/utils.sh
	. $RFIDIC_HOME/bin/prereqChecks.sh
else
	. $SCRIPT_DIR/tsEnv.sh
	. $SCRIPT_DIR/utils.sh
	. $SCRIPT_DIR/prereqChecks.sh
fi

usage()
{
	tsGetMessage.sh RFID05083I "$0"
}

startMQ()
{
	isHostnameRemote $MQ_HOST
	mq_dist=$?
	
	echo "========================================="

	if [ "$mq_dist" = "$TRUE" ];then
		tsGetMessage.sh TSIN01299I $MQ_HOST
		#echo "Ensure that WebSphere MQ queue manager is running on the host $MQ_HOST"
		return
	fi
	if [ -d "$MQ_HOME" ];then
		tsGetMessage.sh RFID05038I
		strmqm ${QUEUE_MANAGER}
        #If MQ is already running, it'll return a 5
        if [ $? -ne 0 -a $? -ne 5 ];then
            tsGetMessage.sh RFID05042E "WebSphere MQ"
            exit $FALSE
        fi
		runmqlsr -t tcp -m ${QUEUE_MANAGER} -p ${MQ_LSR_PORT} &
	else
		tsGetMessage.sh RFID05039E "$MQ_HOME"
        exit $FALSE
	fi

	sleep 5

	return
}

startOracle()
{
	isHostnameRemote $DBMS_HOST
	db_dist=$?
	
	echo "========================================="

	java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME -DTS_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.install.DBConnect connect > /dev/null 2>&1
	db_status=$?
	if [ "$db_status" -ne 0 ];then
		if [ "$db_dist" = "$TRUE" ];then
			tsGetMessage.sh TSIN01301I $DBMS_HOST
			#echo "Ensure that the Oracle database on host $DBMS_HOST is running"
			return
		else   
			if [ -d "$DBMS_HOME" ];then
				#echo "Starting Oracle..." 
				tsGetMessage.sh RFID05227I
				runCommandAsUser $ORACLE_OWNER $DBMS_HOME/bin/dbstart $DBMS_HOME
                if [ $? -ne 0 ];then
                    tsGetMessage.sh RFID05042E "Oracle"
                    exit $FALSE
                fi
			else
				#echo "Starting Oracle failed because RBDMS was not found in $DBMS_HOME" 
				tsGetMessage.sh RFID05226E "Oracle" "$DBMS_HOME"
				exit $FALSE
			fi
		fi
	else
		tsGetMessage.sh TSIN01302I
		#echo "\nOracle- Already running"
	fi
}

startDB2()
{
	isHostnameRemote $DBMS_HOST
	db_dist=$?
	echo "========================================="

	java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME -DTS_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.install.DBConnect connect > /dev/null 2>&1
	db_status=$?
	if [ "$db_status" -ne 0 ];then
		if [ "$db_dist" = "$TRUE" ];then
			tsGetMessage.sh TSIN01303I $DBMS_HOST
			#echo "Ensure that the DB2 database on host $DBMS_HOST is running."
			return
		else		
			if [ -d "$DBMS_HOME" ]
			then
				#echo "Starting DB2..." 
				tsGetMessage.sh RFID05234I
				runCommandAsUser ${DB2_INSTANCE_OWNER} /home/$DB2_INSTANCE/sqllib/adm/db2start
                if [ $? -ne 0 ];then
                    tsGetMessage.sh RFID05042E "DB2"
                    exit $FALSE
                fi
			else
				#echo "Starting DB2 failed because RBDMS was not found in $DBMS_HOME" 
				tsGetMessage.sh RFID05226E "DB2" "$DBMS_HOME"
				exit $FALSE
			fi
			return
		fi
	else
		tsGetMessage.sh TSIN01304I
		#echo "\nDB2 - Already running"
	fi
}

startCAPTURE()
{
	echo "========================================="
	#Start the listener 
	tsGetMessage.sh RFID05088I
	
    getWAScredentials
    
    isWASRunning
    wasRunning=$?
    
    if [ "$wasRunning" == "$TRUE" ];then    
        RFIDIC_PROPS_FILE=/tmp/startCap.$$
        writeProperties
        ${WAS_PROFILE_HOME}/bin/wsadmin.sh -wsadmin_classpath ${WSADMIN_JARS_PATH} -lang jython ${credentials} -f ${RFIDIC_HOME}/bin/jython/startMessageEndpoints.py ${RFIDIC_PROPS_FILE} ${RFIDIC_HOME}/bin/jython start
        captureStatus=$?

        /bin/rm -f ${RFIDIC_PROPS_FILE}

        if [ "$captureStatus" -eq "0" ]; then
            tsGetMessage.sh RFID05089I
        else
            tsGetMessage.sh RFID05113I
            tsGetMessage.sh RFID05042E "capture"
            exit $FALSE
        fi
    else
        tsGetMessage.sh RFID97082I
    fi
}

startWAS()
{
	echo "========================================="
    getWAScredentials
	# Checking WAS
	if [ -z "$CLUSTERNAME" ];then
        serverStatus=`${WAS_PROFILE_HOME}/bin/serverStatus.sh $SERVERNAME ${credentials}`
		present=`echo "$serverStatus" | grep "ADMU0508I"`
		status=$?
		if [ $status = 0 ];then
			tsGetMessage.sh TSIN01305I
			#echo "\nWAS - Already running"
		else
			if [ -d "$WAS_PROFILE_HOME" ];then
				tsGetMessage.sh RFID05046I
                if [ -n "$was_runas_user" ];then
                    runCommandAsUser $was_runas_user:$sudo_password ${WAS_PROFILE_HOME}/bin/startServer.sh $SERVERNAME
                else
                    ${WAS_PROFILE_HOME}/bin/startServer.sh $SERVERNAME
                fi
    
                if [ $? -ne 0 ];then
                    tsGetMessage.sh RFID05042E "WebSphere Application Server"
                    exit $FALSE
                fi
			else
				tsGetMessage.sh RFID05048I "$WAS_HOME"
			fi
			return
		fi
	else
		RFIDIC_PROPS_FILE=/tmp/startWAS.$$
		writeProperties
		${WAS_PROFILE_HOME}/bin/wsadmin.sh -wsadmin_classpath ${WSADMIN_JARS_PATH} -lang jython ${credentials} -f ${RFIDIC_HOME}/bin/jython/startServers.py ${RFIDIC_PROPS_FILE} ${RFIDIC_HOME}/bin/jython $dev_mode
        wasStatus=$?
		/bin/rm -f ${RFIDIC_PROPS_FILE}
        if [ $wasStatus -ne 0 ];then
            tsGetMessage.sh RFID05042E "WebSphere Application Server"
            exit $FALSE
        fi
	fi
	sleep 1
}

# This function can only be called once per running instance of this script.
startApps()
{
    if [ -z "$appsAreStarted" ];then
        appsAreStarted=$TRUE

        echo "========================================="
        tsGetMessage.sh RFID05071I

        getWAScredentials

        isWASRunning
        wasRunning=$?
    
        if [ "$wasRunning" == "$TRUE" ];then    
            RFIDIC_PROPS_FILE=/tmp/startApps.$$
            writeProperties
            appName=$1
            getWAScredentials
            ${WAS_PROFILE_HOME}/bin/wsadmin.sh -wsadmin_classpath ${WSADMIN_JARS_PATH} -lang jython ${credentials} -f ${RFIDIC_HOME}/bin/jython/startApplications.py ${RFIDIC_PROPS_FILE} ${RFIDIC_HOME}/bin/jython $*
            appsStatus=$?
            /bin/rm -f ${RFIDIC_PROPS_FILE}

            if [ $appsStatus -ne 0 ];then
                tsGetMessage.sh RFID05268E
                exit $FALSE
            fi
        else
            tsGetMessage.sh RFID97082I
        fi
    fi
}

# main processing
components="$DB_TYPE,MQ,WAS,CAPTURE,ENGINE,UI,SERIALID"

for item in $@
do
	if [ `echo $item | wc -c` = 2 ];then
		usage
		exit -1
	elif [ `expr match "$item" '-components='` != 0 ];then
        tsGetMessage.sh RFID05073I
        sleep 2
		components=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-was_runas_user='` != 0 ];then
		was_runas_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-sudo_password='` != 0 ];then
		sudo_password=`echo ${item#-sudo_password=}`
	elif [ `expr match "$item" '-was_admin_user='` != 0 ];then
		was_admin_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-was_admin_password='` != 0 ];then
		was_admin_password=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-force_stop'` != 0 ];then
		force_stop=true
	elif [ `expr match "$item" '-dev_mode'` != 0 ];then
		dev_mode=true
	elif [ `expr match "$item" '-help'` != 0 ];then
		usage
		exit -1
	else
		usage
		exit -1
	fi
done

getActualWASConfig

if [ -n "$force_stop" ];then
    if [ -n "$dev_mode" ];then
        stopCmd="$RFIDIC_HOME/bin/stopTS.sh -dev_mode"
    else
        stopCmd="$RFIDIC_HOME/bin/stopTS.sh"
    fi

    stopCmd="$stopCmd -components=$components"
    
    if [ -n "$was_admin_user" ];then
        stopCmd="$stopCmd -was_admin_user=$was_admin_user"
    fi

    if [ -n "$was_admin_password" ];then
        stopCmd="$stopCmd -was_admin_password=$was_admin_password"
    fi

    $stopCmd
    retcode=$?
	
    if [ "$retcode" -lt 0 ];then
        usage
        exit -1
    fi
fi

#Making input case neutral and ensuring the components are started in the right order
components=`echo "$components" |tr "[a-z]" "[A-Z]"`
components=`echo "$components" | sed "s/ORACLE/AORACLE/g"`
components=`echo "$components" | sed "s/ENGINE/WASA_ENGINE/g"`
components=`echo "$components" | sed "s/UI/WASB_UI/g"`
components=`echo "$components" | sed "s/SERIALID/WASC_SERIALID/g"`
components=`echo "$components" | sed "s/CAPTURE/WASD_CAPTURE/g"`

components=`echo "$components" | tr "," "\n" | sort`
components=`echo "$components" | sed "s/AORACLE/ORACLE/g"`
components=`echo "$components" | sed "s/WASA_ENGINE/ENGINE/g"`
components=`echo "$components" | sed "s/WASB_UI/UI/g"`
components=`echo "$components" | sed "s/WASC_SERIALID/SERIALID/g"`
components=`echo "$components" | sed "s/WASD_CAPTURE/CAPTURE/g"`

comp=`echo $components|sed "s/ /|/g"`
tsGetMessage.sh RFID05036I "$comp"

appList=""

for item in $components
do
    case "$item" in
        DB)
            ;;
        ORACLE)
            ;;
        DB2)
            ;;
        MQ)
            ;;
        WAS)
            ;;
        CAPTURE)
            ;;
        ENGINE)
            appList="$appList $CPAPP_NAME"
            ;;
        UI)
            appList="$appList $UIAPP_NAME"
            ;;
        SERIALID)
            appList="$appList $SIDAPP_NAME"
            ;;
    esac
done

for item in $components
do
	case "$item" in
		DB)
			case "$DB_TYPE" in
				ORACLE)
					startOracle
					;;
				DB2)
					startDB2
					;;
			esac;;
		ORACLE)
			startOracle
			;;
		DB2)
			startDB2
			;;
		MQ)
			startMQ
			;;
		WAS)
			startWAS
			;;
		CAPTURE)
			startCAPTURE
			;;
        ENGINE|UI|SERIALID)
            startApps $appList
            ;;
		*)
			tsGetMessage.sh RFID05037I $item
	esac
done	
