#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
#
# 
# updateEnv.sh -  (DESIGNED FOR LAUNCHPAD) updates tsEnv.sh and rfidicServer.xml file with new values [DB,MQ,WAS]
###############################################################################################################

sDir=`dirname ${0}`
. $sDir/utils.sh

ECHO="echo"

AWK="awk -F ".""
PLATFORM=`/bin/uname`
	case $PLATFORM in
	SunOS)
		AWK="awk -F."
		;;
	esac

run_command ()
{
	command="$*"
	"$@"
	retcode=$?
	if [ "$retcode" -ne 0 ]
	then	
		getMessage RFID05138E "$command"
        $ECHO $msg
		return $retcode
	fi
}

updateTableSpace()
{
    grep "DBTableSpace" ${TS_HOME}/etc/RFIDICServer.xml >> /dev/null
    if [ $? -ne 0 -a -n "$1" ];then
        sed '/<\/Database>/ i\
        <DBTableSpace>'$1'</DBTableSpace>' ${TS_HOME}/etc/RFIDICServer.xml > /tmp/RFIDICServer.xml.$$
        sedRC=$?
    else
        if [ -n "$1" ];then
            sed 's/<DBTableSpace>*.*<\/DBTableSpace>/<DBTableSpace>'$1'<\/DBTableSpace>/' ${TS_HOME}/etc/RFIDICServer.xml > /tmp/RFIDICServer.xml.$$
            sedRC=$?
        else
            sed '/<DBTableSpace>*.*<\/DBTableSpace>/d' ${TS_HOME}/etc/RFIDICServer.xml > /tmp/RFIDICServer.xml.$$
            sedRC=$?
        fi
    fi

    if [ $sedRC -eq 0 ];then
        cp /tmp/RFIDICServer.xml.$$ ${TS_HOME}/etc/RFIDICServer.xml
        rm -f /tmp/RFIDICServer.xml.$$
    fi

    return $sedRC
}

asciiUpdate()
{
    # Takes an array of search and replace strings for a file, constructs the sed script and performs the update on the file
    index=0
    searchStr=$2
    replaceStr=$3
    count=${#searchStr[*]}
    command="{\n"
    while [ "$index" -lt "$count" ]
    do
        command=$command"s%"${searchStr[$index]}"%"${replaceStr[$index]}"%g\n"
        index=`expr $index + 1`
    done
    command=$command"}"
    $ECHO $command > $1.sed
    run_command sed -f $1.sed $1 > $1.tmp
    sedReturnCode=$?

    if [ $? -eq 0 ];then
        run_command mv -f $1.tmp $1
    else
        rm -f $1.tmp
    fi

    run_command rm -f $1.sed
    unset searchStr
    unset replaceStr

    return $sedReturnCode
}


usage(){
	echo "	USAGE: ./update-env.sh"
	echo "                          [-TS_HOME=<TS_HOME value>]"
	echo "                          [-DB_TYPE=<value>]"
	echo "                          [-DBMS_HOME=<Path where the DB is installed>]"
	echo "                          [-DBMS_HOST=<value>]"
	echo "                          [-DBMS_ADMIN_USER=<value>]"
	echo "                          [-DBMS_ADMIN_PASSWORD=<value>]"
	echo "                          [-DBMS_PORT_NUMBER=<queue manager name>]"
	echo "                          [-DB2_INSTANCE=<value>]"
	echo "                          [-DB2_INSTANCE_OWNER=<value>]"
	echo "                          [-DBMS_DB_NAME=<value>]"
	echo "                          [-DBMS_TABLE_SPACE=<value>]"
	echo "                          [-DBMS_JDBC_LIB_PATH=<value>]"
	echo "                          [-ORACLE_OWNER=<value>]"
	echo "                          [-ORACLE_GROUP=<value>]"
	echo "                          [-ORACLE_JDBC_URL=<value of listener port>]"
	return 1
}

updateDB2()
{
	getMessage TSIN02263I
	echo $msg
	#echo "updating tsEnv.sh file"
	
	searchStr[0]='DB_TYPE=.*'
	searchStr[1]='DBMS_HOME=.*'
	searchStr[2]='DBMS_ADMIN_USER=.*'
	searchStr[3]='DBMS_PORT_NUMBER=.*'
	searchStr[4]='DBMS_HOST=.*'
	searchStr[5]='DB2_INSTANCE=.*'
	searchStr[6]='DB2_INSTANCE_OWNER=.*'
	searchStr[7]='DBMS_DB_NAME=.*'
	searchStr[8]='DBMS_JDBC_LIB_PATH=.*'
	
	replaceStr[0]="DB_TYPE=$DB_TYPE"
	replaceStr[1]="DBMS_HOME=$DBMS_HOME"
	replaceStr[2]="DBMS_ADMIN_USER=$DBMS_ADMIN_USER"
	replaceStr[3]="DBMS_PORT_NUMBER=$DBMS_PORT_NUMBER"
	replaceStr[4]="DBMS_HOST=$DBMS_HOST"
	replaceStr[5]="DB2_INSTANCE=$DB2_INSTANCE"
	replaceStr[6]="DB2_INSTANCE_OWNER=$DB2_INSTANCE_OWNER"
	replaceStr[7]="DBMS_DB_NAME=$DBMS_DB_NAME"
	replaceStr[8]="DBMS_JDBC_LIB_PATH=$DBMS_JDBC_LIB_PATH"
		
	asciiUpdate "${TS_HOME}/bin/tsEnv.sh" $searchStr $replaceStr
    tsEnvCode=$?
    
	chown $TS_ADMIN_USER:$TS_ADMIN_GROUP ${TS_HOME}/bin/tsEnv.sh
  	run_command chmod 750 ${TS_HOME}/bin/tsEnv.sh

	getMessage TSIN02263I
	echo $msg
	#echo "updating rfidicServer.xml file"
	
	searchStr[0]='<DBMS>*.*</DBMS>'
	searchStr[1]='<UserID>*.*</UserID>'
	searchStr[2]='<Passwor[A-Za-z0-9=\ ]*>*.*</Password>'
	searchStr[3]='<DatabaseName>*.*</DatabaseName>'
	searchStr[4]='<Hostname>*.*</Hostname>'
	searchStr[5]='<Portnumber>*.*</Portnumber>'
	
	replaceStr[0]="<DBMS>$DB_TYPE</DBMS>"
	replaceStr[1]="<UserID>$DBMS_ADMIN_USER</UserID>"
	replaceStr[2]="<Password enctype=\"b5\">$ENCRYPTED_DB_PASSWORD</Password>"
	replaceStr[3]="<DatabaseName>$DBMS_DB_NAME</DatabaseName>"
	replaceStr[4]="<Hostname>$DBMS_HOST</Hostname>"
	replaceStr[5]="<Portnumber>$DBMS_PORT_NUMBER</Portnumber>"
		
	asciiUpdate "${TS_HOME}/etc/RFIDICServer.xml" $searchStr $replaceStr
    rfidicServerCode=$?

    updateTableSpace "${DBMS_TABLE_SPACE}"
    tableSpaceCode=$?

	chown $TS_ADMIN_USER:$TS_ADMIN_GROUP ${TS_HOME}/etc/RFIDICServer.xml
  	run_command chmod 640 ${TS_HOME}/etc/RFIDICServer.xml

    if [ $tsEnvCode -eq 0 -a $rfidicServerCode -eq 0 -a $tableSpaceCode -eq 0 ];then
        return 0
    else
        return 1
    fi
}

updateOracle()
{
	getMessage TSIN02263I
	echo $msg
	#echo "updating tsEnv.sh file"
	
	searchStr[0]='DB_TYPE=.*'
	searchStr[1]='DBMS_HOME=.*'
	searchStr[2]='DBMS_ADMIN_USER=.*'
	searchStr[3]='DBMS_PORT_NUMBER=.*'
	searchStr[4]='DBMS_HOST=.*'
	searchStr[5]='ORACLE_OWNER=.*'
	searchStr[6]='ORACLE_GROUP=.*'
	searchStr[7]='ORACLE_JDBC_URL=.*'
	searchStr[8]='DBMS_DB_NAME=.*'
	searchStr[9]='DBMS_JDBC_LIB_PATH=.*'
	
	replaceStr[0]="DB_TYPE=$DB_TYPE"
	replaceStr[1]="DBMS_HOME=$DBMS_HOME"
	replaceStr[2]="DBMS_ADMIN_USER=$DBMS_ADMIN_USER"
	replaceStr[3]="DBMS_PORT_NUMBER=$DBMS_PORT_NUMBER"
	replaceStr[4]="DBMS_HOST=$DBMS_HOST"
	replaceStr[5]="ORACLE_OWNER=$ORACLE_OWNER"
	replaceStr[6]="ORACLE_GROUP=$ORACLE_GROUP"
	replaceStr[7]="ORACLE_JDBC_URL=$ORACLE_JDBC_URL"
	replaceStr[8]="DBMS_DB_NAME=$DBMS_DB_NAME"
	replaceStr[9]="DBMS_JDBC_LIB_PATH=$DBMS_JDBC_LIB_PATH"
		
	asciiUpdate "${TS_HOME}/bin/tsEnv.sh" $searchStr $replaceStr
    tsEnvCode=$?

	chown $TS_ADMIN_USER:$TS_ADMIN_GROUP ${TS_HOME}/bin/tsEnv.sh
  	run_command chmod 750 ${TS_HOME}/bin/tsEnv.sh

	getMessage TSIN02263I
	echo $msg
	#echo "updating rfidicServer.xml file"
	
	searchStr[0]='<DBMS>*.*</DBMS>'
	searchStr[1]='<UserID>*.*</UserID>'
	searchStr[2]='<Passwor[A-Za-z0-9=\ ]*>*.*</Password>'
	searchStr[3]='<DatabaseName>*.*</DatabaseName>'
	searchStr[4]='<Hostname>*.*</Hostname>'
	searchStr[5]='<Portnumber>*.*</Portnumber>'
	
	replaceStr[0]="<DBMS>Oracle</DBMS>"
	replaceStr[1]="<UserID>$DBMS_ADMIN_USER</UserID>"
	replaceStr[2]="<Password enctype=\"b5\">$ENCRYPTED_DB_PASSWORD</Password>"
	replaceStr[3]="<DatabaseName>$DBMS_DB_NAME</DatabaseName>"
	replaceStr[4]="<Hostname>$DBMS_HOST</Hostname>"
	replaceStr[5]="<Portnumber>$DBMS_PORT_NUMBER</Portnumber>"
		
	asciiUpdate "${TS_HOME}/etc/RFIDICServer.xml" $searchStr $replaceStr
    rfidicServerCode=$?

    updateTableSpace "${DBMS_TABLE_SPACE}"
    tableSpaceCode=$?

    chown $TS_ADMIN_USER:$TS_ADMIN_GROUP ${TS_HOME}/etc/RFIDICServer.xml
  	run_command chmod 640 ${TS_HOME}/etc/RFIDICServer.xml

    if [ $tsEnvCode -eq 0 -a $rfidicServerCode -eq 0 -a $tableSpaceCode -eq 0 ];then
        return 0
    else
        return 1
    fi
}

updateMQPassword()
{
    if [ -n "$MQ_USER_PASSWORD" ];then
        rawPass=`${TS_HOME}/bin/encryptOnce.sh $MQ_USER_PASSWORD`
        printf "%s\n" $rawPass | sed "s/[^A-Za-z0-9]/\\\&/g" > 1.$$
        ENCRYPTED_MQ_PASSWORD=`cat 1.$$`
        rm -f 1.$$

        cp ${TS_HOME}/etc/RFIDICServer.xml /tmp/RFIDICServer.xml.bak

        sed '/Principal/d' ${TS_HOME}/etc/RFIDICServer.xml > /tmp/RFIDICServer.xml.$$
        cp /tmp/RFIDICServer.xml.$$ ${TS_HOME}/etc/RFIDICServer.xml
        rm -f /tmp/RFIDICServer.xml.$$

        sed 's#</tns:MQQueue>#<Principal username="'$MQ_USER'" password="'$ENCRYPTED_MQ_PASSWORD'" enctype="b5" />\
            </tns:MQQueue>#' ${TS_HOME}/etc/RFIDICServer.xml > /tmp/RFIDICServer.xml.$$
        cp /tmp/RFIDICServer.xml.$$ ${TS_HOME}/etc/RFIDICServer.xml
        rm -f /tmp/RFIDICServer.xml.$$
    fi
}

updateMQ()
{
	getMessage TSIN02263I
	echo $msg
	#echo "updating tsEnv.sh file"
	
	searchStr[0]='MQ_HOST=.*'
	searchStr[1]='MQ_HOME=.*'
	searchStr[2]='QUEUE_MANAGER=.*'
	searchStr[3]='MQ_LOG_FILE_PAGES=.*'
	searchStr[4]='MQ_LOG_TYPE=.*'
	searchStr[5]='MQ_LOG_PRIMARY_FILES=.*'
	searchStr[6]='MQ_LOG_SECONDARY_FILES=.*'
	searchStr[7]='MQ_TS_CHANNEL=.*'
	searchStr[8]='QUEUE_NAME=.*'
	searchStr[9]='ALERTS_ENGINE_INPUT_QUEUE_NAME=.*'
	searchStr[10]='MDM_CHANGE_NOTIF_QUEUE_NAME=.*'
	searchStr[11]='AS2DELIVERY_QUEUE_NAME=.*'
	searchStr[12]='AS2REQUEST_QUEUE_NAME=.*'
	searchStr[13]='AS2RESPONSE_QUEUE_NAME=.*'
	searchStr[14]='CAPTURE_NOTIF_QUEUE_NAME=.*'
	searchStr[15]='MQ_LSR_PORT=.*'
	searchStr[16]='MQ_USER=.*'
	
	if [ -n "$QUEUE_MANAGER_TYPE" ];then
		searchStr[17]='MQ_CLUSTER=.*'
		searchStr[18]='R_QUEUE_MANAGER=.*'
		searchStr[19]='R_MQ_HOST=.*'
		searchStr[20]='R_MQ_LSR_PORT=.*'
	fi

	replaceStr[0]="MQ_HOST=$MQ_HOST"
	replaceStr[1]="MQ_HOME=$MQ_HOME"
	replaceStr[2]="QUEUE_MANAGER=$QUEUE_MANAGER"
	replaceStr[3]="MQ_LOG_FILE_PAGES=$MQ_LOG_FILE_PAGES"
	replaceStr[4]="MQ_LOG_TYPE=$MQ_LOG_TYPE"
	replaceStr[5]="MQ_LOG_PRIMARY_FILES=$MQ_LOG_PRIMARY_FILES"
	replaceStr[6]="MQ_LOG_SECONDARY_FILES=$MQ_LOG_SECONDARY_FILES"
	replaceStr[7]="MQ_TS_CHANNEL=$MQ_TS_CHANNEL"
	replaceStr[8]="QUEUE_NAME=$QUEUE_NAME"
	replaceStr[9]="ALERTS_ENGINE_INPUT_QUEUE_NAME=$ALERTS_ENGINE_INPUT_QUEUE_NAME"
	replaceStr[10]="MDM_CHANGE_NOTIF_QUEUE_NAME=$MDM_CHANGE_NOTIF_QUEUE_NAME"
	replaceStr[11]="AS2DELIVERY_QUEUE_NAME=$AS2DELIVERY_QUEUE_NAME"
	replaceStr[12]="AS2REQUEST_QUEUE_NAME=$AS2REQUEST_QUEUE_NAME"
	replaceStr[13]="AS2RESPONSE_QUEUE_NAME=$AS2RESPONSE_QUEUE_NAME"
	replaceStr[14]="CAPTURE_NOTIF_QUEUE_NAME=$CAPTURE_NOTIF_QUEUE_NAME"
	replaceStr[15]="MQ_LSR_PORT=$MQ_LSR_PORT"
	replaceStr[16]="MQ_USER=$MQ_USER"
	
	if [ -n "$QUEUE_MANAGER_TYPE" ];then
		replaceStr[17]="MQ_CLUSTER=$MQ_CLUSTER"
		replaceStr[18]="R_QUEUE_MANAGER=$R_QUEUE_MANAGER"
		replaceStr[19]="R_MQ_HOST=$R_MQ_HOST"
		replaceStr[20]="R_MQ_LSR_PORT=$R_MQ_LSR_PORT"
	fi
	
	asciiUpdate "${TS_HOME}/bin/tsEnv.sh" $searchStr $replaceStr
    tsEnvCode=$?

	chown $TS_ADMIN_USER:$TS_ADMIN_GROUP ${TS_HOME}/bin/tsEnv.sh
	run_command chmod 750 ${TS_HOME}/bin/tsEnv.sh
    
	#only update RFIDICServer.xml file when its either partial in mqha or nonHA
    rfidicServerCode=0
	if [ -n "$QUEUE_MANAGER_TYPE" ];then	#called using HA-FULL
		getMessage TSIN02266I
		echo $msg
		#echo "RFIDICServer.xml is not updated for full repositories"		
	else
        updateMQPassword
        
		searchStr[0]='<QueueManagerName>*.*</QueueManagerName>'
		replaceStr[0]="<QueueManagerName>$MQ_HOST:$MQ_LSR_PORT</QueueManagerName>"
		asciiUpdate "${TS_HOME}/etc/RFIDICServer.xml" $searchStr $replaceStr
        rfidicServerCode=$?

		chown $TS_ADMIN_USER:$TS_ADMIN_GROUP ${TS_HOME}/etc/RFIDICServer.xml
  		run_command chmod 640 ${TS_HOME}/etc/RFIDICServer.xml
	fi

	chown $TS_ADMIN_USER:$TS_ADMIN_GROUP ${TS_HOME}/etc/RFIDICServer.xml
  	run_command chmod 640 ${TS_HOME}/etc/RFIDICServer.xml

	getMessage TSIN02267I
	echo $msg
	#echo "mq parameters updated"

    if [ $tsEnvCode -eq 0 -a $rfidicServerCode -eq 0 ];then
        return 0
    else
        return 1
    fi
}

updateWAS()
{
	getMessage TSIN02263I
	echo $msg
	#echo "updating tsEnv.sh file"
	
	searchStr[0]='WAS_HOME=.*'
	searchStr[1]='WAS_PROFILE=.*'
	searchStr[2]='WAS_PORT_NO=.*'
	searchStr[3]='SERVERNAME=.*'
	searchStr[4]='NODENAME=.*'
	searchStr[5]='CELLNAME=.*'
	searchStr[6]='CLUSTERNAME=.*'
	searchStr[7]='RFIDIC_BUS_NAME=.*'
	searchStr[8]='was_runas_user=.*'
	searchStr[9]='was_runas_group=.*'
	searchStr[10]='was_admin_user=.*'
	searchStr[11]='was_admin_group=.*'
	searchStr[12]='RFIDIC_FILE_STORE=.*'
	
	replaceStr[0]="WAS_HOME=$WAS_HOME"
	replaceStr[1]="WAS_PROFILE=$WAS_PROFILE"
	replaceStr[2]="WAS_PORT_NO=$WAS_PORT_NO"
	replaceStr[3]="SERVERNAME=$SERVERNAME"
	replaceStr[4]="NODENAME=$NODENAME"
	replaceStr[5]="CELLNAME=$CELLNAME"
	replaceStr[6]="CLUSTERNAME=$CLUSTERNAME"
	replaceStr[7]="RFIDIC_BUS_NAME=$RFIDIC_BUS_NAME"
	replaceStr[8]="was_runas_user=$was_runas_user"
	replaceStr[9]="was_runas_group=$was_runas_group"
	replaceStr[10]="was_admin_user=$was_admin_user"
	replaceStr[11]="was_admin_group=$was_admin_group"
	replaceStr[12]="RFIDIC_FILE_STORE=$RFIDIC_FILE_STORE"
		
	asciiUpdate "${TS_HOME}/bin/tsEnv.sh" $searchStr $replaceStr
    tsEnvCode=$?

	chown $TS_ADMIN_USER:$TS_ADMIN_GROUP ${TS_HOME}/bin/tsEnv.sh
	run_command chmod 750 ${TS_HOME}/bin/tsEnv.sh
	
	getMessage TSIN02268I
	echo $msg
	#echo "WAS parameters updated"

    if [ $tsEnvCode -eq 0 ];then
        return 0
    else
        return 1
    fi
}

for item in $@
do
	if [ `expr match "$item" '-TS_HOME='` != 0 ];then
		TS_HOME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
    elif [ `expr match "$item" '-TS_ADMIN_USER='` != 0 ];then
        TS_ADMIN_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
    elif [ `expr match "$item" '-TS_ADMIN_PASSWORD='` != 0 ];then
        TS_ADMIN_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-CONFIG_TYPE='` != 0 ];then
		CONFIG_TYPE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-DB_TYPE='` != 0 ];then
		DB_TYPE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-DBMS_HOST='` != 0 ];then
		DBMS_HOST=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-DBMS_HOME='` != 0 ];then
		DBMS_HOME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-DBMS_ADMIN_USER='` != 0 ];then
		DBMS_ADMIN_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-DBMS_ADMIN_PASSWORD='` != 0 ];then
		DBMS_ADMIN_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-DBMS_PORT_NUMBER='` != 0 ];then
		DBMS_PORT_NUMBER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-DB2_INSTANCE='` != 0 ];then
		DB2_INSTANCE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-DB2_INSTANCE_OWNER='` != 0 ];then
		DB2_INSTANCE_OWNER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-DBMS_DB_NAME='` != 0 ];then
		DBMS_DB_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-DBMS_TABLE_SPACE='` != 0 ];then
		DBMS_TABLE_SPACE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-DBMS_JDBC_LIB_PATH='` != 0 ];then
		DBMS_JDBC_LIB_PATH=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-ORACLE_OWNER='` != 0 ];then
		ORACLE_OWNER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-ORACLE_GROUP='` != 0 ];then
		ORACLE_GROUP=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-ORACLE_JDBC_URL='` != 0 ];then
		ORACLE_JDBC_URL=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-RESULT='` != 0 ];then
		RESULT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-SCRIPT_DIR='` != 0 ];then
		SCRIPT_DIR=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_HOST='` != 0 ];then
		MQ_HOST=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_HOME='` != 0 ];then
		MQ_HOME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-QUEUE_MANAGER='` != 0 ];then
		QUEUE_MANAGER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_LOG_FILE_PAGES='` != 0 ];then
		MQ_LOG_FILE_PAGES=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_LOG_TYPE='` != 0 ];then
		MQ_LOG_TYPE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_LOG_PRIMARY_FILES='` != 0 ];then
		MQ_LOG_PRIMARY_FILES=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_LOG_SECONDARY_FILES='` != 0 ];then
		MQ_LOG_SECONDARY_FILES=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_TS_CHANNEL='` != 0 ];then
		MQ_TS_CHANNEL=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-QUEUE_NAME='` != 0 ];then
		QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-ALERTS_ENGINE_INPUT_QUEUE_NAME='` != 0 ];then
		ALERTS_ENGINE_INPUT_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MDM_CHANGE_NOTIF_QUEUE_NAME='` != 0 ];then
		MDM_CHANGE_NOTIF_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-AS2DELIVERY_QUEUE_NAME='` != 0 ];then
		AS2DELIVERY_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-AS2REQUEST_QUEUE_NAME='` != 0 ];then
		AS2REQUEST_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-AS2RESPONSE_QUEUE_NAME='` != 0 ];then
		AS2RESPONSE_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-CAPTURE_NOTIF_QUEUE_NAME='` != 0 ];then
		CAPTURE_NOTIF_QUEUE_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_LSR_PORT='` != 0 ];then
		MQ_LSR_PORT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_USER='` != 0 ];then
		MQ_USER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_USER_PASSWORD='` != 0 ];then
		MQ_USER_PASSWORD=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-QUEUE_MANAGER_TYPE='` != 0 ];then
        QUEUE_MANAGER_TYPE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-MQ_CLUSTER='` != 0 ];then
        MQ_CLUSTER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-R_MQ_HOST='` != 0 ];then
        R_MQ_HOST=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-R_QUEUE_MANAGER='` != 0 ];then
        R_QUEUE_MANAGER=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-R_MQ_LSR_PORT='` != 0 ];then
        R_MQ_LSR_PORT=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-WAS_HOME='` != 0 ];then
		WAS_HOME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-WAS_PROFILE='` != 0 ];then
		WAS_PROFILE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-WAS_PORT_NO='` != 0 ];then
		WAS_PORT_NO=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-SERVERNAME='` != 0 ];then
		SERVERNAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-NODENAME='` != 0 ];then
		NODENAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-CELLNAME='` != 0 ];then
		CELLNAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-CLUSTERNAME='` != 0 ];then
		CLUSTERNAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-was_runas_user'` != 0 ];then
		was_runas_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-was_runas_group'` != 0 ];then
		was_runas_group=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-was_admin_user'` != 0 ];then
		was_admin_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-was_admin_group'` != 0 ];then
		was_admin_group=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-RFIDIC_BUS_NAME='` != 0 ];then
		RFIDIC_BUS_NAME=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-RFIDIC_FILE_STORE='` != 0 ];then
		RFIDIC_FILE_STORE=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
	elif [ `expr match "$item" '-help'` != 0 ];then
		usage 
		exit
	else
		getMessage TSIN02215I
		echo $msg
		#echo "Unidentified argument passed"
		usage 
		exit
    fi

done

echo "TS_HOME: ${TS_HOME}"
. ${TS_HOME}/bin/tsEnv.sh


#now we have got all the variables, we ascii update the required files
returnCode=0
if [ "$CONFIG_TYPE" = "DB" ];then
	getMessage TSIN02269I
	echo $msg
	#echo "Updating the database server parameters"

    if [ -n "$DBMS_ADMIN_PASSWORD" ];then
        rawPass=`${TS_HOME}/bin/encryptOnce.sh $DBMS_ADMIN_PASSWORD`
        # Double escape of the backslash needed since it needs to run through asciiUpdate after this.
        printf "%s\n" $rawPass | sed "s/\\\\/\\\\\\\\/g" | sed "s/[^A-Za-z0-9]/\\\&/g" > 1.$$
        ENCRYPTED_DB_PASSWORD=`cat 1.$$`
        rm -f 1.$$
    fi

	if [ "$DB_TYPE" = "DB2" ];then
		updateDB2
        returnCode=$?
	else
		updateOracle
        returnCode=$?
	fi
elif [ "$CONFIG_TYPE" = "MQ" ];then
	if [ "$QUEUE_MANAGER_TYPE" = "PARTIAL" ];then
		getMessage TSIN02270I
		echo $msg
		#echo "updating RFIDICServer.xml with partial repository details"

        updateMQPassword
        returnCode=$?

        if [ $returnCode -eq 0 ];then
            searchStr[0]='<QueueManagerName>*.*</QueueManagerName>'
            replaceStr[0]="<QueueManagerName>$MQ_HOST:$MQ_LSR_PORT</QueueManagerName>"
            asciiUpdate "${TS_HOME}/etc/RFIDICServer.xml" $searchStr $replaceStr
            returnCode=$?
            chown $TS_ADMIN_USER:$TS_ADMIN_GROUP ${TS_HOME}/etc/RFIDICServer.xml
            run_command chmod 640 ${TS_HOME}/etc/RFIDICServer.xml
        fi
	else
		updateMQ
        returnCode=$?
	fi
elif [ "$CONFIG_TYPE" = "WAS" ];then
	updateWAS
    returnCode=$?
fi

if [ $returnCode -eq 0 ];then
	echo "SUCCESS"
	if [ ! -z "$RESULT" ];then
		$ECHO "SUCCESS" >> $RESULT
	fi
fi
exit $returnCode