#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
#
# utils.sh - utility methods
#########################################################################

# Jump to the bottom to find the executable part of this script

log()
{
    $ECHO $* >> $utilsLogFile
	
	if [ "$isVerbose" -eq "$TRUE" ];then
		$ECHO $*
	fi
}

getIPAddress()
{
    unset returnString

    hostName=$1

    if [ -z "$hostName" ];then
        hostName=$HOSTNAME
    fi

    if [ "$PLATFORM" = "AIX" ];then
        IP=`host -n -t A $hostName`
        if [ $? = 0 ];then
            IP=`echo $IP | awk '{print($4)}'`
        else
            IP=127.0.0.1
        fi
    elif [ "$PLATFORM" = "Linux" ];then
        IP=`host $hostName`
        if [ $? = 0 ];then
            IP=`echo $IP | awk '{print($4)}'`
        else
            IP=127.0.0.1
        fi
    elif [ "$PLATFORM" = "SunOS" ];then
        IP=`getent hosts $hostName`
        if [ $? = 0 ];then
            IP=`echo $IP | awk '{print($1)}'`
        else
            IP=127.0.0.1
        fi
    fi

    returnString=$IP
}

# Takes an argument of hostname or IP address. Returns 1 if the hostname matches this machine, otherwise returns 0.
isHostnameRemote()
{
    host=$1
    
    if [ -z "$host" ];then
        return $FALSE
    fi
	
	getIPAddress
    
    if [ "$host" = "$HOSTNAME" -o "$host" = "$HOSTNAMEFULL" -o "$host" = "$returnString" ];then
        return $FALSE
    else
        return $TRUE
    fi
}

asciiUpdate()
{
    # Takes an array of search and replace strings for a file, constructs the sed script and performs the update on the file
    index=0
    searchStr=$2
    replaceStr=$3
    count=${#searchStr[*]}
    command="{\n"
    while [ "$index" -lt "$count" ]
    do
        command=$command"s%"${searchStr[$index]}"%"${replaceStr[$index]}"%g\n"
        index=`expr $index + 1`
    done
    command=$command"}"
    $ECHO $command > $1.sed
    run_command sed -f $1.sed $1 > $1.tmp
    sedReturnCode=$?

    if [ $? -eq 0 ];then
        run_command mv -f $1.tmp $1
    else
        rm -f $1.tmp
    fi

    run_command rm -f $1.sed
    unset searchStr
    unset replaceStr

    return $sedReturnCode
}

getDiskSpace()
{
	unset returnString
	
	directoryName=$1
	
	if [ -z "$directoryName" ];then
		directoryName="/"
	fi
	
	if [ "$PLATFORM" = "SunOS" ];then
		DF_OPTIONS="-k"
	else
		DF_OPTIONS="-Pk"
	fi
	
	returnString=`df $DF_OPTIONS "$directoryName" | ${TAIL}1 | awk '{ print $4 }'`
}

getMessageClasspath()
{
	unset returnString
	
	if [ -z "$message_classpath" ];then
		#Set the message_classpath since it's not set.
		unset tsHome
	
		if [ -z "$TS_HOME" ];then
			if [ -n "$WAS_HOME" -a -d "$WAS_HOME/ts" ];then
				#If WAS_HOME is available, we can try to guess the TS_HOME directory. Set it if it exists.
				tsHome="$WAS_HOME/ts"
			fi
		else
			tsHome="$TS_HOME"
		fi
		
		if [ -n "$tsHome" ];then
			message_classpath="$tsHome/lib/com.ibm.rfidic.messages.jar:$tsHome/lib/com.ibm.rfidic.utils.messages.jar:$tsHome/lib/com.ibm.rfidic.utils.jar:$tsHome/lib/com.ibm.imc.algorithms.jar:$tsHome/lib/commons-lang-2.4.jar:$tsHome/lib/icu4j-4_4_1.jar:$tsHome/lib/commons-lang-2.4.jar:$tsHome/lib/icu4j-charsets-4_4_1.jar:$tsHome/lib/commons-lang-2.4.jar:$tsHome/lib/icu4j-localespi-4_4_1.jar"
		fi
	fi
	
	returnString=$message_classpath
}

getMessage()
{
	msg=""
    
    if [ -z "$WAS_HOME" ];then
        sDir=`dirname ${0}`
        if [ -e "$sDir/../etc/RFIDICServer.xml" ];then
            WAS_HOME=$sDir/../..
        fi
    fi
	
	if [ -n "$WAS_HOME" ];then
		getMessageClasspath
		msg=`${WAS_HOME}/java/bin/java -classpath $returnString com.ibm.rfidic.messages.tools.RFIDICGetMessage -noid "$@"`
	fi
}

verbose()
{
	if [ "$1" -eq "$TRUE" -o "$1" -eq "$FALSE" ];then
		isVerbose=$1
		return $TRUE
	else
		return $FALSE
	fi
}

assignLogFile()
{
	#create directory for log file
    logDir=`dirname $1`
	if [ ! -d "$logDir" ];then
		mkdir -p `dirname $1`
		if [ "$?" -ne "0" ];then
			getMessage TSIN02207E $logDir
			log $msg
			#log "Could not create directory $logDir"
			return $FALSE
		fi
	fi
	
	
	#create log file
	if [ ! -f "$1" ];then
		touch $1
		if [ "$?" -ne "0" -a -w "$1" ];then
			getMessage TSIN02208E $1
			log $msg
			#log "Could not create file $1"
			return $FALSE
		fi
	fi
	
	utilsLogFile=$1
	return $TRUE
}

run_command()
{
	command="$*"
	"$@"
	retcode=$?
	if [ "$retcode" -ne 0 ]
	then	
		getMessage RFID05138E "$command"
		return $retcode
	fi
}

# Usage: runCommandAsUser <User:password> <Command>
# Note: The password is the password of the user requesting the command to be run, not the user
# which is passed into the function. The requesting user must also be part of the sudoers list.
runCommandAsUser()
{
    unset runUser
    unset runPass
    runUser=`echo $1 | sed "s/:.*//g"`
    containsPassword=`echo $1 | sed "s/[^:]//g"`
    if [ -n "$containsPassword" ];then
        runPass=`echo $1 | sed "s/.*://g"`
    fi
    shift
    command="$*"
    retcode=1
    COUNT=0
    if [ "$CURRENT_USER" = "$runUser" ];then
        sh -c "$command"
        retcode=$?    
    elif [ "$CURRENT_USER" != "root" -a -n "$runPass" ];then
        sudo -p "" -S -u $runUser sh -c "$command" << RUNCMD;retcode=$?
$runPass
RUNCMD
    else
    	getMessage TSIN02206I $runUser
    	echo $msg
        #echo "If prompted - enter the password for $runUser"
        while [ $retcode -ne 0 ] && [ $COUNT -lt 2 ]
        do
            if [ "$PLATFORM" = "SunOS" ];then
                /bin/su - ${runUser} -c "${command}"
                retcode=$?
            elif [ "$PLATFORM" = "AIX" ];then
                /bin/su - ${runUser} "-c ${command}"
                retcode=$?
            else
                /bin/su - -c "${command}" ${runUser}
                retcode=$?
            fi
            COUNT=`expr $COUNT + 1`
        done
    fi

    return $retcode
}

getWAScredentials()
{
    if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
        tsGetMessage.sh RFID05030I "$was_admin_user"
        stty -echo
        read was_admin_password
        stty echo
        echo
    fi

    if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
        credentials="-user $was_admin_user -password $was_admin_password"
    else
        credentials=""
    fi
}

promptUserYesNo()
{
	while [ 1 ];do
		read input
		if [ "$input" = "y" ] || [ "$input" = "Y" ];then
			return $YES
		elif [ "$input" = "n" ] || [ "$input" = "N" ];then
			return $NO
		else
			getMessage RFID05256E
		fi
    done
}

addGroupToUser()
{
    thisGroup=$1
    thisUser=$2

    groupFound=$FALSE

    if [ "$PLATFORM" = "SunOS" ];then
		groupList=`groups ${thisUser}`
    else
		groupList=`id -nG ${thisUser}`
    fi

    for group in $groupList
    do
        if [ "$group" = "$1" ];then
            groupFound=$TRUE
        fi
    done

    if [ "$groupFound" = "$FALSE" ];then
        grp_list=`$ECHO ${groupList} | tr " " ","`
        grp_list=$grp_list",${thisGroup}"
        if [ "$CURRENT_USER" = "root" -o -n "$TS_ADMIN_PASSWORD" ];then
            runCommandAsUser root:$TS_ADMIN_PASSWORD /usr/sbin/usermod -G ${grp_list} ${thisUser}
        fi
    fi
}

# Create any required object caches based on imported metadata files in tsar/tscontent/metadata
# The prereqChecks.sh script must be loaded before this function is called.
createObjectCaches()
{
    RFIDIC_PROPS_FILE=/tmp/cfgProps.$$
    writeProperties

    getWAScredentials
    if [ -z "$was_admin_user" -a -z "$was_admin_password" ];then
        isWASRunning
    else
        isWASRunning $was_admin_user $was_admin_password
    fi
    was_status=$?

    if [ "$was_status" -eq "$TRUE" ];then
        conntype="-conntype SOAP"
    else
        conntype="-conntype NONE"
    fi

    run_command $WAS_PROFILE_HOME/bin/wsadmin.sh $conntype $credentials -lang jython -wsadmin_classpath $WSADMIN_JARS_PATH -f $TS_HOME/bin/jython/addObjectCacheFromMetaData.py $RFIDIC_PROPS_FILE $TS_HOME/bin/jython
    retCode=$?
    rm -f $RFIDIC_PROPS_FILE
}

isWASSecurityEnabled()
{
    if [ -z "$securityEnabledInternal" ];then
        securityEnabledInternal=`${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -lang jython -c "AdminTask.isGlobalSecurityEnabled()" | ${TAIL}1`
    fi

    if [ "$securityEnabledInternal" == "'true'" ];then
        return $TRUE
    else
        return $FALSE
    fi
}

getWebServicePort()
{
    unset ws_port
    
    portdefFile="$WAS_PROFILE_HOME/properties/portdef.props"
    
    isWASSecurityEnabled
    if [ $? -eq  $TRUE ];then
        portName="WC_defaulthost_secure"
    else
        portName="WC_defaulthost"
    fi
    
    ws_port=`grep $portName= $portdefFile |sed 's/'$portName'=//'` >> /dev/null
}

getUrlProtocol() {
    isWASSecurityEnabled
    if [ $? -eq  $TRUE ];then
        protocol="https://"
    else
        protocol="http://"
    fi 
}

getBaseUrl() {
    getWebServicePort
    getUrlProtocol
    base_url=$protocol$HOSTNAMEFULL":"$ws_port
}

putJavaInPath() {
    if [ -z "$WAS_HOME" ];then
        sDir=`dirname ${0}`
        if [ -e "$sDir/../etc/RFIDICServer.xml" ];then
            WAS_HOME=$sDir/../..
            WAS_HOME=`cd ${WAS_HOME} ; pwd`
        fi
    fi

    JAVA_EXEC=`which java`

    # Does the path to the existing Java in the current PATH contain the path to WAS?
    # If not, put the WAS Java version at the head of the path and set JAVA_HOME.
    if [[ $JAVA_EXEC != ${WAS_HOME}* ]];then
        PATH=$WAS_HOME/java/bin:$PATH
        export PATH
        JAVA_HOME=$WAS_HOME/java
        export JAVA_HOME
    fi
}

isLocalOSSecurityEnabled()
{
    isWASSecurityEnabled

    if [ $? -eq $TRUE ];then
        run_command ${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -lang jython -c "AdminTask.getActiveSecuritySettings()" | grep LocalOSUserRegistry > /dev/null
        if [ $? -eq 0 ];then
            return $TRUE
        fi
    fi

    return $FALSE
}

ECHO="echo"
AWK_PERIOD="awk -F ".""
AWK_EQUAL="awk -F "=""
AWK_QUOTE="awk -F "\'""
AWK_COLON="awk -F ":""
AWK_SLASH="awk -F "/""
TRUE=0
FALSE=1
YES=$TRUE
NO=$FALSE
HEAD="head -n "
TAIL="tail -n "

if [ -z "$isVerbose" ];then
    isVerbose=$FALSE
fi

if [ -z "$utilsLogFile" ];then
    utilsLogFile=/tmp/TSConfigLog_`date "+%Y%m%d%H%M%S"`
fi

ID=`id`
CURRENT_USER=`expr "$ID" : ".*uid=[0-9]*(\([^)]*\)*"`
CURRENT_GROUP=`expr "$ID" : ".*gid=[0-9]*(\([^)]*\)*"`

PLATFORM=`uname`
case $PLATFORM in
    AIX)
        HOSTNAME=`hostname -s`
        HOSTNAMEFULL=`hostname`
        ;;
    Linux)
        ECHO="echo -e"
        HOSTNAME=`hostname -s`
        HOSTNAMEFULL=`hostname -f`
        ;;
    SunOS)
        AWK_PERIOD="awk -F."
        AWK_EQUAL="awk -F="
        AWK_QUOTE="awk -F'"
        AWK_COLON="awk -F:"
        AWK_SLASH="awk -F/"
        HOSTNAME=`hostname`
        sun_release=`uname -r`
        if [ "$sun_release" = "5.10" ];then
            HOSTNAMEFULL=`/usr/sbin/check-hostname | awk '{print($7)}'`
        else
            HOSTNAMEFULL=`/usr/lib/mail/sh/check-hostname | awk '{print($7)}'`
        fi
        HEAD="head -"
        TAIL="tail -"
        ;;
esac

putJavaInPath
