/**
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-O98
 * (c)  Copyright IBM Corp. 2006, 2011 All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with
 * IBM Corp.
 * 
 * The following sample of source code ("Sample Code") is owned by 
 * International Business Machines Corporation or one of its subsidiaries 
 * ("IBM") and is copyrighted and licensed, not sold. You may use, copy, 
 * modify, and distribute the Sample Code in any form without payment to IBM, 
 * for the purpose of assisting you in the development of your applications.
 *
 * The Sample Code is provided to you on an "AS IS" basis, without warranty of 
 * any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER EXPRESS OR 
 * IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Some jurisdictions do 
 * not allow for the exclusion or limitation of implied warranties, so the 
 * above limitations or exclusions may not apply to you. IBM shall not be 
 * liable for any damages you suffer as a result of using, copying, modifying 
 * or distributing the Sample Code, even if IBM has been advised of the 
 * possibility of such damages.
 */
package com.ibm.ts.alerts.templates;

import java.util.Iterator;
import java.util.List;

import com.ibm.rfidic.alerts.Entity;
import com.ibm.rfidic.alerts.IDeliveryMethod;
import com.ibm.rfidic.alerts.IDeliveryPoint;
import com.ibm.rfidic.alerts.INotification;
import com.ibm.rfidic.alerts.IParameter;
import com.ibm.rfidic.alerts.IParameterValue;
import com.ibm.rfidic.alerts.Parameter;
import com.ibm.rfidic.alerts.util.Utility;
import com.ibm.rfidic.common.exceptions.RFIDICException;
import com.ibm.rfidic.value.IAttributeType;
import com.ibm.rfidic.value.TypeFactory;

/* 
 * This class is a template class for a Delivery Method. A Solution Developer
 * can use it as a starting point for building a Delivery Method which is to be deployed 
 * to the RFIDIC Alerts Component.
 */
//  <-- Solution Developer: rename this class to reflect your delivery method name.
public class DeliveryMethodTemplate extends Entity implements IDeliveryMethod
{
  /* Declare an array to store the delivery method's parameters. */
  private IParameter[] parameters;
  
  /* Declare parameters for the delivery method. */
  //<-- Solution Developer: edit and add to the parameters below.
  private IParameter fileNameParam;
  private IParameter messageParam;

  public DeliveryMethodTemplate()
  {
    /* Call out super class constructor passing in the name and description of the 
     * delivery method. This text will be used to refer to the Delivery Method. */
    //  <-- Solution Developer: edit the line below.
    super("File delivery method", "Writes notification into a file."); //$NON-NLS-1$ //$NON-NLS-2$
    
    /* Create a string type to be used when constructing parameters. */
    final TypeFactory    typeFactory = TypeFactory.getInstance();
    final IAttributeType stringType  = typeFactory.getStringType(255, 0);

    /* Initialize the delivery method parameters. */ 
    //  <-- Solution Developer: edit the lines below to declare your parameters.    
    fileNameParam = new Parameter("Delivery file name", stringType, true, null); //$NON-NLS-1$
    messageParam  = new Parameter("Message", stringType, true, null); //$NON-NLS-1$

    parameters = new IParameter[] { fileNameParam, messageParam };
  }
  
  private void processNotification(INotification notification, IDeliveryPoint deliveryPoint)
  {
    /* The getDeliveryValues() method returns the parameter values for the 
     * delivery method. */
    final IParameterValue[] parameterValues = notification.getDeliveryValues(deliveryPoint);
      
    try
    {
      /* Retrieve the parameter values provided by the subscription. */
      final String deliveryFileName = (String) Utility.findValue(parameterValues, fileNameParam).getSQLValue();
      final String messageTemplate  = (String) Utility.findValue(parameterValues, messageParam).getSQLValue();
          
      //          
      //  <-- Solution Developer: Add code here to perform your delivery method.
      //
    }
    catch(RFIDICException e)
    {
      e.printStackTrace();
    }
  }
 
  // ========================================================================== //
  // === For simple Delivery Methods there is no need to alter any of      ==== //
  // === the methods below.                                                ==== //
  //=========================================================================== //
  
  /* This method is called when the Alerts Engine needs the delivery method 
   * parameters. */ 
  public IParameter[] getParameters()
  {
    return parameters;
  }

  /* This method is called when an alert has been triggered and notifications
   * need to be processed.  */
  public void processNotifications(List<INotification> notifications, IDeliveryPoint deliveryPoint)
  {
    if ( notifications == null || notifications.size() == 0 )
      return;

    for ( Iterator<INotification> ix = notifications.iterator(); ix.hasNext(); )
    {
      INotification notification = (INotification) ix.next();

      processNotification(notification,deliveryPoint);
    }
  }

  public String toString()
  {
    String text = ""; //$NON-NLS-1$
    text += "[\n"; //$NON-NLS-1$
    text += "id: " + getId() + ",\n"; //$NON-NLS-1$ //$NON-NLS-2$
    text += "className: " + this.getClass().getName() + ",\n"; //$NON-NLS-1$ //$NON-NLS-2$
    text += "name: " + getName() + ",\n"; //$NON-NLS-1$ //$NON-NLS-2$
    text += "description: " + getDescription() + ",\n"; //$NON-NLS-1$ //$NON-NLS-2$
    text += "]"; //$NON-NLS-1$
    return text;
  }

  public String[] getOutputChannels()
  {
    return null;
  }
}
