/*
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-O98
 * (c)  Copyright IBM Corp. 2006, 2011 All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with
 * IBM Corp.
 * 
 * The following sample of source code ("Sample Code") is owned by 
 * International Business Machines Corporation or one of its subsidiaries 
 * ("IBM") and is copyrighted and licensed, not sold. You may use, copy, 
 * modify, and distribute the Sample Code in any form without payment to IBM, 
 * for the purpose of assisting you in the development of your applications.
 *
 * The Sample Code is provided to you on an "AS IS" basis, without warranty of 
 * any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER EXPRESS OR 
 * IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Some jurisdictions do 
 * not allow for the exclusion or limitation of implied warranties, so the 
 * above limitations or exclusions may not apply to you. IBM shall not be 
 * liable for any damages you suffer as a result of using, copying, modifying 
 * or distributing the Sample Code, even if IBM has been advised of the 
 * possibility of such damages.
 */

package com.ibm.ts.alerts.utils;

import java.sql.Connection;
import java.sql.SQLException;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.sql.DataSource;

import com.ibm.websphere.rsadapter.JDBCConnectionSpec;
import com.ibm.websphere.rsadapter.WSDataSource;
import com.ibm.websphere.rsadapter.WSRRAFactory;

import java.sql.ResultSet;

import java.sql.Statement;
import java.sql.PreparedStatement;

/** This class provides some database utility methods for building 
 * native alerts.
 */
public class DBUtil 
{
  
  Connection conn = null;

  /** Returns a connection to the database identified by the 
   * JNDI name passed in.  */ 
  private Connection getConnection(String dsJndiName) throws SQLException
  {
    Context initCtx    = null;
    Object namedObject = null;
    try 
    {
      Context initialContext = new InitialContext();
      namedObject = initialContext.lookup(dsJndiName);
    }
    catch (Exception ex) 
    {
      ex.printStackTrace();
      SQLException sqlEx = new SQLException(ex.getLocalizedMessage());
      sqlEx.initCause(ex);
      throw sqlEx;
    } 
    finally 
    {
      closeContext(initCtx);
    }
    
    validateDataSourceType(namedObject, dsJndiName);
    conn = getDataSourceConnection((DataSource) namedObject);
    conn.setTransactionIsolation(Connection.TRANSACTION_READ_COMMITTED);
    return conn;
  }
  
  /** Returns a prepared statement for the query name and JNDI 
   * name passed in.  */
  public PreparedStatement getPreparedStatement(String query, String dsJndiName) throws SQLException
  {    
    return getConnection(dsJndiName).prepareStatement(query);
  }
  
  /** Executes the query string passed on the JNDI connection and
   * returns the result set. */
  public ResultSet executeQuery(String query, String dsJndiName) throws SQLException
  {
    Statement s = getConnection(dsJndiName).createStatement();
    System.err.println("query ::"+query); //$NON-NLS-1$
    return s.executeQuery(query);
  }

  /** Closes the connection. */
  public void closeConnection() throws Exception
  {
    conn.close();
  }

  /**
   * This method will be called by the Connection class to get the DBMS
   * connection
   */
  private Connection getDataSourceConnection(DataSource ds) throws SQLException 
  {
    JDBCConnectionSpec spec=WSRRAFactory.createJDBCConnectionSpec();
    spec.setTransactionIsolation(Connection.TRANSACTION_READ_COMMITTED); 
    return ((WSDataSource)ds).getConnection(spec);
  }

  /**
   * This method is used to validate a JNDI data source object Have not tested
   * this method is JNDI lookup is pending
   */
  private void validateDataSourceType(Object namedObject, String jndiNameUrl)
      throws SQLException 
  {
    if (namedObject != null && namedObject instanceof DataSource)
      return;
    throw new SQLException("DataSource not available"); //$NON-NLS-1$
  }

  /** Closes the context passed in. */
  private void closeContext(Context ctx) 
  {
    if (ctx == null)
      return; // nothing to close
    
    try 
    {
      ctx.close();
    } 
    catch (Exception e) 
    {
      e.printStackTrace();
    }
  }
}