/*
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-O98
 * (c)  Copyright IBM Corp. 2006, 2011 All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with
 * IBM Corp.
 * 
 * The following sample of source code ("Sample Code") is owned by 
 * International Business Machines Corporation or one of its subsidiaries 
 * ("IBM") and is copyrighted and licensed, not sold. You may use, copy, 
 * modify, and distribute the Sample Code in any form without payment to IBM, 
 * for the purpose of assisting you in the development of your applications.
 *
 * The Sample Code is provided to you on an "AS IS" basis, without warranty of 
 * any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER EXPRESS OR 
 * IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Some jurisdictions do 
 * not allow for the exclusion or limitation of implied warranties, so the 
 * above limitations or exclusions may not apply to you. IBM shall not be 
 * liable for any damages you suffer as a result of using, copying, modifying 
 * or distributing the Sample Code, even if IBM has been advised of the 
 * possibility of such damages.
 */ 
package com.ibm.rfidic.audit.sample;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Enumeration;
import java.util.concurrent.atomic.AtomicInteger;

import javax.ejb.MessageDrivenBean;
import javax.ejb.MessageDrivenContext;
import javax.jms.JMSException;
import javax.jms.MapMessage;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.TextMessage;

/**
 * Bean implementation class for Enterprise Bean: com.ibm.rfidic.audit.sample.AuditEventReader
 */
public class AuditEventReaderBean implements MessageDrivenBean, MessageListener
{

	private static final long serialVersionUID = 1L;
	private MessageDrivenContext fMessageDrivenCtx;
	
	private static File auditDir;
	private static AtomicInteger sequenceNumber;
	private static String        executionId;
	
	static {
    final StringBuilder path = new StringBuilder ();
    path.append (System.getProperty ("TS_HOME")); //$NON-NLS-1$
    path.append ("/samples/audit"); //$NON-NLS-1$
    auditDir = new File (path.toString ());
    try {
      auditDir.mkdirs ();
    } catch (Exception e) {
      System.err.println ("Error creating audit directory");
      e.printStackTrace();
      auditDir = null;
    }
    
    sequenceNumber = new AtomicInteger ();
    
    executionId = Long.toString (System.currentTimeMillis ());
	}

	/**
	 * getMessageDrivenContext
	 */
	public MessageDrivenContext getMessageDrivenContext() {
		return fMessageDrivenCtx;
	}

	/* (non-Javadoc)
	 * @see javax.ejb.MessageDrivenBean#setMessageDrivenContext(javax.ejb.MessageDrivenContext)
	 */
	@Override
	public void setMessageDrivenContext(MessageDrivenContext ctx) {
		fMessageDrivenCtx = ctx;
	}

	/**
	 * ejbCreate
	 */
	public void ejbCreate() {
	}

	/* (non-Javadoc)
	 * @see javax.jms.MessageListener#onMessage(javax.jms.Message)
	 */
	@Override
	public void onMessage(Message msg) {
		try {
      if (msg instanceof MapMessage){
      	final MapMessage msg1 = (MapMessage) msg;
      	try {
          System.out.println("Received map message: "+msg.getJMSMessageID ()); //$NON-NLS-1$
      		// Print out the map names in the MapMessage 
      		System.out.println("Map names in the map mesage:"); //$NON-NLS-1$
      		final Enumeration<?> mapNames = msg1.getMapNames ();
      		while (mapNames.hasMoreElements ()) {
      		  System.out.println (mapNames.nextElement ().toString ());
      		}
      		System.out.println("Property names in the map mesage:"); //$NON-NLS-1$
      		// Print out all the property names in the MapMessage
      		final Enumeration<?> propNames = msg1.getPropertyNames ();
      		while (propNames.hasMoreElements ()) {
      		  System.out.println (propNames.nextElement ().toString ());
      		}
      		//	TODO: Forward the received message to business logic for processing...
      	} catch (JMSException e) {
      		e.printStackTrace();
      	}
      } else if (msg instanceof TextMessage) {
        final TextMessage textMsg = (TextMessage)msg;
        System.out.printf ("Received text message : %s %s", textMsg.getJMSMessageID (), textMsg.getText ()); //$NON-NLS-1$
        saveMessage (textMsg.getText ());
        // TODO: Forward the received message to business logic for processing...
      }
      else {
      	System.out.printf("Received message is neither a text message nor a map message: %s\n", msg.getJMSMessageID ()); //$NON-NLS-1$
      }
    } catch (JMSException e) {
      e.printStackTrace();
    }
	}
	
	private void saveMessage (String message) {
	  if (auditDir != null) {
      final StringBuilder fileName = new StringBuilder ("msg"); //$NON-NLS-1$
      fileName.append (executionId);
      fileName.append ('_');
      fileName.append (sequenceNumber.getAndIncrement ());
      fileName.append (".xml"); //$NON-NLS-1$
      final File msgFile = new File (auditDir, fileName.toString ());
      try {
        final FileWriter writer = new FileWriter (msgFile);
        writer.write (message);
        writer.close ();
      } catch (IOException e) {
        e.printStackTrace ();
      }
    }
	}

	/* (non-Javadoc)
	 * @see javax.ejb.MessageDrivenBean#ejbRemove()
	 */
	@Override
	public void ejbRemove() {
	}
}
